@@ -95,7 +95,7 @@ do { \
 #  define ARCH_HEAP_NSECTS    ARCH_PG2SECT(CONFIG_ARCH_HEAP_NPAGES)
 
 #  ifdef CONFIG_ARCH_VMA_MAPPING
-#    define ARCH_SHM_NSECTS   ARCH_PG2SECT(ARCH_SHM_MAXPAGES)
+#    define ARCH_SHM_NSECTS   ARCH_PG2SECT((CONFIG_ARCH_SHM_NPAGES * CONFIG_ARCH_SHM_MAXREGIONS))
 #  endif
 
 #  ifdef CONFIG_ARCH_STACK_DYNAMIC
