@@ -96,7 +96,7 @@
 #define GD32_IRQ_TIMER7_CHANNEL             (GD32_IRQ_EXINT+46) /* 46: TIMER7 channel capture compare interrupt */
 #define GD32_IRQ_DMA0_CHANNEL7              (GD32_IRQ_EXINT+47) /* 47: DMA0 channel7 interrupt */
 
-#if defined(CONFIG_GD32F4_GD32F450)
+#if defined(CONFIG_GD32F4_GD32F450) || defined(CONFIG_GD32F4_GD32F470)
 #define GD32_IRQ_EXMC                       (GD32_IRQ_EXINT+48) /* 48: EXMC interrupt */
 #define GD32_IRQ_SDIO                       (GD32_IRQ_EXINT+49) /* 49: SDIO interrupt */
 #define GD32_IRQ_TIMER4                     (GD32_IRQ_EXINT+50) /* 50: TIMER4 interrupt */
@@ -210,7 +210,7 @@
     #error "Unkonwn GD32F4xx chip."
 #endif /* CONFIG_GD32F4_GD32F450 */
 
-#if defined(CONFIG_GD32F4_GD32F450)
+#if defined(CONFIG_GD32F4_GD32F450) || defined(CONFIG_GD32F4_GD32F470)
 #  define GD32_IRQ_NEXTINT      (91)
 #  define NR_IRQS                (GD32_IRQ_EXINT + GD32_IRQ_NEXTINT)
 #elif defined(CONFIG_GD32F4_GD32F407)
