@@ -73,7 +73,8 @@
     defined (CONFIG_ARCH_CHIP_STM32H753ZI) || \
     defined (CONFIG_ARCH_CHIP_STM32H7B3LI) || \
     defined (CONFIG_ARCH_CHIP_STM32H745XI) || \
-    defined (CONFIG_ARCH_CHIP_STM32H745ZI)
+    defined (CONFIG_ARCH_CHIP_STM32H745ZI) || \
+    defined (CONFIG_ARCH_CHIP_STM32H755II)
 #elif defined(CONFIG_ARCH_CHIP_STM32H747XI)
 #else
 #  error STM32 H7 chip not identified
