@@ -97,68 +97,68 @@
 
 /* Camera Sensor Interface (CSI) */
 
-#define PIO_CSI0_CK     (PIO_PERIPH3 | PIO_PORT_PIOE | PIO_PIN1)
-#define PIO_CSI0_D0     (PIO_PERIPH3 | PIO_PORT_PIOE | PIO_PIN4)
-#define PIO_CSI0_D1     (PIO_PERIPH3 | PIO_PORT_PIOE | PIO_PIN5)
-#define PIO_CSI0_D2     (PIO_PERIPH3 | PIO_PORT_PIOE | PIO_PIN6)
-#define PIO_CSI0_D3     (PIO_PERIPH3 | PIO_PORT_PIOE | PIO_PIN7)
-#define PIO_CSI0_D4     (PIO_PERIPH3 | PIO_PORT_PIOE | PIO_PIN8)
-#define PIO_CSI0_D5     (PIO_PERIPH3 | PIO_PORT_PIOE | PIO_PIN9)
-#define PIO_CSI0_D6     (PIO_PERIPH3 | PIO_PORT_PIOE | PIO_PIN10)
-#define PIO_CSI0_D7     (PIO_PERIPH3 | PIO_PORT_PIOE | PIO_PIN11)
-#define PIO_CSI0_D8     (PIO_PERIPH5 | PIO_PORT_PIOG | PIO_PIN4)
-#define PIO_CSI0_D9     (PIO_PERIPH5 | PIO_PORT_PIOG | PIO_PIN5)
-#define PIO_CSI0_D10    (PIO_PERIPH5 | PIO_PORT_PIOG | PIO_PIN6)
-#define PIO_CSI0_D11    (PIO_PERIPH5 | PIO_PORT_PIOG | PIO_PIN7)
-#define PIO_CSI0_D12    (PIO_PERIPH5 | PIO_PORT_PIOG | PIO_PIN8)
-#define PIO_CSI0_D13    (PIO_PERIPH5 | PIO_PORT_PIOG | PIO_PIN9)
-#define PIO_CSI0_D14    (PIO_PERIPH5 | PIO_PORT_PIOG | PIO_PIN10)
-#define PIO_CSI0_D15    (PIO_PERIPH5 | PIO_PORT_PIOG | PIO_PIN11)
-#define PIO_CSI0_HSYNC  (PIO_PERIPH3 | PIO_PORT_PIOE | PIO_PIN2)
-#define PIO_CSI0_PCK    (PIO_PERIPH3 | PIO_PORT_PIOE | PIO_PIN0)
-#define PIO_CSI0_VSYNC  (PIO_PERIPH3 | PIO_PORT_PIOE | PIO_PIN3)
+#define PIO_CSI0_CK       (PIO_PERIPH3 | PIO_PORT_PIOE | PIO_PIN1)
+#define PIO_CSI0_D0       (PIO_PERIPH3 | PIO_PORT_PIOE | PIO_PIN4)
+#define PIO_CSI0_D1       (PIO_PERIPH3 | PIO_PORT_PIOE | PIO_PIN5)
+#define PIO_CSI0_D2       (PIO_PERIPH3 | PIO_PORT_PIOE | PIO_PIN6)
+#define PIO_CSI0_D3       (PIO_PERIPH3 | PIO_PORT_PIOE | PIO_PIN7)
+#define PIO_CSI0_D4       (PIO_PERIPH3 | PIO_PORT_PIOE | PIO_PIN8)
+#define PIO_CSI0_D5       (PIO_PERIPH3 | PIO_PORT_PIOE | PIO_PIN9)
+#define PIO_CSI0_D6       (PIO_PERIPH3 | PIO_PORT_PIOE | PIO_PIN10)
+#define PIO_CSI0_D7       (PIO_PERIPH3 | PIO_PORT_PIOE | PIO_PIN11)
+#define PIO_CSI0_D8       (PIO_PERIPH5 | PIO_PORT_PIOG | PIO_PIN4)
+#define PIO_CSI0_D9       (PIO_PERIPH5 | PIO_PORT_PIOG | PIO_PIN5)
+#define PIO_CSI0_D10      (PIO_PERIPH5 | PIO_PORT_PIOG | PIO_PIN6)
+#define PIO_CSI0_D11      (PIO_PERIPH5 | PIO_PORT_PIOG | PIO_PIN7)
+#define PIO_CSI0_D12      (PIO_PERIPH5 | PIO_PORT_PIOG | PIO_PIN8)
+#define PIO_CSI0_D13      (PIO_PERIPH5 | PIO_PORT_PIOG | PIO_PIN9)
+#define PIO_CSI0_D14      (PIO_PERIPH5 | PIO_PORT_PIOG | PIO_PIN10)
+#define PIO_CSI0_D15      (PIO_PERIPH5 | PIO_PORT_PIOG | PIO_PIN11)
+#define PIO_CSI0_HSYNC    (PIO_PERIPH3 | PIO_PORT_PIOE | PIO_PIN2)
+#define PIO_CSI0_PCK      (PIO_PERIPH3 | PIO_PORT_PIOE | PIO_PIN0)
+#define PIO_CSI0_VSYNC    (PIO_PERIPH3 | PIO_PORT_PIOE | PIO_PIN3)
 
-#define PIO_CSI1_CK     (PIO_PERIPH3 | PIO_PORT_PIOG | PIO_PIN1)
-#define PIO_CSI1_D0_1   (PIO_PERIPH3 | PIO_PORT_PIOG | PIO_PIN4)
-#define PIO_CSI1_D0_2   (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN0)
-#define PIO_CSI1_D1_1   (PIO_PERIPH3 | PIO_PORT_PIOG | PIO_PIN5)
-#define PIO_CSI1_D1_2   (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN1)
-#define PIO_CSI1_D2_1   (PIO_PERIPH3 | PIO_PORT_PIOG | PIO_PIN6)
-#define PIO_CSI1_D2_2   (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN2)
-#define PIO_CSI1_D3_1   (PIO_PERIPH3 | PIO_PORT_PIOG | PIO_PIN7)
-#define PIO_CSI1_D3_2   (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN3)
-#define PIO_CSI1_D4_1   (PIO_PERIPH3 | PIO_PORT_PIOG | PIO_PIN8)
-#define PIO_CSI1_D4_2   (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN4)
-#define PIO_CSI1_D5_1   (PIO_PERIPH3 | PIO_PORT_PIOG | PIO_PIN9)
-#define PIO_CSI1_D5_2   (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN5)
-#define PIO_CSI1_D6_1   (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN6)
-#define PIO_CSI1_D6_2   (PIO_PERIPH3 | PIO_PORT_PIOG | PIO_PIN10)
-#define PIO_CSI1_D7_1   (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN7)
-#define PIO_CSI1_D7_2   (PIO_PERIPH3 | PIO_PORT_PIOG | PIO_PIN11)
-#define PIO_CSI1_D8     (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN8)
-#define PIO_CSI1_D9     (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN9)
-#define PIO_CSI1_D10    (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN10)
-#define PIO_CSI1_D11    (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN11)
-#define PIO_CSI1_D12    (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN12)
-#define PIO_CSI1_D13    (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN13)
-#define PIO_CSI1_D14    (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN14)
-#define PIO_CSI1_D15    (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN15)
-#define PIO_CSI1_D16    (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN16)
-#define PIO_CSI1_D17    (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN17)
-#define PIO_CSI1_D18    (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN18)
-#define PIO_CSI1_D19    (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN19)
-#define PIO_CSI1_D20    (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN20)
-#define PIO_CSI1_D21    (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN21)
-#define PIO_CSI1_D22    (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN22)
-#define PIO_CSI1_D23    (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN23)
-#define PIO_CSI1_FIELD  (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN25)
-#define PIO_CSI1_HSYNC  (PIO_PERIPH3 | PIO_PORT_PIOG | PIO_PIN2)
-#define PIO_CSI1_HSYNC  (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN26)
-#define PIO_CSI1_MCLK   (PIO_PERIPH3 | PIO_PORT_PIOD | PIO_PIN20)
-#define PIO_CSI1_PCK    (PIO_PERIPH3 | PIO_PORT_PIOG | PIO_PIN0)
-#define PIO_CSI1_PCLK   (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN24)
-#define PIO_CSI1_VSYNC  (PIO_PERIPH3 | PIO_PORT_PIOG | PIO_PIN3)
-#define PIO_CSI1_VSYNC  (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN27)
+#define PIO_CSI1_CK       (PIO_PERIPH3 | PIO_PORT_PIOG | PIO_PIN1)
+#define PIO_CSI1_D0_1     (PIO_PERIPH3 | PIO_PORT_PIOG | PIO_PIN4)
+#define PIO_CSI1_D0_2     (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN0)
+#define PIO_CSI1_D1_1     (PIO_PERIPH3 | PIO_PORT_PIOG | PIO_PIN5)
+#define PIO_CSI1_D1_2     (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN1)
+#define PIO_CSI1_D2_1     (PIO_PERIPH3 | PIO_PORT_PIOG | PIO_PIN6)
+#define PIO_CSI1_D2_2     (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN2)
+#define PIO_CSI1_D3_1     (PIO_PERIPH3 | PIO_PORT_PIOG | PIO_PIN7)
+#define PIO_CSI1_D3_2     (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN3)
+#define PIO_CSI1_D4_1     (PIO_PERIPH3 | PIO_PORT_PIOG | PIO_PIN8)
+#define PIO_CSI1_D4_2     (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN4)
+#define PIO_CSI1_D5_1     (PIO_PERIPH3 | PIO_PORT_PIOG | PIO_PIN9)
+#define PIO_CSI1_D5_2     (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN5)
+#define PIO_CSI1_D6_1     (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN6)
+#define PIO_CSI1_D6_2     (PIO_PERIPH3 | PIO_PORT_PIOG | PIO_PIN10)
+#define PIO_CSI1_D7_1     (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN7)
+#define PIO_CSI1_D7_2     (PIO_PERIPH3 | PIO_PORT_PIOG | PIO_PIN11)
+#define PIO_CSI1_D8       (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN8)
+#define PIO_CSI1_D9       (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN9)
+#define PIO_CSI1_D10      (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN10)
+#define PIO_CSI1_D11      (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN11)
+#define PIO_CSI1_D12      (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN12)
+#define PIO_CSI1_D13      (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN13)
+#define PIO_CSI1_D14      (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN14)
+#define PIO_CSI1_D15      (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN15)
+#define PIO_CSI1_D16      (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN16)
+#define PIO_CSI1_D17      (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN17)
+#define PIO_CSI1_D18      (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN18)
+#define PIO_CSI1_D19      (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN19)
+#define PIO_CSI1_D20      (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN20)
+#define PIO_CSI1_D21      (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN21)
+#define PIO_CSI1_D22      (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN22)
+#define PIO_CSI1_D23      (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN23)
+#define PIO_CSI1_FIELD    (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN25)
+#define PIO_CSI1_HSYNC_1  (PIO_PERIPH3 | PIO_PORT_PIOG | PIO_PIN2)
+#define PIO_CSI1_HSYNC_2  (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN26)
+#define PIO_CSI1_MCLK     (PIO_PERIPH3 | PIO_PORT_PIOD | PIO_PIN20)
+#define PIO_CSI1_PCK      (PIO_PERIPH3 | PIO_PORT_PIOG | PIO_PIN0)
+#define PIO_CSI1_PCLK     (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN24)
+#define PIO_CSI1_VSYNC_1  (PIO_PERIPH3 | PIO_PORT_PIOG | PIO_PIN3)
+#define PIO_CSI1_VSYNC_2  (PIO_PERIPH7 | PIO_PORT_PIOH | PIO_PIN27)
 
 /* Ethernet MAC */
 
@@ -414,10 +414,10 @@
 #define PIO_SDC0_D2     (PIO_PERIPH2 | PIO_PORT_PIOF | PIO_PIN5)
 #define PIO_SDC0_D3     (PIO_PERIPH2 | PIO_PORT_PIOF | PIO_PIN4)
 
-#define PIO_SDC1_CLK    (PIO_PERIPH4 | PIO_PORT_PIOG | PIO_PIN1)
-#define PIO_SDC1_CLK    (PIO_PERIPH5 | PIO_PORT_PIOH | PIO_PIN23)
-#define PIO_SDC1_CMD    (PIO_PERIPH4 | PIO_PORT_PIOG | PIO_PIN0)
-#define PIO_SDC1_CMD    (PIO_PERIPH5 | PIO_PORT_PIOH | PIO_PIN22)
+#define PIO_SDC1_CLK_1  (PIO_PERIPH4 | PIO_PORT_PIOG | PIO_PIN1)
+#define PIO_SDC1_CLK_2  (PIO_PERIPH5 | PIO_PORT_PIOH | PIO_PIN23)
+#define PIO_SDC1_CMD_1  (PIO_PERIPH4 | PIO_PORT_PIOG | PIO_PIN0)
+#define PIO_SDC1_CMD_2  (PIO_PERIPH5 | PIO_PORT_PIOH | PIO_PIN22)
 #define PIO_SDC1_D0_1   (PIO_PERIPH4 | PIO_PORT_PIOG | PIO_PIN2)
 #define PIO_SDC1_D0_2   (PIO_PERIPH5 | PIO_PORT_PIOH | PIO_PIN24)
 #define PIO_SDC1_D1_1   (PIO_PERIPH4 | PIO_PORT_PIOG | PIO_PIN3)
