@@ -37,6 +37,7 @@
 #include "mmu.h"
 #include "addrenv.h"
 #include "pgalloc.h"
+#include "sched/sched.h"
 
 #if defined(CONFIG_BUILD_KERNEL) && defined(CONFIG_ARCH_VMA_MAPPING)
 
@@ -65,7 +66,7 @@
 
 int up_shmat(uintptr_t *pages, unsigned int npages, uintptr_t vaddr)
 {
-  struct tcb_s *tcb = nxsched_self();
+  struct tcb_s *tcb = this_task();
   struct arch_addrenv_s *addrenv;
   uintptr_t *l1entry;
   uint32_t *l2table;
@@ -188,7 +189,7 @@ int up_shmat(uintptr_t *pages, unsigned int npages, uintptr_t vaddr)
 
 int up_shmdt(uintptr_t vaddr, unsigned int npages)
 {
-  struct tcb_s *tcb = nxsched_self();
+  struct tcb_s *tcb = this_task();
   struct arch_addrenv_s *addrenv;
   uintptr_t *l1entry;
   uint32_t *l2table;
