@@ -30,6 +30,8 @@
 #include <errno.h>
 
 #include <nuttx/arch.h>
+#include <nuttx/pci/pci.h>
+#include <nuttx/spinlock.h>
 #include <arch/irq.h>
 
 #include "arm_internal.h"
@@ -43,6 +45,53 @@
 
 #ifdef CONFIG_ARMV7A_HAVE_GICv2
 
+/****************************************************************************
+ * Private Data
+ ****************************************************************************/
+
+#if defined(CONFIG_SMP) && CONFIG_SMP_NCPUS > 1
+static volatile cpu_set_t g_gic_init_done;
+#endif
+
+/****************************************************************************
+ * Private Functions
+ ****************************************************************************/
+
+/****************************************************************************
+ * Name: arm_gic_init_done
+ *
+ * Description:
+ *   Indicates gic init done, and only cpu0 need wait the gic initialize
+ *   done. Because cpu1 ~ (CONFIG_SMP_NCPUS - 1) may not response the
+ *   interrupt request by cpu0 when the gic not initialize done.
+ *
+ ****************************************************************************/
+
+#if defined(CONFIG_SMP) && CONFIG_SMP_NCPUS > 1
+static void arm_gic_init_done(void)
+{
+  irqstate_t flags;
+
+  flags = spin_lock_irqsave(NULL);
+  CPU_SET(up_cpu_index(), &g_gic_init_done);
+  spin_unlock_irqrestore(NULL, flags);
+}
+
+static void arm_gic_wait_done(cpu_set_t cpuset)
+{
+  cpu_set_t tmpset;
+
+  do
+    {
+      CPU_AND(&tmpset, &g_gic_init_done, &cpuset);
+    }
+  while (!CPU_EQUAL(&tmpset, &cpuset));
+}
+#else
+#define arm_gic_init_done()
+#define arm_gic_wait_done(cpuset)
+#endif
+
 /****************************************************************************
  * Public Functions
  ****************************************************************************/
@@ -162,11 +211,16 @@ void arm_gic0_initialize(void)
       putreg32(0x01010101, GIC_ICDIPTR(irq));  /* SPI on CPU0 */
     }
 
+#ifdef CONFIG_ARMV7A_GICv2M
+  gic_v2m_initialize();
+#endif
+
 #ifdef CONFIG_SMP
   /* Attach SGI interrupt handlers. This attaches the handler to all CPUs. */
 
-  DEBUGVERIFY(irq_attach(GIC_IRQ_SGI1, arm_start_handler, NULL));
-  DEBUGVERIFY(irq_attach(GIC_IRQ_SGI2, arm_pause_handler, NULL));
+  DEBUGVERIFY(irq_attach(GIC_SMP_CPUSTART, arm_start_handler, NULL));
+  DEBUGVERIFY(irq_attach(GIC_SMP_SCHED, arm_smp_sched_handler, NULL));
+  DEBUGVERIFY(irq_attach(GIC_SMP_CALL, nxsched_smp_call_handler, NULL));
 #endif
 
   arm_gic_dump("Exit arm_gic0_initialize", true, 0);
@@ -293,9 +347,7 @@ void arm_gic_initialize(void)
 #  endif
 #endif
 
-#ifndef CONFIG_ARCH_TRUSTZONE_SECURE
   iccicr |= GIC_ICCICRS_ACKTCTL;
-#endif
 
 #ifdef CONFIG_ARCH_TRUSTZONE_NONSECURE
   /* Enable the Group 1 interrupts and disable Group 1 bypass. */
@@ -324,6 +376,7 @@ void arm_gic_initialize(void)
 
   putreg32(icddcr, GIC_ICDDCR);
   arm_gic_dump("Exit arm_gic_initialize", true, 0);
+  arm_gic_init_done();
 }
 
 /****************************************************************************
@@ -667,4 +720,60 @@ int arm_gic_irq_trigger(int irq, bool edge)
   return -EINVAL;
 }
 
+void arm_cpu_sgi(int sgi, unsigned int cpuset)
+{
+  uint32_t regval;
+
+  arm_gic_wait_done(cpuset);
+
+#ifdef CONFIG_SMP
+  regval = GIC_ICDSGIR_INTID(sgi) | GIC_ICDSGIR_CPUTARGET(cpuset) |
+           GIC_ICDSGIR_TGTFILTER_LIST;
+#else
+  regval = GIC_ICDSGIR_INTID(sgi) | GIC_ICDSGIR_CPUTARGET(0) |
+           GIC_ICDSGIR_TGTFILTER_THIS;
+#endif
+
+#if defined(CONFIG_ARCH_TRUSTZONE_SECURE)
+  if (sgi >= GIC_IRQ_SGI0 && sgi <= GIC_IRQ_SGI7)
+#endif
+    {
+      /* Set NSATT be 1: forward the SGI specified in the SGIINTID field to a
+       * specified CPU interfaces only if the SGI is configured as Group 1 on
+       * that interface.
+       * For non-secure context, the configuration of GIC_ICDSGIR_NSATT_GRP1
+       * is not mandatory in the GICv2 specification, but for SMP scenarios,
+       * this value needs to be configured, otherwise issues may occur in the
+       * SMP scenario.
+       */
+
+      regval |= GIC_ICDSGIR_NSATT_GRP1;
+    }
+
+  putreg32(regval, GIC_ICDSGIR);
+}
+
+/****************************************************************************
+ * Name: up_get_legacy_irq
+ *
+ * Description:
+ *   Reserve vector for legacy
+ *
+ ****************************************************************************/
+
+int up_get_legacy_irq(uint32_t devfn, uint8_t line, uint8_t pin)
+{
+#if CONFIG_ARMV7A_GICV2_LEGACY_IRQ0 >= 0
+  uint8_t slot;
+  uint8_t tmp;
+
+  UNUSED(line);
+  slot = PCI_SLOT(devfn);
+  tmp = (pin - 1 + slot) % 4;
+  return CONFIG_ARMV7A_GICV2_LEGACY_IRQ0 + tmp;
+#else
+  return -ENOTSUP;
+#endif
+}
+
 #endif /* CONFIG_ARMV7A_HAVE_GICv2 */
