@@ -43,7 +43,8 @@
 uint32_t *arm_undefinedinsn(uint32_t *regs)
 {
   _alert("Undefined instruction at 0x%" PRIx32 "\n", regs[REG_PC]);
-  CURRENT_REGS = regs;
+  up_set_current_regs(regs);
+
   PANIC_WITH_REGS("panic", regs);
   return regs; /* To keep the compiler happy */
 }
