@@ -49,16 +49,16 @@
 
 /* Configuration ************************************************************/
 
-#if defined(CONFIG_PAGING) || defined(CONFIG_ARCH_ADDRENV)
+#if defined(CONFIG_LEGACY_PAGING) || defined(CONFIG_ARCH_ADDRENV)
 
 /* Sanity check -- we cannot be using a ROM page table and supporting on-
  * demand paging.
  */
 
 #ifdef CONFIG_ARCH_ROMPGTABLE
-#  error "Cannot support both CONFIG_PAGING/CONFIG_ARCH_ADDRENV and CONFIG_ARCH_ROMPGTABLE"
+#  error "Cannot support both CONFIG_LEGACY_PAGING/CONFIG_ARCH_ADDRENV and CONFIG_ARCH_ROMPGTABLE"
 #endif
-#endif /* CONFIG_PAGING */
+#endif /* CONFIG_LEGACY_PAGING */
 
 /* MMU CP15 Register Bit Definitions ****************************************/
 
@@ -645,7 +645,10 @@
  * require up to 16Kb of memory.
  */
 
-#define PGTABLE_SIZE       0x00004000
+#ifndef PGTABLE_SIZE
+#  define PGTABLE_SIZE       0x00004000
+#endif
+
 #ifdef CONFIG_ARCH_ADDRENV
 #  define ALL_PGTABLE_SIZE (PGTABLE_SIZE * CONFIG_SMP_NCPUS)
 #else
@@ -654,7 +657,7 @@
 
 /* Virtual Page Table Location **********************************************/
 
-#ifdef CONFIG_PAGING
+#ifdef CONFIG_LEGACY_PAGING
 /* Check if the virtual address of the page table has been defined. It
  * should not be defined:  architecture specific logic should suppress
  * defining PGTABLE_BASE_VADDR unless:  (1) it is defined in the NuttX
@@ -894,7 +897,7 @@
 #define PG_POOL_PGPADDR(ndx)    (PG_PAGED_PBASE + ((ndx) << PAGESHIFT))
 #define PG_POOL_PGVADDR(ndx)    (PG_PAGED_VBASE + ((ndx) << PAGESHIFT))
 
-#endif /* CONFIG_PAGING */
+#endif /* CONFIG_LEGACY_PAGING */
 
 /****************************************************************************
  * Public Types
@@ -1053,8 +1056,8 @@ struct page_mapping_s
  *
  * Description:
  *   Write several, contiguous L2 page table entries.  npages entries will be
- *   written. This macro is used when CONFIG_PAGING is enable.  This case,
- *   it is used as follows:
+ *   written. This macro is used when CONFIG_LEGACY_PAGING is enable.
+ *   This case, it is used as follows:
  *
  *  ldr  r0, =PGTABLE_L2_BASE_PADDR  <-- Address in L2 table
  *  ldr  r1, =PG_LOCKED_PBASE        <-- Physical page memory address
@@ -1083,7 +1086,7 @@ struct page_mapping_s
  *
  ****************************************************************************/
 
-#ifdef CONFIG_PAGING
+#ifdef CONFIG_LEGACY_PAGING
   .macro  pg_l2map, l2, ppage, npages, mmuflags, tmp
   b    2f
 1:
@@ -1116,7 +1119,7 @@ struct page_mapping_s
   cmp  \npages, #0
   bgt  1b
   .endm
-#endif /* CONFIG_PAGING */
+#endif /* CONFIG_LEGACY_PAGING */
 
 /****************************************************************************
  * Name: pg_l1span
@@ -1124,7 +1127,7 @@ struct page_mapping_s
  * Description:
  *   Write several, contiguous, unmapped, small L1 page table entries.
  *   As many entries will be written as  many as needed to span npages.
- *   This macro is used when CONFIG_PAGING is enable.  In this case,
+ *   This macro is used when CONFIG_LEGACY_PAGING is enable.  In this case,
  *   it is used as follows:
  *
  *  ldr  r0, =PG_L1_PGTABLE_PADDR  <-- Address in the L1 table
@@ -1159,7 +1162,7 @@ struct page_mapping_s
  *
  ****************************************************************************/
 
-#ifdef CONFIG_PAGING
+#ifdef CONFIG_LEGACY_PAGING
   .macro  pg_l1span, l1, l2, npages, ppage, mmuflags, tmp
   b    2f
 1:
@@ -1197,7 +1200,7 @@ struct page_mapping_s
   bgt  1b
   .endm
 
-#endif /* CONFIG_PAGING */
+#endif /* CONFIG_LEGACY_PAGING */
 #endif /* __ASSEMBLY__ */
 
 /****************************************************************************
