@@ -34,8 +34,9 @@
  * Included Files
  ****************************************************************************/
 
+#include <arch/irq.h>
+
 #include "barriers.h"
-#include "cp15.h"
 
 /****************************************************************************
  * Pre-processor Definitions
@@ -62,20 +63,6 @@
  * Tightly CoupledMemory (TCM), so this register always Reads-As-Zero (RAZ).
  */
 
-/* Multiprocessor Affinity Register (MPIDR) */
-
-#define MPIDR_CPUID_SHIFT        (0)       /* Bits 0-1: CPU ID */
-#define MPIDR_CPUID_MASK         (3 << MPIDR_CPUID_SHIFT)
-#  define MPIDR_CPUID_CPU0       (0 << MPIDR_CPUID_SHIFT)
-#  define MPIDR_CPUID_CPU1       (1 << MPIDR_CPUID_SHIFT)
-#  define MPIDR_CPUID_CPU2       (2 << MPIDR_CPUID_SHIFT)
-#  define MPIDR_CPUID_CPU3       (3 << MPIDR_CPUID_SHIFT)
-                                           /* Bits 2-7: Reserved */
-#define MPIDR_CLUSTID_SHIFT      (8)       /* Bits 8-11: Cluster ID value */
-#define MPIDR_CLUSTID_MASK       (15 << MPIDR_CLUSTID_SHIFT)
-                                           /* Bits 12-29: Reserved */
-#define MPIDR_U                  (1 << 30) /* Bit 30: Multiprocessing Extensions. */
-
 /* Processor Feature Register 0 (ID_PFR0) */
 
 /* TODO: To be provided */
@@ -461,14 +448,6 @@ static inline unsigned int cp15_rdid(void)
   return CP15_GET(MIDR);
 }
 
-/* Get the Multiprocessor Affinity Register (MPIDR) */
-
-noinstrument_function
-static inline unsigned int cp15_rdmpidr(void)
-{
-  return CP15_GET(MPIDR);
-}
-
 /* Read/write the system control register (SCTLR) */
 
 static inline unsigned int cp15_rdsctlr(void)
