@@ -26,6 +26,7 @@
 
 #include <stdint.h>
 #include <assert.h>
+#include <debug.h>
 
 #include "mpu.h"
 #include "arm_internal.h"
@@ -68,9 +69,9 @@ static const uint8_t g_ls_regionmask[9] =
   0x00, 0x01, 0x03, 0x07, 0x0f, 0x1f, 0x3f, 0x7f, 0xff
 };
 
-/* The next available region number */
+/* The available region bitmap */
 
-static uint8_t g_region;
+static unsigned int g_mpu_region;
 
 /****************************************************************************
  * Private Functions
@@ -88,6 +89,13 @@ static uint8_t g_region;
  *   l2size has the same properties as the return value from
  *   mpu_log2regionceil()
  *
+ * Input Parameters:
+ *   size: The size of the region.
+ *   l2size: The L2 size of the region.
+ *
+ * Returned Value:
+ *   The sub-region bitmask.
+ *
  ****************************************************************************/
 
 static inline uint32_t mpu_subregion_ms(size_t size, uint8_t l2size)
@@ -139,6 +147,13 @@ static inline uint32_t mpu_subregion_ms(size_t size, uint8_t l2size)
  *   l2size has the same properties as the return value from
  *   mpu_log2regionceil()
  *
+ * Input Parameters:
+ *   offset: The offset of the region.
+ *   l2size: The L2 size of the region.
+ *
+ * Returned Value:
+ *   The sub-region bitmask.
+ *
  ****************************************************************************/
 
 static inline uint32_t mpu_subregion_ls(size_t offset, uint8_t l2size)
@@ -183,6 +198,12 @@ static inline uint32_t mpu_subregion_ls(size_t offset, uint8_t l2size)
  * Description:
  *   Resets the MPU to disabled.
  *
+ * * Input Parameters:
+ *   None.
+ *
+ * Returned Value:
+ *   None.
+ *
  ****************************************************************************/
 
 #if defined(CONFIG_ARM_MPU_RESET) || defined(CONFIG_ARM_MPU_EARLY_RESET)
@@ -214,17 +235,52 @@ static void mpu_reset_internal()
  * Description:
  *   Allocate the next region
  *
- * Assumptions:
- *   - Regions are never deallocated
- *   - Regions are only allocated early in initialization, so no special
- *     protection against re-entrancy is required;
+ * Input Parameters:
+ *   None
+ *
+ * Returned Value:
+ *   The index of the allocated region.
  *
  ****************************************************************************/
 
 unsigned int mpu_allocregion(void)
 {
-  DEBUGASSERT(g_region < CONFIG_ARM_MPU_NREGIONS);
-  return (unsigned int)g_region++;
+  unsigned int i = ffs(~g_mpu_region) - 1;
+
+  /* There are not enough regions to apply */
+
+  DEBUGASSERT(i < CONFIG_ARM_MPU_NREGIONS);
+  g_mpu_region |= 1 << i;
+  return i;
+}
+
+/****************************************************************************
+ * Name: mpu_freeregion
+ *
+ * Description:
+ *   Free target region.
+ *
+ * Input Parameters:
+ *  region - The index of the region to be freed.
+ *
+ * Returned Value:
+ *   None
+ *
+ ****************************************************************************/
+
+void mpu_freeregion(unsigned int region)
+{
+  DEBUGASSERT(region < CONFIG_ARM_MPU_NREGIONS);
+
+  /* Clear and disable the given MPU Region */
+
+  mpu_set_rgnr(region);
+  mpu_set_drbar(0);
+  mpu_set_dracr(0);
+  mpu_set_drsr(0);
+  g_mpu_region &= ~(1 << region);
+  ARM_DSB();
+  ARM_ISB();
 }
 
 /****************************************************************************
@@ -236,6 +292,12 @@ unsigned int mpu_allocregion(void)
  *
  *   size <= (1 << l2size)
  *
+ * Input Parameters:
+ *   size - The size of the region.
+ *
+ * Returned Value:
+ *   The logarithm base 2 of the ceiling value for the MPU region size.
+ *
  ****************************************************************************/
 
 uint8_t mpu_log2regionceil(size_t size)
@@ -257,6 +319,12 @@ uint8_t mpu_log2regionceil(size_t size)
  *
  *   size >= (1 << l2size)
  *
+ * Input Parameters:
+ *   size - The size of the region.
+ *
+ * Returned Value:
+ *   The logarithm base 2 of the floor value for the MPU region size.
+ *
  ****************************************************************************/
 
 uint8_t mpu_log2regionfloor(size_t size)
@@ -283,6 +351,14 @@ uint8_t mpu_log2regionfloor(size_t size)
  *   l2size has the same properties as the return value from
  *   mpu_log2regionceil()
  *
+ * Input Parameters:
+ *   base   - The base address of the region.
+ *   size   - The size of the region.
+ *   l2size - Log2 of the actual region size is <= (1 << l2size).
+ *
+ * Returned Value:
+ *   The subregion settings as a 32-bit value.
+ *
  ****************************************************************************/
 
 uint32_t mpu_subregion(uintptr_t base, size_t size, uint8_t l2size)
@@ -328,6 +404,157 @@ uint32_t mpu_subregion(uintptr_t base, size_t size, uint8_t l2size)
   return ret;
 }
 
+/****************************************************************************
+ * Name: mpu_modify_region
+ *
+ * Description:
+ *   Modify a region for privileged, strongly ordered memory
+ *
+ * Input Parameters:
+ *   region - Region number to modify.
+ *   base   - Base address of the region.
+ *   size   - Size of the region.
+ *   flags  - Flags to configure the region.
+ *
+ * Returned Value:
+ *   None.
+ *
+ ****************************************************************************/
+
+void mpu_modify_region(unsigned int region, uintptr_t base, size_t size,
+                       uint32_t flags)
+{
+  uint32_t regval;
+  uint8_t l2size;
+  uint8_t subregions;
+
+  /* Check that the region is valid */
+
+  DEBUGASSERT(g_mpu_region & (1 << region));
+
+  /* Select the region */
+
+  mpu_set_rgnr(region);
+
+  /* Select the region base address */
+
+  mpu_set_drbar(base & MPU_RBAR_ADDR_MASK);
+
+  /* Select the region size and the sub-region map */
+
+  l2size = mpu_log2regionceil(size);
+  subregions = mpu_subregion(base, size, l2size);
+
+  /* Configure the Region */
+
+  mpu_set_dracr(flags);
+  regval = MPU_RASR_ENABLE                              | /* Enable region */
+           MPU_RASR_RSIZE_LOG2(l2size)                  | /* Region size   */
+           (subregions << MPU_RASR_SRD_SHIFT);            /* Sub-regions   */
+  mpu_set_drsr(regval);
+}
+
+/****************************************************************************
+ * Name: mpu_configure_region
+ *
+ * Description:
+ *   Configure a region.
+ *
+ * Input Parameters:
+ *   base - Base address of the region.
+ *   size - Size of the region.
+ *   flags - Flags to configure the region.
+ *
+ * Returned Value:
+ *   The region number allocated for the configured region.
+ *
+ ****************************************************************************/
+
+unsigned int mpu_configure_region(uintptr_t base, size_t size,
+                                  uint32_t flags)
+{
+  unsigned int region = mpu_allocregion();
+  mpu_modify_region(region, base, size, flags);
+  return region;
+}
+
+/****************************************************************************
+ * Name: mpu_initialize
+ *
+ * Description:
+ *   Configure a region for privileged, strongly ordered memory
+ *
+ * Input Parameters:
+ *   table - MPU Initiaze table.
+ *   count - Initialize the number of entries in the region table.
+ *
+ * Returned Value:
+ *   NULL.
+ *
+ ****************************************************************************/
+
+void mpu_initialize(const struct mpu_region_s *table, size_t count)
+{
+  const struct mpu_region_s *conf;
+  size_t index;
+
+  mpu_control(false);
+  for (index = 0; index < count; index++)
+    {
+      conf = &table[index];
+      mpu_configure_region(conf->base, conf->size, conf->flags);
+    }
+
+  mpu_control(true);
+}
+
+/****************************************************************************
+ * Name: mpu_dump_region
+ *
+ * Description:
+ *   Dump the region that has been used.
+ *
+ * Input Parameters:
+ *   None.
+ *
+ * Returned Value:
+ *   None.
+ *
+ ****************************************************************************/
+
+void mpu_dump_region(void)
+{
+  int i;
+  int count = 0;
+  uint32_t dracr;
+  uint32_t drbar;
+  uint32_t drsr;
+  uint32_t sctrl;
+
+  /* Get free region */
+
+  sctrl = cp15_rdsctlr();
+  _info("MPU-SCTRL Enable:%" PRIu32 "\n", sctrl & SCTLR_M);
+  for (i = 0; i < CONFIG_ARM_MPU_NREGIONS; i++)
+    {
+      mpu_set_rgnr(i);
+      drbar = mpu_get_drbar();
+      dracr = mpu_get_dracr();
+      drsr = mpu_get_drsr();
+      _info("MPU-%d, base=0%08X l2size=%"PRIu32" bufferable=%u"
+            "cacheable=%u shareable=%u\n", i, drbar & MPU_RBAR_ADDR_MASK,
+            drsr & MPU_RASR_RSIZE_MASK, dracr & MPU_RACR_B,
+            dracr & MPU_RACR_C, dracr & MPU_RACR_S);
+      if (drsr & MPU_RASR_ENABLE)
+        {
+          count++;
+        }
+    }
+
+  _info("Total Use Region:%d, Remaining Available:%d\n", count,
+        CONFIG_ARM_MPU_NREGIONS - count);
+}
+
 /****************************************************************************
  * Name: mpu_reset
  *
@@ -335,6 +562,12 @@ uint32_t mpu_subregion(uintptr_t base, size_t size, uint8_t l2size)
  *   Conditional public interface that resets the MPU to disabled during
  *   MPU initialization.
  *
+ * Input Parameters:
+ *   None.
+ *
+ * Returned Value:
+ *   None.
+ *
  ****************************************************************************/
 #if defined(CONFIG_ARM_MPU_RESET)
 void mpu_reset()
@@ -350,6 +583,12 @@ void mpu_reset()
  *   Conditional public interface that resets the MPU to disabled immediately
  *   after reset.
  *
+ * Input Parameters:
+ *   None.
+ *
+ * Returned Value:
+ *   None.
+ *
  ****************************************************************************/
 #if defined(CONFIG_ARM_MPU_EARLY_RESET)
 void mpu_early_reset()
