@@ -156,20 +156,25 @@ static void dispatch_syscall(void)
 
 uint32_t *arm_syscall(uint32_t *regs)
 {
+  struct tcb_s *tcb = this_task();
+
   uint32_t cmd;
+  int cpu;
 #ifdef CONFIG_BUILD_PROTECTED
   uint32_t cpsr;
 #endif
 
   /* Nested interrupts are not supported */
 
-  DEBUGASSERT(CURRENT_REGS == NULL);
+  DEBUGASSERT(up_current_regs() == NULL);
+
+  tcb->xcp.regs = regs;
 
   /* Current regs non-zero indicates that we are processing an interrupt;
-   * CURRENT_REGS is also used to manage interrupt level context switches.
+   * current_regs is also used to manage interrupt level context switches.
    */
 
-  CURRENT_REGS = regs;
+  up_set_current_regs(regs);
 
   /* The SYSCALL command is in R0 on entry.  Parameters follow in R1..R7 */
 
@@ -200,7 +205,7 @@ uint32_t *arm_syscall(uint32_t *regs)
 #ifdef CONFIG_LIB_SYSCALL
       case SYS_syscall_return:
         {
-          struct tcb_s *rtcb = nxsched_self();
+          struct tcb_s *rtcb = this_task();
           int index = (int)rtcb->xcp.nsyscalls - 1;
 
           /* Make sure that there is a saved SYSCALL return address. */
@@ -266,8 +271,8 @@ uint32_t *arm_syscall(uint32_t *regs)
            * set will determine the restored context.
            */
 
-          CURRENT_REGS = (uint32_t *)regs[REG_R1];
-          DEBUGASSERT(CURRENT_REGS);
+          tcb->xcp.regs = (uint32_t *)regs[REG_R1];
+          DEBUGASSERT(up_current_regs());
         }
         break;
 
@@ -292,7 +297,7 @@ uint32_t *arm_syscall(uint32_t *regs)
         {
           DEBUGASSERT(regs[REG_R1] != 0 && regs[REG_R2] != 0);
           *(uint32_t **)regs[REG_R1] = regs;
-          CURRENT_REGS = (uint32_t *)regs[REG_R2];
+          tcb->xcp.regs = (uint32_t *)regs[REG_R2];
         }
         break;
 
@@ -382,7 +387,7 @@ uint32_t *arm_syscall(uint32_t *regs)
 
       case SYS_signal_handler:
         {
-          struct tcb_s *rtcb = nxsched_self();
+          struct tcb_s *rtcb = this_task();
 
           /* Remember the caller's return address */
 
@@ -422,7 +427,7 @@ uint32_t *arm_syscall(uint32_t *regs)
 
               /* Copy "info" into user stack */
 
-              if (rtcb->xcp.sigdeliver)
+              if (rtcb->sigdeliver)
                 {
                   usp = rtcb->xcp.saved_regs[REG_SP];
                 }
@@ -459,7 +464,7 @@ uint32_t *arm_syscall(uint32_t *regs)
 
       case SYS_signal_handler_return:
         {
-          struct tcb_s *rtcb = nxsched_self();
+          struct tcb_s *rtcb = this_task();
 
           /* Set up to return to the kernel-mode signal dispatching logic. */
 
@@ -496,7 +501,7 @@ uint32_t *arm_syscall(uint32_t *regs)
       default:
         {
 #ifdef CONFIG_LIB_SYSCALL
-          struct tcb_s *rtcb = nxsched_self();
+          struct tcb_s *rtcb = this_task();
           int index = rtcb->xcp.nsyscalls;
 
           /* Verify that the SYS call number is within range */
@@ -559,29 +564,36 @@ uint32_t *arm_syscall(uint32_t *regs)
         break;
     }
 
-  /* Restore the cpu lock */
-
-  if (regs != CURRENT_REGS)
+  if (regs != tcb->xcp.regs)
     {
+      cpu = this_cpu();
+
+      /* Update scheduler parameters */
+
+      nxsched_suspend_scheduler(g_running_tasks[cpu]);
+      nxsched_resume_scheduler(tcb);
+
       /* Record the new "running" task.  g_running_tasks[] is only used by
        * assertion logic for reporting crashes.
        */
 
-      g_running_tasks[this_cpu()] = this_task();
+      g_running_tasks[cpu] = tcb;
 
-      restore_critical_section();
-      regs = (uint32_t *)CURRENT_REGS;
+      /* Restore the cpu lock */
+
+      restore_critical_section(tcb, cpu);
+      regs = tcb->xcp.regs;
     }
 
   /* Report what happened */
 
   dump_syscall("Exit", cmd, regs);
 
-  /* Set CURRENT_REGS to NULL to indicate that we are no longer in an
+  /* Set current_regs to NULL to indicate that we are no longer in an
    * interrupt handler.
    */
 
-  CURRENT_REGS = NULL;
+  up_set_current_regs(NULL);
 
   /* Return the last value of curent_regs.  This supports context switches
    * on return from the exception.  That capability is only used with the
