@@ -53,11 +53,11 @@
 
 uint32_t *arm_dataabort(uint32_t *regs, uint32_t dfar, uint32_t dfsr)
 {
-  /* Save the saved processor context in CURRENT_REGS where it can be
+  /* Save the saved processor context in current_regs where it can be
    * accessed for register dumps and possibly context switching.
    */
 
-  CURRENT_REGS = regs;
+  up_set_current_regs(regs);
 
   /* Crash -- possibly showing diagnostic debug information. */
 
