@@ -52,7 +52,8 @@ static const uint16_t g_reg_offs[] =
   TCB_REG_OFF(REG_R15),
   TCB_REG_OFF(REG_CPSR),
 
-#ifdef CONFIG_ARCH_FPU
+#if 0
+#  ifdef CONFIG_ARCH_FPU
   TCB_REG_OFF(REG_D0),
   TCB_REG_OFF(REG_D1),
   TCB_REG_OFF(REG_D2),
@@ -69,9 +70,9 @@ static const uint16_t g_reg_offs[] =
   TCB_REG_OFF(REG_D13),
   TCB_REG_OFF(REG_D14),
   TCB_REG_OFF(REG_D15),
-#endif
+#  endif
 
-#ifdef CONFIG_ARM_DPFPU32
+#  ifdef CONFIG_ARM_DPFPU32
   TCB_REG_OFF(REG_D16),
   TCB_REG_OFF(REG_D17),
   TCB_REG_OFF(REG_D18),
@@ -88,10 +89,11 @@ static const uint16_t g_reg_offs[] =
   TCB_REG_OFF(REG_D29),
   TCB_REG_OFF(REG_D30),
   TCB_REG_OFF(REG_D31),
-#endif
+#  endif
 
-#ifdef CONFIG_ARCH_FPU
+#  ifdef CONFIG_ARCH_FPU
   TCB_REG_OFF(REG_FPSCR),
+#  endif
 #endif
 };
 
@@ -106,8 +108,7 @@ const struct tcbinfo_s g_tcbinfo =
   .pri_off   = TCB_PRI_OFF,
   .name_off  = TCB_NAME_OFF,
   .regs_off  = TCB_REGS_OFF,
-  .basic_num = 17,
-  .total_num = nitems(g_reg_offs),
+  .regs_num  = nitems(g_reg_offs),
   {
     .p = g_reg_offs,
   },
