@@ -61,6 +61,10 @@ struct unwind_frame_s
 
   unsigned long *lr_addr;
 
+  /* Lowest value of sp allowed */
+
+  unsigned long stack_base;
+
   /* Highest value of sp allowed */
 
   unsigned long stack_top;
@@ -588,7 +592,7 @@ int unwind_frame(struct unwind_frame_s *frame)
           return urc;
         }
 
-      if (ctrl.vrs[SP] < frame->sp ||
+      if (ctrl.vrs[SP] < frame->stack_base ||
           ctrl.vrs[SP] > ctrl.stack_top)
         {
           return -1;
@@ -698,6 +702,14 @@ again:
  * Returned Value:
  *   up_backtrace() returns the number of addresses returned in buffer
  *
+ * Assumptions:
+ *   Have to make sure tcb keep safe during function executing, it means
+ *   1. Tcb have to be self or not-running.  In SMP case, the running task
+ *      PC & SP cannot be backtrace, as whose get from tcb is not the newest.
+ *   2. Tcb have to keep not be freed.  In task exiting case, have to
+ *      make sure the tcb get from pid and up_backtrace in one critical
+ *      section procedure.
+ *
  ****************************************************************************/
 
 int up_backtrace(struct tcb_s *tcb,
@@ -705,7 +717,6 @@ int up_backtrace(struct tcb_s *tcb,
 {
   struct tcb_s *rtcb = running_task();
   struct unwind_frame_s frame;
-  irqstate_t flags;
   int ret;
 
   if (size <= 0 || !buffer)
@@ -719,24 +730,25 @@ int up_backtrace(struct tcb_s *tcb,
       frame.lr = (unsigned long)__builtin_return_address(0);
       frame.pc = (unsigned long)&up_backtrace;
       frame.sp = frame.fp;
-      frame.stack_top = (unsigned long)rtcb->stack_base_ptr +
-                                       rtcb->adj_stack_size;
+      frame.stack_base = (unsigned long)rtcb->stack_base_ptr;
+      frame.stack_top = frame.stack_base + rtcb->adj_stack_size;
+
       if (up_interrupt_context())
         {
 #if CONFIG_ARCH_INTERRUPTSTACK > 7
-          frame.stack_top = up_get_intstackbase(up_cpu_index()) +
-                            INTSTACK_SIZE;
+          frame.stack_base = up_get_intstackbase(this_cpu());
+          frame.stack_top = frame.stack_base + INTSTACK_SIZE;
 #endif /* CONFIG_ARCH_INTERRUPTSTACK > 7 */
 
           ret = backtrace_unwind(&frame, buffer, size, &skip);
           if (ret < size)
             {
-              frame.fp = CURRENT_REGS[REG_FP];
-              frame.sp = CURRENT_REGS[REG_SP];
-              frame.pc = CURRENT_REGS[REG_PC];
-              frame.lr = CURRENT_REGS[REG_LR];
-              frame.stack_top = (unsigned long)rtcb->stack_base_ptr +
-                                               rtcb->adj_stack_size;
+              frame.fp = up_current_regs()[REG_FP];
+              frame.sp = up_current_regs()[REG_SP];
+              frame.pc = up_current_regs()[REG_PC];
+              frame.lr = up_current_regs()[REG_LR];
+              frame.stack_base = (unsigned long)rtcb->stack_base_ptr;
+              frame.stack_top = frame.stack_base + rtcb->adj_stack_size;
               ret += backtrace_unwind(&frame, &buffer[ret],
                                       size - ret, &skip);
             }
@@ -748,18 +760,14 @@ int up_backtrace(struct tcb_s *tcb,
     }
   else
     {
-      flags = enter_critical_section();
-
       frame.fp = tcb->xcp.regs[REG_FP];
       frame.sp = tcb->xcp.regs[REG_SP];
       frame.lr = tcb->xcp.regs[REG_LR];
       frame.pc = tcb->xcp.regs[REG_PC];
-      frame.stack_top = (unsigned long)tcb->stack_base_ptr +
-                                       tcb->adj_stack_size;
+      frame.stack_base = (unsigned long)tcb->stack_base_ptr;
+      frame.stack_top = frame.stack_base + tcb->adj_stack_size;
 
       ret = backtrace_unwind(&frame, buffer, size, &skip);
-
-      leave_critical_section(flags);
     }
 
   return ret;
