@@ -224,9 +224,9 @@ size_t up_check_tcbstack(struct tcb_s *tcb)
 }
 
 #if CONFIG_ARCH_INTERRUPTSTACK > 3
-size_t up_check_intstack(void)
+size_t up_check_intstack(int cpu)
 {
-  return arm_stack_check((void *)up_get_intstackbase(),
+  return arm_stack_check((void *)up_get_intstackbase(cpu),
                          STACK_ALIGN_DOWN(CONFIG_ARCH_INTERRUPTSTACK));
 }
 #endif
