@@ -34,6 +34,7 @@
 
 #include "chip.h"
 #include "arm_internal.h"
+#include "sched/sched.h"
 
 /****************************************************************************
  * Public Functions
@@ -41,8 +42,10 @@
 
 uint32_t *arm_decodeirq(uint32_t *regs)
 {
+  struct tcb_s *tcb = this_task();
+
 #ifdef CONFIG_SUPPRESS_INTERRUPTS
-  CURRENT_REGS = regs;
+  up_set_current_regs(regs);
   err("ERROR: Unexpected IRQ\n");
   PANIC();
   return NULL;
@@ -71,28 +74,30 @@ uint32_t *arm_decodeirq(uint32_t *regs)
 
           /* Current regs non-zero indicates that we are processing an
            * interrupt;
-           * CURRENT_REGS is also used to manage interrupt level context
+           * current_regs is also used to manage interrupt level context
            * switches.
            *
            * Nested interrupts are not supported.
            */
 
-          DEBUGASSERT(CURRENT_REGS == NULL);
-          CURRENT_REGS = regs;
+          DEBUGASSERT(up_current_regs() == NULL);
+          tcb->xcp.regs = regs;
+          up_set_current_regs(regs);
 
           /* Deliver the IRQ */
 
           irq_dispatch(irq, regs);
+          tcb = this_task();
 
 #ifdef CONFIG_ARCH_ADDRENV
           /* Check for a context switch.  If a context switch occurred, then
-           * CURRENT_REGS will have a different value than it did on entry.
+           * current_regs will have a different value than it did on entry.
            * If an interrupt level context switch has occurred, then
            * establish the correct address environment before returning
            * from the interrupt.
            */
 
-          if (regs != CURRENT_REGS)
+          if (regs != tcb->xcp.regs)
             {
               /* Make sure that the address environment for the previously
                * running task is closed down gracefully (data caches dump,
@@ -104,11 +109,11 @@ uint32_t *arm_decodeirq(uint32_t *regs)
             }
 #endif
 
-          /* Set CURRENT_REGS to NULL to indicate that we are no longer in
+          /* Set current_regs to NULL to indicate that we are no longer in
            * an interrupt handler.
            */
 
-          CURRENT_REGS = NULL;
+          up_set_current_regs(NULL);
         }
     }
 #endif
