@@ -28,12 +28,12 @@
 #include <assert.h>
 #include <debug.h>
 
+#include <arch/irq.h>
 #include <arch/chip/chip.h>
 
 #include "arm_internal.h"
 
 #include "barriers.h"
-#include "cp15.h"
 #include "arm_gic.h"
 #include "chip.h"
 #include "fvp_boot.h"
