@@ -29,7 +29,7 @@
 #include "arm.h"
 #include "arm_internal.h"
 
-#ifdef CONFIG_PAGING
+#ifdef CONFIG_LEGACY_PAGING
 #  include <nuttx/page.h>
 #  include "pg_macros.h"
 #endif
@@ -71,7 +71,7 @@ static const struct section_mapping_s g_section_mapping[] =
 {
   { LPC31_SHADOWSPACE_PSECTION, LPC31_SHADOWSPACE_VSECTION,
     LPC31_SHADOWSPACE_MMUFLAGS, LPC31_SHADOWSPACE_NSECTIONS},
-#ifndef CONFIG_PAGING /* SRAM is already fully mapped */
+#ifndef CONFIG_LEGACY_PAGING /* SRAM is already fully mapped */
   { LPC31_INTSRAM_PSECTION, LPC31_INTSRAM_VSECTION,
     LPC31_INTSRAM_MMUFLAGS, LPC31_INTSRAM_NSECTIONS},
 #endif
@@ -188,7 +188,7 @@ static void up_setupmappings(void)
  *
  ****************************************************************************/
 
-#if !defined(CONFIG_ARCH_ROMPGTABLE) && defined(CONFIG_ARCH_LOWVECTORS) && defined(CONFIG_PAGING)
+#if !defined(CONFIG_ARCH_ROMPGTABLE) && defined(CONFIG_ARCH_LOWVECTORS) && defined(CONFIG_LEGACY_PAGING)
 static void  up_vectorpermissions(uint32_t mmuflags)
 {
   /* The PTE for the beginning of ISRAM is at the base of the L2 page table */
@@ -281,7 +281,7 @@ static void up_copyvectorblock(void)
    */
 
 #if !defined(CONFIG_ARCH_ROMPGTABLE) && defined(CONFIG_ARCH_LOWVECTORS) && \
-     defined(CONFIG_PAGING)
+     defined(CONFIG_LEGACY_PAGING)
   up_vectorpermissions(MMU_L2_VECTRWFLAGS);
 #endif
 
@@ -306,7 +306,7 @@ static void up_copyvectorblock(void)
 
   /* Make the vectors read-only, cacheable again */
 
-#if !defined(CONFIG_ARCH_ROMPGTABLE) && defined(CONFIG_ARCH_LOWVECTORS) && defined(CONFIG_PAGING)
+#if !defined(CONFIG_ARCH_ROMPGTABLE) && defined(CONFIG_ARCH_LOWVECTORS) && defined(CONFIG_LEGACY_PAGING)
   up_vectorpermissions(MMU_L2_VECTROFLAGS);
 #endif
 
