@@ -59,8 +59,9 @@
 
 struct nrf53_gpiote_callback_s
 {
-  xcpt_t callback;
-  void  *arg;
+  xcpt_t    callback;
+  void     *arg;
+  uint32_t  pinset;
 };
 
 /****************************************************************************
@@ -501,13 +502,14 @@ int nrf53_gpiote_set_event(uint32_t pinset,
 
   flags = enter_critical_section();
 
-  /* Get free channel */
+  /* Get free channel or channel already used by pinset */
 
   for (i = 0; i < GPIOTE_CHANNELS; i++)
     {
-      if (g_gpiote_ch_callbacks[i].callback == NULL)
+      if (g_gpiote_ch_callbacks[i].callback == NULL ||
+          g_gpiote_ch_callbacks[i].pinset == pinset)
         {
-          /* Configure channel */
+          g_gpiote_ch_callbacks[i].pinset = pinset;
 
           nrf53_gpiote_set_ch_event(pinset, i,
                                     risingedge, fallingedge,
