@@ -224,7 +224,7 @@ void __start(void)
 
   showprogress('C');
 
-#ifdef CONFIG_ARCH_HAVE_FPU
+#ifdef CONFIG_ARCH_FPU
   /* Initialize the FPU (if available) */
 
   arm_fpuconfig();
