@@ -34,6 +34,7 @@
 #include <debug.h>
 
 #include <arch/board/board.h>
+#include <arch/chip/sam_afec.h>
 #include <nuttx/irq.h>
 #include <nuttx/arch.h>
 #include <nuttx/wqueue.h>
@@ -826,6 +827,7 @@ static void afec_reset(struct adc_dev_s *dev)
 
   gpio_pinset_t pinset = 0;
   uint32_t afec_cher = 0;
+  uint32_t afec_cgr = 0;
   for (int i = 0; i < priv->nchannels; i++)
     {
       DEBUGASSERT(priv->chanlist[i] < ADC_MAX_CHANNELS);
@@ -837,11 +839,13 @@ static void afec_reset(struct adc_dev_s *dev)
       afec_putreg(priv, SAM_AFEC_COCR_OFFSET, 0x200);
 
       afec_cher |= AFEC_CH(priv->chanlist[i]);
+      afec_cgr |= AFEC_CGR_GAIN(priv->chanlist[i], 0);
     }
 
   /* Enable channels */
 
   afec_putreg(priv, SAM_AFEC_CHER_OFFSET, afec_cher);
+  afec_putreg(priv, SAM_AFEC_CGR_OFFSET, afec_cgr);
 
   return;
 
@@ -1021,20 +1025,55 @@ static int afec_ioctl(struct adc_dev_s *dev, int cmd, unsigned long arg)
         }
         break;
 #endif
-      case ANIOC_GET_NCHANNELS:
-        {
-          /* Return the number of configured channels */
+    case ANIOC_GET_NCHANNELS:
+      {
+        /* Return the number of configured channels */
 
-          ret = priv->nchannels;
-        }
-        break;
+        ret = priv->nchannels;
+      }
+      break;
+    case ANIOC_SAMV7_AFEC_IOCTRL_GAIN:
+      {
+        /* Set the requested gain of the associated channel */
 
-      default:
-        {
-          aerr("ERROR: Unknown cmd: %d\n", cmd);
-          ret = -ENOTTY;
-        }
-        break;
+        sam_afec_gain_param_tds *chgain = (sam_afec_gain_param_tds *) arg;
+
+        uint32_t afec_cgr = afec_getreg(priv, SAM_AFEC_CGR_OFFSET);
+        afec_cgr &= ~AFEC_CGR_GAIN_MASK(chgain->channel);
+        afec_cgr |= AFEC_CGR_GAIN(chgain->channel, chgain->gain);
+        afec_putreg(priv, SAM_AFEC_CGR_OFFSET, afec_cgr);
+
+        /* new gain is set, now adjust the offset register, use gain
+         * 1 as default and fallback
+         */
+
+        uint16_t offset;
+        if (chgain->gain == 1)
+          {
+            offset = 0x100;
+          }
+        else if (chgain->gain == 2)
+          {
+            offset = 0x40;
+          }
+        else
+          {
+            offset = 0x200;
+          }
+
+        afec_putreg(priv, SAM_AFEC_CSELR_OFFSET,
+                    AFEC_CSELR_CSEL(chgain->channel));
+
+        afec_putreg(priv, SAM_AFEC_COCR_OFFSET, offset);
+      }
+      break;
+
+    default:
+      {
+        aerr("ERROR: Unknown cmd: %d\n", cmd);
+        ret = -ENOTTY;
+      }
+      break;
     }
 
   return ret;
