@@ -867,7 +867,7 @@
 #  define ATIM_BDTR_LOCKOFF       (0 << ATIM_BDTR_LOCK_SHIFT)    /* 00: LOCK OFF - No bit is write protected */
 #  define ATIM_BDTR_LOCK1         (1 << ATIM_BDTR_LOCK_SHIFT)    /* 01: LOCK Level 1 protection */
 #  define ATIM_BDTR_LOCK2         (2 << ATIM_BDTR_LOCK_SHIFT)    /* 10: LOCK Level 2 protection */
-#  define ATIM_BDTR_LOCK3         (3 << ATIM_BDTR_LOCK_SHIFT)    /* 11: LOCK Level 3 protection */ */
+#  define ATIM_BDTR_LOCK3         (3 << ATIM_BDTR_LOCK_SHIFT)    /* 11: LOCK Level 3 protection */
 #define ATIM_BDTR_OSSI            (1 << 10)                      /* Bit 10: Off-State Selection for Idle mode */
 #define ATIM_BDTR_OSSR            (1 << 11)                      /* Bit 11: Off-State Selection for Run mode */
 #define ATIM_BDTR_BKE             (1 << 12)                      /* Bit 12: Break enable */
