@@ -38,10 +38,8 @@
 #include <nuttx/arch.h>
 
 #include <nuttx/wqueue.h>
-#include <nuttx/can.h>
 #include <nuttx/net/netdev.h>
 #include <nuttx/net/can.h>
-#include <netpacket/can.h>
 
 #include "arm_internal.h"
 #include "stm32_fdcan.h"
@@ -1751,7 +1749,7 @@ static int fdcan_send(struct stm32_fdcan_s *priv)
 
       /* Set DLC */
 
-      txbuffer[1] |= BUFFER_R1_DLC(len_to_can_dlc[frame->len]);
+      txbuffer[1] |= BUFFER_R1_DLC(g_len_to_can_dlc[frame->len]);
 
       /* Set flags */
 
@@ -2469,8 +2467,8 @@ static void fdcan_receive(struct stm32_fdcan_s *priv,
 
       /* Word R1 contains the DLC and timestamp */
 
-      frame->len = can_dlc_to_len[((rxbuffer[1] & BUFFER_R1_DLC_MASK) >>
-                                   BUFFER_R1_DLC_SHIFT)];
+      frame->len = g_can_dlc_to_len[((rxbuffer[1] & BUFFER_R1_DLC_MASK) >>
+                                    BUFFER_R1_DLC_SHIFT)];
 
       /* Get CANFD flags */
 
