@@ -143,12 +143,6 @@ static const struct rtc_ops_s g_rtc_ops =
   .setperiodic    = stm32_setperiodic,
   .cancelperiodic = stm32_cancelperiodic,
 #endif
-#ifdef CONFIG_RTC_IOCTL
-  .ioctl       = NULL,
-#endif
-#ifndef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
-  .destroy     = NULL,
-#endif
 };
 
 /* STM32 RTC device state */
