@@ -31,7 +31,7 @@
 
 #include <nuttx/arch.h>
 #include <nuttx/irq.h>
-#include <nuttx/time.h>
+#include <nuttx/clock.h>
 #include <arch/board/board.h>
 
 #include "arm_internal.h"
