@@ -409,16 +409,24 @@
 #define GPIO_ECAT_P0_TXD3_2         (GPIO_ECAT_CONF_OUTPUT | GPIO_PADA2_STRONGSHARP | GPIO_PORT1 | GPIO_PIN2 | GPIO_OUTPUT_ALT1)
 #define GPIO_ECAT_P0_TX_EN_1        (GPIO_ECAT_CONF_OUTPUT | GPIO_PADA2_STRONGSHARP | GPIO_PORT6 | GPIO_PIN1 | GPIO_OUTPUT_ALT4)
 #define GPIO_ECAT_P0_TX_EN_2        (GPIO_ECAT_CONF_OUTPUT | GPIO_PADA2_STRONGSHARP | GPIO_PORT1 | GPIO_PIN3 | GPIO_OUTPUT_ALT1)
-#define GPIO_ECAT_P1_LED_LINK_ACT   (GPIO_ECAT_CONF_OUTPUT | GPIO_PADA2_STRONGSOFT | GPIO_PORT3 | GPIO_PIN12  | GPIO_OUTPUT_ALT1)
+#define GPIO_ECAT_P1_LED_LINK_ACT_1 (GPIO_ECAT_CONF_OUTPUT | GPIO_PADA2_STRONGSOFT | GPIO_PORT3 | GPIO_PIN12  | GPIO_OUTPUT_ALT1)
+#define GPIO_ECAT_P1_LED_LINK_ACT_2 (GPIO_ECAT_CONF_OUTPUT | GPIO_PADA2_STRONGSOFT | GPIO_PORT0 | GPIO_PIN11  | GPIO_OUTPUT_ALT1)
 #define GPIO_ECAT_P1_LINK_STATUS_1  (GPIO_INPUT | GPIO_PORT3 | GPIO_PIN4)
 #define GPIO_ECAT_P1_LINK_STATUS_2  (GPIO_INPUT_PULLUP | GPIO_PORT15 | GPIO_PIN3)
-#define GPIO_ECAT_P1_RXD0           (GPIO_INPUT | GPIO_PORT0  | GPIO_PIN11)
-#define GPIO_ECAT_P1_RXD1           (GPIO_INPUT | GPIO_PORT0  | GPIO_PIN6)
-#define GPIO_ECAT_P1_RXD2           (GPIO_INPUT | GPIO_PORT0  | GPIO_PIN5)
-#define GPIO_ECAT_P1_RXD3           (GPIO_INPUT | GPIO_PORT0  | GPIO_PIN4)
-#define GPIO_ECAT_P1_RX_CLK         (GPIO_INPUT | GPIO_PORT0  | GPIO_PIN1)
-#define GPIO_ECAT_P1_RX_DV          (GPIO_INPUT | GPIO_PORT0  | GPIO_PIN9)
-#define GPIO_ECAT_P1_RX_ERR         (GPIO_INPUT | GPIO_PORT15 | GPIO_PIN2)
+#define GPIO_ECAT_P1_RXD0_1         (GPIO_INPUT | GPIO_PORT0  | GPIO_PIN11)
+#define GPIO_ECAT_P1_RXD0_2         (GPIO_INPUT | GPIO_PORT14 | GPIO_PIN7)
+#define GPIO_ECAT_P1_RXD1_1         (GPIO_INPUT | GPIO_PORT0  | GPIO_PIN6)
+#define GPIO_ECAT_P1_RXD1_2         (GPIO_INPUT | GPIO_PORT14 | GPIO_PIN12)
+#define GPIO_ECAT_P1_RXD2_1         (GPIO_INPUT | GPIO_PORT0  | GPIO_PIN5)
+#define GPIO_ECAT_P1_RXD2_2         (GPIO_INPUT | GPIO_PORT14 | GPIO_PIN13)
+#define GPIO_ECAT_P1_RXD3_1         (GPIO_INPUT | GPIO_PORT0  | GPIO_PIN4)
+#define GPIO_ECAT_P1_RXD3_2         (GPIO_INPUT | GPIO_PORT14 | GPIO_PIN14)
+#define GPIO_ECAT_P1_RX_CLK_1       (GPIO_INPUT | GPIO_PORT0  | GPIO_PIN1)
+#define GPIO_ECAT_P1_RX_CLK_2       (GPIO_INPUT | GPIO_PORT14 | GPIO_PIN6)
+#define GPIO_ECAT_P1_RX_DV_1        (GPIO_INPUT | GPIO_PORT0  | GPIO_PIN9)
+#define GPIO_ECAT_P1_RX_DV_2        (GPIO_INPUT | GPIO_PORT14 | GPIO_PIN15)
+#define GPIO_ECAT_P1_RX_ERR_1       (GPIO_INPUT | GPIO_PORT15 | GPIO_PIN2)
+#define GPIO_ECAT_P1_RX_ERR_2       (GPIO_INPUT | GPIO_PORT3  | GPIO_PIN5)
 #define GPIO_ECAT_P1_TX_CLK         (GPIO_INPUT | GPIO_PORT0  | GPIO_PIN10)
 #define GPIO_ECAT_P1_TXD0           (GPIO_ECAT_CONF_OUTPUT | GPIO_PADA2_STRONGSHARP | GPIO_PORT3 | GPIO_PIN1 | GPIO_OUTPUT_ALT3)
 #define GPIO_ECAT_P1_TXD1           (GPIO_ECAT_CONF_OUTPUT | GPIO_PADA2_STRONGSHARP | GPIO_PORT3 | GPIO_PIN2 | GPIO_OUTPUT_ALT3)
