@@ -60,18 +60,7 @@ void up_exit(int status)
   struct tcb_s *tcb = this_task();
   UNUSED(status);
 
-  /* Make sure that we are in a critical section with local interrupts.
-   * The IRQ state will be restored when the next task is started.
-   */
-
-  enter_critical_section();
-
-  nxsched_dumponexit();
-
   /* Destroy the task at the head of the ready to run list. */
-#ifdef CONFIG_ARCH_FPU
-  arm64_destory_fpu(tcb);
-#endif
 
   nxtask_exit();
 
