@@ -109,6 +109,28 @@ EXTERN volatile uint8_t *g_current_regs;
  * Inline functions
  ****************************************************************************/
 
+#ifdef CONFIG_ARCH_FAMILY_AVR32
+static inline_function uint32_t *up_current_regs(void)
+{
+  return (uint32_t *)g_current_regs;
+}
+
+static inline_function void up_set_current_regs(uint32_t *regs)
+{
+  g_current_regs = regs;
+}
+#else
+static inline_function FAR uint8_t *up_current_regs(void)
+{
+  return (FAR uint8_t *)g_current_regs;
+}
+
+static inline_function void up_set_current_regs(FAR uint8_t *regs)
+{
+  g_current_regs = regs;
+}
+#endif
+
 /****************************************************************************
  * Name: up_interrupt_context
  *
@@ -118,7 +140,7 @@ EXTERN volatile uint8_t *g_current_regs;
  *
  ****************************************************************************/
 
-#define up_interrupt_context() (g_current_regs != NULL)
+#define up_interrupt_context() (up_current_regs() != NULL)
 
 #undef EXTERN
 #ifdef __cplusplus
