@@ -54,7 +54,7 @@ uintptr_t up_getusrsp(void *regs)
 
 void up_dump_register(void *dumpregs)
 {
-  volatile uint8_t *regs = dumpregs ? dumpregs : g_current_regs;
+  volatile uint8_t *regs = dumpregs ? dumpregs : up_current_regs();
 
   /* Are user registers available from interrupt processing? */
 
