@@ -87,7 +87,7 @@ void up_initial_state(struct tcb_s *tcb)
 #else
   /* No pending signal delivery */
 
-  xcp->sigdeliver   = NULL;
+  tcb->sigdeliver   = NULL;
 
   /* Clear the frame pointer and link register since this is the outermost
    * frame.
