@@ -51,7 +51,7 @@ uintptr_t up_getusrsp(void *regs)
 
 void up_dump_register(void *dumpregs)
 {
-  volatile uint32_t *regs = dumpregs ? dumpregs : CURRENT_REGS;
+  volatile uint32_t *regs = dumpregs ? dumpregs : up_current_regs();
   int rx;
 
   /* Dump the interrupt registers */
