@@ -79,6 +79,9 @@ typedef __WCHAR_TYPE__     _wchar_t;
 typedef int                _wchar_t;
 #endif
 
+typedef int                _wint_t;
+typedef int                _wctype_t;
+
 /* A size is two bytes */
 
 #if defined(__SIZE_TYPE__)
