@@ -122,6 +122,16 @@ EXTERN volatile uint8_t *g_current_regs;
  * Inline functions
  ****************************************************************************/
 
+static inline_function uint8_t *up_current_regs(void)
+{
+  return (FAR uint8_t *)g_current_regs;
+}
+
+static inline_function void up_set_current_regs(FAR uint8_t *regs)
+{
+  g_current_regs = regs;
+}
+
 /****************************************************************************
  * Name: up_interrupt_context
  *
@@ -131,7 +141,7 @@ EXTERN volatile uint8_t *g_current_regs;
  *
  ****************************************************************************/
 
-#define up_interrupt_context() (g_current_regs != NULL)
+#define up_interrupt_context() (up_current_regs() != NULL)
 
 /****************************************************************************
  * Public Function Prototypes
