@@ -68,8 +68,8 @@ uint32_t *mips_doirq(int irq, uint32_t *regs)
    * Nested interrupts are not supported
    */
 
-  DEBUGASSERT(CURRENT_REGS == NULL);
-  CURRENT_REGS = regs;
+  DEBUGASSERT(up_current_regs() == NULL);
+  up_set_current_regs(regs);
 
   /* Disable further occurrences of this interrupt (until the interrupt
    * source have been cleared by the driver).
@@ -88,12 +88,12 @@ uint32_t *mips_doirq(int irq, uint32_t *regs)
    * returning from the interrupt.
    */
 
-  if (regs != CURRENT_REGS)
+  if (regs != up_current_regs())
     {
 #ifdef CONFIG_ARCH_FPU
       /* Restore floating point registers */
 
-      up_restorefpu((uint32_t *)CURRENT_REGS);
+      up_restorefpu(up_current_regs());
 #endif
 
 #ifdef CONFIG_ARCH_ADDRENV
@@ -120,13 +120,13 @@ uint32_t *mips_doirq(int irq, uint32_t *regs)
    * switch occurred during interrupt processing.
    */
 
-  regs = (uint32_t *)CURRENT_REGS;
+  regs = up_current_regs();
 
   /* Set g_current_regs to NULL to indicate that we are no longer in an
    * interrupt handler.
    */
 
-  CURRENT_REGS = NULL;
+  up_set_current_regs(NULL);
 
   /* Unmask the last interrupt (global interrupts are still disabled) */
 
