@@ -76,88 +76,41 @@
  *
  ****************************************************************************/
 
-void up_schedule_sigaction(struct tcb_s *tcb, sig_deliver_t sigdeliver)
+void up_schedule_sigaction(struct tcb_s *tcb)
 {
   uint32_t status;
 
-  sinfo("tcb=%p sigdeliver=%p\n", tcb, sigdeliver);
+  sinfo("tcb=%p, rtcb=%p current_regs=%p\n", tcb,
+        this_task(), up_current_regs());
 
-  /* Refuse to handle nested signal actions */
+  /* First, handle some special cases when the signal is
+   * being delivered to the currently executing task.
+   */
 
-  if (!tcb->xcp.sigdeliver)
+  if (tcb == this_task())
     {
-      tcb->xcp.sigdeliver = sigdeliver;
-
-      /* First, handle some special cases when the signal is
-       * being delivered to the currently executing task.
+      /* CASE 1:  We are not in an interrupt handler and
+       * a task is signalling itself for some reason.
        */
 
-      sinfo("rtcb=%p CURRENT_REGS=%p\n",
-            this_task(), CURRENT_REGS);
-
-      if (tcb == this_task())
+      if (!up_current_regs())
         {
-          /* CASE 1:  We are not in an interrupt handler and
-           * a task is signalling itself for some reason.
-           */
+          /* In this case just deliver the signal now. */
 
-          if (!CURRENT_REGS)
-            {
-              /* In this case just deliver the signal now. */
-
-              sigdeliver(tcb);
-              tcb->xcp.sigdeliver = NULL;
-            }
-
-          /* CASE 2:  We are in an interrupt handler AND the
-           * interrupted task is the same as the one that
-           * must receive the signal, then we will have to modify
-           * the return state as well as the state in the TCB.
-           *
-           * Hmmm... there looks like a latent bug here: The following
-           * logic would fail in the strange case where we are in an
-           * interrupt handler, the thread is signalling itself, but
-           * a context switch to another task has occurred so that
-           * g_current_regs does not refer to the thread of this_task()!
-           */
-
-          else
-            {
-              /* Save the return EPC and STATUS registers.  These will be
-               * restored by the signal trampoline after the signals have
-               * been delivered.
-               */
-
-              tcb->xcp.saved_epc        = CURRENT_REGS[REG_EPC];
-              tcb->xcp.saved_status     = CURRENT_REGS[REG_STATUS];
-
-              /* Then set up to vector to the trampoline with interrupts
-               * disabled
-               */
-
-              CURRENT_REGS[REG_EPC]     = (uint32_t)mips_sigdeliver;
-              status                    = CURRENT_REGS[REG_STATUS];
-              status                   &= ~CP0_STATUS_INT_MASK;
-              status                   |= CP0_STATUS_INT_SW0;
-              CURRENT_REGS[REG_STATUS]  = status;
-
-              /* And make sure that the saved context in the TCB
-               * is the same as the interrupt return context.
-               */
-
-              mips_savestate(tcb->xcp.regs);
-
-              sinfo("PC/STATUS Saved: %08" PRIx32 "/%08" PRIx32
-                    " New: %08" PRIx32 "/%08" PRIx32 "\n",
-                    tcb->xcp.saved_epc, tcb->xcp.saved_status,
-                    CURRENT_REGS[REG_EPC], CURRENT_REGS[REG_STATUS]);
-            }
+          (tcb->sigdeliver)(tcb);
+          tcb->sigdeliver = NULL;
         }
 
-      /* Otherwise, we are (1) signaling a task is not running
-       * from an interrupt handler or (2) we are not in an
-       * interrupt handler and the running task is signalling
-       * some non-running task.
+      /* CASE 2:  We are in an interrupt handler AND the
+       * interrupted task is the same as the one that
+       * must receive the signal, then we will have to modify
+       * the return state as well as the state in the TCB.
+       *
+       * Hmmm... there looks like a latent bug here: The following
+       * logic would fail in the strange case where we are in an
+       * interrupt handler, the thread is signalling itself, but
+       * a context switch to another task has occurred so that
+       * g_current_regs does not refer to the thread of this_task()!
        */
 
       else
@@ -167,23 +120,62 @@ void up_schedule_sigaction(struct tcb_s *tcb, sig_deliver_t sigdeliver)
            * been delivered.
            */
 
-          tcb->xcp.saved_epc         = tcb->xcp.regs[REG_EPC];
-          tcb->xcp.saved_status      = tcb->xcp.regs[REG_STATUS];
+          tcb->xcp.saved_epc    = up_current_regs()[REG_EPC];
+          tcb->xcp.saved_status = up_current_regs()[REG_STATUS];
 
           /* Then set up to vector to the trampoline with interrupts
            * disabled
            */
 
-          tcb->xcp.regs[REG_EPC]     = (uint32_t)mips_sigdeliver;
-          status                     = tcb->xcp.regs[REG_STATUS];
-          status                    &= ~CP0_STATUS_INT_MASK;
-          status                    |= CP0_STATUS_INT_SW0;
-          tcb->xcp.regs[REG_STATUS]  = status;
+          up_current_regs()[REG_EPC] = (uint32_t)mips_sigdeliver;
+          status  = up_current_regs()[REG_STATUS];
+          status &= ~CP0_STATUS_INT_MASK;
+          status |= CP0_STATUS_INT_SW0;
+          up_current_regs()[REG_STATUS]  = status;
+
+          /* And make sure that the saved context in the TCB
+           * is the same as the interrupt return context.
+           */
+
+          mips_savestate(tcb->xcp.regs);
 
           sinfo("PC/STATUS Saved: %08" PRIx32 "/%08" PRIx32
                 " New: %08" PRIx32 "/%08" PRIx32 "\n",
                 tcb->xcp.saved_epc, tcb->xcp.saved_status,
-                tcb->xcp.regs[REG_EPC], tcb->xcp.regs[REG_STATUS]);
+                up_current_regs()[REG_EPC],
+                up_current_regs()[REG_STATUS]);
         }
     }
+
+  /* Otherwise, we are (1) signaling a task is not running
+   * from an interrupt handler or (2) we are not in an
+   * interrupt handler and the running task is signalling
+   * some non-running task.
+   */
+
+  else
+    {
+      /* Save the return EPC and STATUS registers.  These will be
+       * restored by the signal trampoline after the signals have
+       * been delivered.
+       */
+
+      tcb->xcp.saved_epc         = tcb->xcp.regs[REG_EPC];
+      tcb->xcp.saved_status      = tcb->xcp.regs[REG_STATUS];
+
+      /* Then set up to vector to the trampoline with interrupts
+       * disabled
+       */
+
+      tcb->xcp.regs[REG_EPC]     = (uint32_t)mips_sigdeliver;
+      status                     = tcb->xcp.regs[REG_STATUS];
+      status                    &= ~CP0_STATUS_INT_MASK;
+      status                    |= CP0_STATUS_INT_SW0;
+      tcb->xcp.regs[REG_STATUS]  = status;
+
+      sinfo("PC/STATUS Saved: %08" PRIx32 "/%08" PRIx32
+            " New: %08" PRIx32 "/%08" PRIx32 "\n",
+            tcb->xcp.saved_epc, tcb->xcp.saved_status,
+            tcb->xcp.regs[REG_EPC], tcb->xcp.regs[REG_STATUS]);
+    }
 }
