@@ -100,7 +100,7 @@ int mips_swint0(int irq, void *context, void *arg)
   uint32_t *regs = (uint32_t *)context;
   uint32_t cause;
 
-  DEBUGASSERT(regs && regs == CURRENT_REGS);
+  DEBUGASSERT(regs && regs == up_current_regs());
 
   /* Software interrupt 0 is invoked with REG_A0 (REG_R4) = system call
    * command and REG_A1-3 and REG_T0-2 (REG_R5-10) = variable number of
@@ -155,7 +155,7 @@ int mips_swint0(int irq, void *context, void *arg)
       case SYS_restore_context:
         {
           DEBUGASSERT(regs[REG_A1] != 0);
-          CURRENT_REGS = (uint32_t *)regs[REG_A1];
+          up_set_current_regs((uint32_t *)regs[REG_A1]);
         }
         break;
 
@@ -180,7 +180,7 @@ int mips_swint0(int irq, void *context, void *arg)
         {
           DEBUGASSERT(regs[REG_A1] != 0 && regs[REG_A2] != 0);
           mips_copystate((uint32_t *)regs[REG_A1], regs);
-          CURRENT_REGS = (uint32_t *)regs[REG_A2];
+          up_set_current_regs((uint32_t *)regs[REG_A2]);
         }
         break;
 
@@ -199,7 +199,7 @@ int mips_swint0(int irq, void *context, void *arg)
 #ifdef CONFIG_BUILD_KERNEL
       case SYS_syscall_return:
         {
-          struct tcb_s *rtcb = nxsched_self();
+          struct tcb_s *rtcb = this_task();
           int index = (int)rtcb->xcp.nsyscalls - 1;
 
           /* Make sure that there is a saved syscall return address. */
@@ -210,7 +210,7 @@ int mips_swint0(int irq, void *context, void *arg)
            * the original mode.
            */
 
-          CURRENT_REGS[REG_EPC] = rtcb->xcp.syscall[index].sysreturn;
+          up_current_regs()[REG_EPC] = rtcb->xcp.syscall[index].sysreturn;
 #error "Missing logic -- need to restore the original mode"
           rtcb->xcp.nsyscalls     = index;
 
@@ -232,12 +232,12 @@ int mips_swint0(int irq, void *context, void *arg)
       default:
         {
 #ifdef CONFIG_BUILD_KERNEL
-          struct tcb_s *rtcb = nxsched_self();
+          struct tcb_s *rtcb = this_task();
           int index = rtcb->xcp.nsyscalls;
 
           /* Verify that the SYS call number is within range */
 
-          DEBUGASSERT(CURRENT_REGS[REG_A0] < SYS_maxsyscall);
+          DEBUGASSERT(up_current_regs()[REG_A0] < SYS_maxsyscall);
 
           /* Make sure that we got here that there is a no saved syscall
            * return address.  We cannot yet handle nested system calls.
@@ -256,7 +256,7 @@ int mips_swint0(int irq, void *context, void *arg)
 
           /* Offset R0 to account for the reserved values */
 
-          CURRENT_REGS[REG_R0] -= CONFIG_SYS_RESERVED;
+          up_current_regs()[REG_R0] -= CONFIG_SYS_RESERVED;
 
           /* Indicate that we are in a syscall handler. */
 
@@ -273,10 +273,10 @@ int mips_swint0(int irq, void *context, void *arg)
    */
 
 #ifdef CONFIG_DEBUG_SYSCALL_INFO
-  if (regs != CURRENT_REGS)
+  if (regs != up_current_regs())
     {
       svcinfo("SWInt Return: Context switch!\n");
-      up_dump_register(CURRENT_REGS);
+      up_dump_register(up_current_regs());
     }
   else
     {
