@@ -88,11 +88,11 @@ uint32_t *pic32mx_decodeirq(uint32_t *regs)
    */
 
 #ifdef CONFIG_PIC32MX_NESTED_INTERRUPTS
-  savestate = (uint32_t *)CURRENT_REGS;
+  savestate = up_current_regs();
 #else
-  DEBUGASSERT(CURRENT_REGS == NULL);
+  DEBUGASSERT(up_current_regs() == NULL);
 #endif
-  CURRENT_REGS = regs;
+  up_set_current_regs(regs);
 
   /* Loop while there are pending interrupts with priority greater than
    * zero
@@ -131,7 +131,7 @@ uint32_t *pic32mx_decodeirq(uint32_t *regs)
    * switch occurred during interrupt processing.
    */
 
-  regs = (uint32_t *)CURRENT_REGS;
+  regs = up_current_regs();
 
 #if defined(CONFIG_ARCH_FPU) || defined(CONFIG_ARCH_ADDRENV)
   /* Check for a context switch.  If a context switch occurred, then
@@ -141,12 +141,12 @@ uint32_t *pic32mx_decodeirq(uint32_t *regs)
    * returning from the interrupt.
    */
 
-  if (regs != CURRENT_REGS)
+  if (regs != up_current_regs())
     {
 #ifdef CONFIG_ARCH_FPU
       /* Restore floating point registers */
 
-      up_restorefpu((uint32_t *)CURRENT_REGS);
+      up_restorefpu(up_current_regs());
 #endif
 
 #ifdef CONFIG_ARCH_ADDRENV
@@ -171,13 +171,13 @@ uint32_t *pic32mx_decodeirq(uint32_t *regs)
    * of fixing nested context switching.  The logic here is insufficient.
    */
 
-  CURRENT_REGS = savestate;
-  if (CURRENT_REGS == NULL)
+  up_set_current_regs(savestate);
+  if (up_current_regs() == NULL)
     {
       board_autoled_off(LED_INIRQ);
     }
 #else
-  CURRENT_REGS = NULL;
+  up_set_current_regs(NULL);
   board_autoled_off(LED_INIRQ);
 #endif
 
