@@ -96,8 +96,8 @@ int lm32_swint(int irq, void *context, void *arg)
 {
   uint32_t *regs = (uint32_t *)context;
 
-  DEBUGASSERT(regs != NULL && regs == g_current_regs);
-  g_current_regs = regs;
+  DEBUGASSERT(regs != NULL && regs == up_current_regs());
+  up_set_current_regs(regs);
 
   /* Software interrupt 0 is invoked with REG_A0 (REG_X10) = system call
    * command and REG_A1-6 = variable number of
@@ -153,7 +153,7 @@ int lm32_swint(int irq, void *context, void *arg)
       case SYS_restore_context:
         {
           DEBUGASSERT(regs[REG_A1] != 0);
-          g_current_regs = (uint32_t *)regs[REG_A1];
+          up_set_current_regs((uint32_t *)regs[REG_A1]);
         }
         break;
 
@@ -178,7 +178,7 @@ int lm32_swint(int irq, void *context, void *arg)
         {
           DEBUGASSERT(regs[REG_A1] != 0 && regs[REG_A2] != 0);
           lm32_copystate((uint32_t *)regs[REG_A1], regs);
-          g_current_regs = (uint32_t *)regs[REG_A2];
+          up_set_current_regs((uint32_t *)regs[REG_A2]);
         }
         break;
 
@@ -197,7 +197,7 @@ int lm32_swint(int irq, void *context, void *arg)
 #ifdef CONFIG_BUILD_KERNEL
       case SYS_syscall_return:
         {
-          struct tcb_s *rtcb = nxsched_self();
+          struct tcb_s *rtcb = this_task();
           int index = (int)rtcb->xcp.nsyscalls - 1;
 
           /* Make sure that there is a saved syscall return address. */
@@ -208,7 +208,7 @@ int lm32_swint(int irq, void *context, void *arg)
            * the original mode.
            */
 
-          g_current_regs[REG_EPC] = rtcb->xcp.syscall[index].sysreturn;
+          up_current_regs()[REG_EPC] = rtcb->xcp.syscall[index].sysreturn;
 #error "Missing logic -- need to restore the original mode"
           rtcb->xcp.nsyscalls     = index;
 
@@ -230,12 +230,12 @@ int lm32_swint(int irq, void *context, void *arg)
       default:
         {
 #ifdef CONFIG_BUILD_KERNEL
-          struct tcb_s *rtcb = nxsched_self();
+          struct tcb_s *rtcb = this_task();
           int index = rtcb->xcp.nsyscalls;
 
           /* Verify that the SYS call number is within range */
 
-          DEBUGASSERT(g_current_regs[REG_A0] < SYS_maxsyscall);
+          DEBUGASSERT(up_current_regs()[REG_A0] < SYS_maxsyscall);
 
           /* Make sure that we got here that there is a no saved syscall
            * return address.  We cannot yet handle nested system calls.
@@ -254,7 +254,7 @@ int lm32_swint(int irq, void *context, void *arg)
 
           /* Offset R0 to account for the reserved values */
 
-          g_current_regs[REG_A0] -= CONFIG_SYS_RESERVED;
+          up_current_regs()[REG_A0] -= CONFIG_SYS_RESERVED;
 
           /* Indicate that we are in a syscall handler. */
 
@@ -271,10 +271,10 @@ int lm32_swint(int irq, void *context, void *arg)
    */
 
 #ifdef CONFIG_DEBUG_SYSCALL_INFO
-  if (regs != g_current_regs)
+  if (regs != up_current_regs())
     {
       svcinfo("SWInt Return: Context switch!\n");
-      up_dump_register(g_current_regs);
+      up_dump_register(up_current_regs());
     }
   else
     {
