@@ -76,102 +76,95 @@
  *
  ****************************************************************************/
 
-void up_schedule_sigaction(struct tcb_s *tcb, sig_deliver_t sigdeliver)
+void up_schedule_sigaction(struct tcb_s *tcb)
 {
-  sinfo("tcb=%p sigdeliver=%p\n", tcb, sigdeliver);
+  sinfo("tcb=%p, rtcb=%p current_regs=%p\n", tcb,
+        this_task(), up_current_regs());
 
-  /* Refuse to handle nested signal actions */
+  /* First, handle some special cases when the signal is being delivered
+   * to the currently executing task.
+   */
 
-  if (!tcb->xcp.sigdeliver)
+  if (tcb == this_task())
     {
-      tcb->xcp.sigdeliver = sigdeliver;
-
-      /* First, handle some special cases when the signal is being delivered
-       * to the currently executing task.
+      /* CASE 1: We are not in an interrupt handler and a task is
+       * signalling itself for some reason.
        */
 
-      sinfo("rtcb=%p g_current_regs=%p\n", this_task(), g_current_regs);
-
-      if (tcb == this_task())
+      if (!up_current_regs())
         {
-          /* CASE 1: We are not in an interrupt handler and a task is
-           * signalling itself for some reason.
-           */
+          /* In this case just deliver the signal now. */
 
-          if (!g_current_regs)
-            {
-              /* In this case just deliver the signal now. */
-
-              sigdeliver(tcb);
-              tcb->xcp.sigdeliver = NULL;
-            }
-
-          /* CASE 2: We are in an interrupt handler AND the interrupted task
-           * is the same as the one that must receive the signal, then we
-           * will have to modify the return state as well as the state in
-           * the TCB.
-           *
-           * Hmmm... there looks like a latent bug here: The following logic
-           * would fail in the strange case where we are in an interrupt
-           * handler, the thread is signalling itself, but a context switch
-           * to another task has occurred so that g_current_regs does not
-           * refer to the thread of this_task()!
-           */
-
-          else
-            {
-              /* Save the return EPC and STATUS registers.  These will be
-               * restored by the signal trampoline after the signals have
-               * been delivered.
-               */
-
-              tcb->xcp.saved_epc = g_current_regs[REG_CSR_MEPC];
-
-              /* Then set up to vector to the trampoline with interrupts
-               * disabled
-               */
-
-              g_current_regs[REG_CSR_MEPC] = (uint32_t) minerva_sigdeliver;
-              g_current_regs[REG_CSR_MSTATUS] &= ~CSR_MSTATUS_MIE;
-
-              /* And make sure that the saved context in the TCB is the same
-               * as the interrupt return context.
-               */
-
-              misoc_savestate(tcb->xcp.regs);
-
-              sinfo("PC/STATUS Saved: %08x/%08x New: %08x/%08x\n",
-                    tcb->xcp.saved_epc, tcb->xcp.saved_status,
-                    g_current_regs[REG_CSR_MEPC],
-                    g_current_regs[REG_CSR_MSTATUS]);
-            }
+          (tcb->sigdeliver)(tcb);
+          tcb->sigdeliver = NULL;
         }
 
-      /* Otherwise, we are (1) signaling a task is not running from an
-       * interrupt handler or (2) we are not in an interrupt handler and the
-       * running task is signalling some non-running task.
+      /* CASE 2: We are in an interrupt handler AND the interrupted task
+       * is the same as the one that must receive the signal, then we
+       * will have to modify the return state as well as the state in
+       * the TCB.
+       *
+       * Hmmm... there looks like a latent bug here: The following logic
+       * would fail in the strange case where we are in an interrupt
+       * handler, the thread is signalling itself, but a context switch
+       * to another task has occurred so that g_current_regs does not
+       * refer to the thread of this_task()!
        */
 
       else
         {
           /* Save the return EPC and STATUS registers.  These will be
-           * restored by the signal trampoline after the signals have been
-           * delivered.
+           * restored by the signal trampoline after the signals have
+           * been delivered.
            */
 
-          tcb->xcp.saved_epc = tcb->xcp.regs[REG_CSR_MEPC];
-          tcb->xcp.saved_int_ctx = tcb->xcp.regs[REG_CSR_MSTATUS];
+          tcb->xcp.saved_epc = up_current_regs()[REG_CSR_MEPC];
 
           /* Then set up to vector to the trampoline with interrupts
            * disabled
            */
 
-          tcb->xcp.regs[REG_CSR_MEPC] = (uint32_t) minerva_sigdeliver;
-          g_current_regs[REG_CSR_MSTATUS] &= ~CSR_MSTATUS_MIE;
+          up_current_regs()[REG_CSR_MEPC] =
+            (uint32_t)minerva_sigdeliver;
+          up_current_regs()[REG_CSR_MSTATUS] &= ~CSR_MSTATUS_MIE;
+
+          /* And make sure that the saved context in the TCB is the same
+           * as the interrupt return context.
+           */
+
+          misoc_savestate(tcb->xcp.regs);
 
           sinfo("PC/STATUS Saved: %08x/%08x New: %08x/%08x\n",
                 tcb->xcp.saved_epc, tcb->xcp.saved_status,
-                tcb->xcp.regs[REG_CSR_MEPC], tcb->xcp.regs[REG_CSR_MSTATUS]);
+                up_current_regs()[REG_CSR_MEPC],
+                up_current_regs()[REG_CSR_MSTATUS]);
         }
     }
+
+  /* Otherwise, we are (1) signaling a task is not running from an
+   * interrupt handler or (2) we are not in an interrupt handler and the
+   * running task is signalling some non-running task.
+   */
+
+  else
+    {
+      /* Save the return EPC and STATUS registers.  These will be
+       * restored by the signal trampoline after the signals have been
+       * delivered.
+       */
+
+      tcb->xcp.saved_epc = tcb->xcp.regs[REG_CSR_MEPC];
+      tcb->xcp.saved_int_ctx = tcb->xcp.regs[REG_CSR_MSTATUS];
+
+      /* Then set up to vector to the trampoline with interrupts
+       * disabled
+       */
+
+      tcb->xcp.regs[REG_CSR_MEPC] = (uint32_t) minerva_sigdeliver;
+      up_current_regs()[REG_CSR_MSTATUS] &= ~CSR_MSTATUS_MIE;
+
+      sinfo("PC/STATUS Saved: %08x/%08x New: %08x/%08x\n",
+            tcb->xcp.saved_epc, tcb->xcp.saved_status,
+            tcb->xcp.regs[REG_CSR_MEPC], tcb->xcp.regs[REG_CSR_MSTATUS]);
+    }
 }
