@@ -74,80 +74,39 @@
  *
  ****************************************************************************/
 
-void up_schedule_sigaction(struct tcb_s *tcb, sig_deliver_t sigdeliver)
+void up_schedule_sigaction(struct tcb_s *tcb)
 {
-  sinfo("tcb=%p sigdeliver=%p\n", tcb, sigdeliver);
+  sinfo("tcb=%p, rtcb=%p current_regs=%p\n", tcb,
+        this_task(), up_current_regs());
 
-  /* Refuse to handle nested signal actions */
+  /* First, handle some special cases when the signal is
+   * being delivered to the currently executing task.
+   */
 
-  if (!tcb->xcp.sigdeliver)
+  if (tcb == this_task())
     {
-      tcb->xcp.sigdeliver = sigdeliver;
-
-      /* First, handle some special cases when the signal is
-       * being delivered to the currently executing task.
+      /* CASE 1:  We are not in an interrupt handler and
+       * a task is signalling itself for some reason.
        */
 
-      sinfo("rtcb=%p CURRENT_REGS=%p\n", this_task(), CURRENT_REGS);
-
-      if (tcb == this_task())
+      if (!up_current_regs())
         {
-          /* CASE 1:  We are not in an interrupt handler and
-           * a task is signalling itself for some reason.
-           */
+          /* In this case just deliver the signal now. */
 
-          if (!CURRENT_REGS)
-            {
-              /* In this case just deliver the signal now. */
-
-              sigdeliver(tcb);
-              tcb->xcp.sigdeliver = NULL;
-            }
-
-          /* CASE 2:  We are in an interrupt handler AND the
-           * interrupted task is the same as the one that
-           * must receive the signal, then we will have to modify
-           * the return state as well as the state in the TCB.
-           *
-           * Hmmm... there looks like a latent bug here: The following
-           * logic would fail in the strange case where we are in an
-           * interrupt handler, the thread is signalling itself, but
-           * a context switch to another task has occurred so that
-           * CURRENT_REGS does not refer to the thread of this_task()!
-           */
-
-          else
-            {
-              /* Save the return lr and cpsr and one scratch register
-               * These will be restored by the signal trampoline after
-               * the signals have been delivered.
-               */
-
-              /* tcb->xcp.saved_pc      = CURRENT_REGS[REG_PC];
-               * tcb->xcp.saved_cpsr    = CURRENT_REGS[REG_CPSR];
-               */
-
-              /* Then set up to vector to the trampoline with interrupts
-               * disabled
-               */
-
-              /* CURRENT_REGS[REG_PC]   = (uint32_t)or1k_sigdeliver;
-               * CURRENT_REGS[REG_CPSR] = SVC_MODE | PSR_I_BIT |
-               *                          PSR_F_BIT;
-               */
-
-              /* And make sure that the saved context in the TCB
-               * is the same as the interrupt return context.
-               */
-
-              or1k_savestate(tcb->xcp.regs);
-            }
+          (tcb->sigdeliver)(tcb);
+          tcb->sigdeliver = NULL;
         }
 
-      /* Otherwise, we are (1) signaling a task is not running
-       * from an interrupt handler or (2) we are not in an
-       * interrupt handler and the running task is signalling
-       * some non-running task.
+      /* CASE 2:  We are in an interrupt handler AND the
+       * interrupted task is the same as the one that
+       * must receive the signal, then we will have to modify
+       * the return state as well as the state in the TCB.
+       *
+       * Hmmm... there looks like a latent bug here: The following
+       * logic would fail in the strange case where we are in an
+       * interrupt handler, the thread is signalling itself, but
+       * a context switch to another task has occurred so that
+       * current_regs does not refer to the thread of this_task()!
        */
 
       else
@@ -157,17 +116,50 @@ void up_schedule_sigaction(struct tcb_s *tcb, sig_deliver_t sigdeliver)
            * the signals have been delivered.
            */
 
-          tcb->xcp.saved_pc          = tcb->xcp.regs[REG_PC];
-
-          /* tcb->xcp.saved_cpsr     = tcb->xcp.regs[REG_CPSR]; */
+          /* tcb->xcp.saved_pc   = up_current_regs()[REG_PC];
+           * tcb->xcp.saved_cpsr = up_current_regs()[REG_CPSR];
+           */
 
           /* Then set up to vector to the trampoline with interrupts
            * disabled
            */
 
-          /* tcb->xcp.regs[REG_PC]   = (uint32_t)or1k_sigdeliver;
-           * tcb->xcp.regs[REG_CPSR] = SVC_MODE | PSR_I_BIT | PSR_F_BIT;
+          /* up_current_regs()[REG_PC]   = (uint32_t)or1k_sigdeliver;
+           * up_current_regs()[REG_CPSR] = SVC_MODE | PSR_I_BIT |
+           *                          PSR_F_BIT;
            */
+
+          /* And make sure that the saved context in the TCB
+           * is the same as the interrupt return context.
+           */
+
+          or1k_savestate(tcb->xcp.regs);
         }
     }
+
+  /* Otherwise, we are (1) signaling a task is not running
+   * from an interrupt handler or (2) we are not in an
+   * interrupt handler and the running task is signalling
+   * some non-running task.
+   */
+
+  else
+    {
+      /* Save the return lr and cpsr and one scratch register
+       * These will be restored by the signal trampoline after
+       * the signals have been delivered.
+       */
+
+      tcb->xcp.saved_pc          = tcb->xcp.regs[REG_PC];
+
+      /* tcb->xcp.saved_cpsr     = tcb->xcp.regs[REG_CPSR]; */
+
+      /* Then set up to vector to the trampoline with interrupts
+       * disabled
+       */
+
+      /* tcb->xcp.regs[REG_PC]   = (uint32_t)or1k_sigdeliver;
+       * tcb->xcp.regs[REG_CPSR] = SVC_MODE | PSR_I_BIT | PSR_F_BIT;
+       */
+    }
 }
