@@ -64,7 +64,16 @@ static const char *g_reasons_str[RISCV_MAX_EXCEPTION + 1] =
   "Instruction page fault",
   "Load page fault",
   "Reserved",
-  "Store/AMO page fault"
+  "Store/AMO page fault",
+#ifdef CONFIG_ARCH_RV_MACHINE_ISA_1_13
+  "Reserved",
+  "Reserved",
+  "Software check",
+  "Hardware error",
+#endif
+#ifdef RISCV_CUSTOM_EXCEPTION_REASONS
+  RISCV_CUSTOM_EXCEPTION_REASONS
+#endif
 };
 
 /****************************************************************************
@@ -82,7 +91,7 @@ static const char *g_reasons_str[RISCV_MAX_EXCEPTION + 1] =
 int riscv_exception(int mcause, void *regs, void *args)
 {
 #ifdef CONFIG_ARCH_KERNEL_STACK
-  FAR struct tcb_s *tcb = this_task();
+  struct tcb_s *tcb = this_task();
 #endif
   uintreg_t cause = mcause & RISCV_IRQ_MASK;
 
@@ -94,32 +103,29 @@ int riscv_exception(int mcause, void *regs, void *args)
 #ifdef CONFIG_ARCH_KERNEL_STACK
   if ((tcb->flags & TCB_FLAG_TTYPE_MASK) != TCB_FLAG_TTYPE_KERNEL)
     {
-#  if CONFIG_TASK_NAME_SIZE > 0
-      _alert("Segmentation fault in PID %d: %s\n", tcb->pid, tcb->name);
-#  else
-      _alert("Segmentation fault in PID %d\n", tcb->pid);
-#  endif
+      _alert("Segmentation fault in PID %d: %s\n",
+             tcb->pid, get_task_name(tcb));
 
       tcb->flags |= TCB_FLAG_FORCED_CANCEL;
 
       /* Return to _exit function in privileged mode with argument SIGSEGV */
 
-      CURRENT_REGS[REG_EPC] = (uintptr_t)_exit;
-      CURRENT_REGS[REG_A0] = SIGSEGV;
-      CURRENT_REGS[REG_INT_CTX] |= STATUS_PPP;
+      up_current_regs()[REG_EPC] = (uintptr_t)_exit;
+      up_current_regs()[REG_A0] = SIGSEGV;
+      up_current_regs()[REG_INT_CTX] |= STATUS_PPP;
 
       /* Continue with kernel stack in use. The frame(s) in kernel stack
        * are no longer needed, so just set it to top
        */
 
-      CURRENT_REGS[REG_SP] = (uintptr_t)tcb->xcp.ktopstk;
+      up_current_regs()[REG_SP] = (uintptr_t)tcb->xcp.ktopstk;
     }
   else
 #endif
     {
       _alert("PANIC!!! Exception = %" PRIxREG "\n", cause);
       up_irq_save();
-      CURRENT_REGS = regs;
+      up_set_current_regs(regs);
       PANIC_WITH_REGS("panic", regs);
     }
 
@@ -162,7 +168,7 @@ int riscv_fillpage(int mcause, void *regs, void *args)
   uintptr_t vaddr;
   uint32_t  ptlevel;
   uintptr_t satp;
-  uint32_t mmuflags;
+  uint64_t  mmuflags;
 
   _info("EXCEPTION: %s. MCAUSE: %" PRIxREG ", EPC: %" PRIxREG
         ", MTVAL: %" PRIxREG "\n",
@@ -191,14 +197,14 @@ int riscv_fillpage(int mcause, void *regs, void *args)
     {
       _alert("PANIC!!! virtual address not mappable: %" PRIxPTR "\n", vaddr);
       up_irq_save();
-      CURRENT_REGS = regs;
+      up_set_current_regs(regs);
       PANIC_WITH_REGS("panic", regs);
     }
 
   satp    = READ_CSR(CSR_SATP);
   ptprev  = riscv_pgvaddr(mmu_satp_to_paddr(satp));
   ptlevel = ARCH_SPGTS;
-  paddr = mmu_pte_to_paddr(mmu_ln_getentry(ptlevel, ptprev, vaddr));
+  paddr   = mmu_pte_to_paddr(mmu_ln_getentry(ptlevel, ptprev, vaddr));
   if (!paddr)
     {
       /* Nothing yet, allocate one page for final level page table */
@@ -289,11 +295,11 @@ void riscv_exception_attach(void)
   irq_attach(RISCV_IRQ_STOREPF, riscv_exception, NULL);
 #endif
 
-  irq_attach(RISCV_IRQ_RESERVED, riscv_exception, NULL);
+  irq_attach(RISCV_IRQ_RESERVED14, riscv_exception, NULL);
 
 #ifdef CONFIG_SMP
-  irq_attach(RISCV_IRQ_SOFT, riscv_pause_handler, NULL);
+  irq_attach(RISCV_IRQ_SOFT, riscv_smp_call_handler, NULL);
 #else
-  irq_attach(RISCV_IRQ_MSOFT, riscv_exception, NULL);
+  irq_attach(RISCV_IRQ_SOFT, riscv_exception, NULL);
 #endif
 }
