@@ -56,14 +56,6 @@ void up_exit(int status)
 {
   struct tcb_s *tcb = this_task();
 
-  /* Make sure that we are in a critical section with local interrupts.
-   * The IRQ state will be restored when the next task is started.
-   */
-
-  enter_critical_section();
-
-  nxsched_dumponexit();
-
   /* Destroy the task at the head of the ready to run list. */
 
   nxtask_exit();
@@ -80,6 +72,10 @@ void up_exit(int status)
 
   nxsched_resume_scheduler(tcb);
 
+  /* g_running_tasks is not valid now */
+
+  g_running_tasks[this_cpu()] = NULL;
+
   /* Then switch contexts */
 
   riscv_fullcontextrestore(tcb);
