@@ -67,6 +67,9 @@ uintptr_t riscv_get_newintctx(void)
   return (status | STATUS_PPP | STATUS_SUM | STATUS_PIE
 #ifdef CONFIG_ARCH_FPU
                  | MSTATUS_FS_INIT
+#endif
+#ifdef CONFIG_ARCH_RV_ISA_V
+                 | MSTATUS_VS_INIT
 #endif
   );
 }
