@@ -26,11 +26,13 @@
 
 #include <nuttx/sched.h>
 
+#include "sched/sched.h"
+
 /****************************************************************************
  * Public Functions
  ****************************************************************************/
 
 uintptr_t riscv_current_ksp(void)
 {
-  return (uintptr_t)nxsched_self()->xcp.kstkptr;
+  return (uintptr_t)this_task()->xcp.kstkptr;
 }
