@@ -37,6 +37,7 @@
 
 #include <arch/barriers.h>
 
+#include "sched/sched.h"
 #include "addrenv.h"
 #include "pgalloc.h"
 #include "riscv_mmu.h"
@@ -94,7 +95,7 @@
 
 uintptr_t pgalloc(uintptr_t brkaddr, unsigned int npages)
 {
-  struct tcb_s          *tcb = nxsched_self();
+  struct tcb_s          *tcb = this_task();
   struct arch_addrenv_s *addrenv;
   uintptr_t              ptlast;
   uintptr_t              paddr;
