@@ -134,9 +134,16 @@ static bool pmp_check_region_attrs(uintptr_t base, uintptr_t size,
 
     case PMPCFG_A_NAPOT:
       {
-        /* For NAPOT, both base and size must be properly aligned */
+        /* Special range for the whole range */
 
-        if ((base & 0x07) != 0 || size < 8)
+        if (base == 0 && size == 0)
+          {
+            return true;
+          }
+
+        /* For NAPOT, Naturally aligned power-of-two region, >= 8 bytes */
+
+        if ((base & 0x07) != 0 || size < 8 || (size & (size - 1)) != 0)
           {
             return false;
           }
@@ -180,16 +187,16 @@ static uintptr_t pmp_read_region_cfg(uintptr_t region)
   switch (region)
     {
       case 0 ... 3:
-        return PMP_READ_REGION_FROM_REG(region, pmpcfg0);
+        return PMP_READ_REGION_FROM_REG(region, CSR_PMPCFG0);
 
       case 4 ... 7:
-        return PMP_READ_REGION_FROM_REG(region, pmpcfg1);
+        return PMP_READ_REGION_FROM_REG(region, CSR_PMPCFG1);
 
       case 8 ... 11:
-        return PMP_READ_REGION_FROM_REG(region, pmpcfg2);
+        return PMP_READ_REGION_FROM_REG(region, CSR_PMPCFG2);
 
       case 12 ... 15:
-        return PMP_READ_REGION_FROM_REG(region, pmpcfg3);
+        return PMP_READ_REGION_FROM_REG(region, CSR_PMPCFG3);
 
       default:
         break;
@@ -198,10 +205,10 @@ static uintptr_t pmp_read_region_cfg(uintptr_t region)
   switch (region)
     {
       case 0 ... 7:
-        return PMP_READ_REGION_FROM_REG(region, pmpcfg0);
+        return PMP_READ_REGION_FROM_REG(region, CSR_PMPCFG0);
 
       case 8 ... 15:
-        return PMP_READ_REGION_FROM_REG(region, pmpcfg2);
+        return PMP_READ_REGION_FROM_REG(region, CSR_PMPCFG2);
 
       default:
         break;
@@ -232,52 +239,52 @@ static uintptr_t pmp_read_addr(uintptr_t region)
   switch (region)
       {
         case 0:
-          return READ_CSR(pmpaddr0);
+          return READ_CSR(CSR_PMPADDR0);
 
         case 1:
-          return READ_CSR(pmpaddr1);
+          return READ_CSR(CSR_PMPADDR1);
 
         case 2:
-          return READ_CSR(pmpaddr2);
+          return READ_CSR(CSR_PMPADDR2);
 
         case 3:
-          return READ_CSR(pmpaddr3);
+          return READ_CSR(CSR_PMPADDR3);
 
         case 4:
-          return READ_CSR(pmpaddr4);
+          return READ_CSR(CSR_PMPADDR4);
 
         case 5:
-          return READ_CSR(pmpaddr5);
+          return READ_CSR(CSR_PMPADDR5);
 
         case 6:
-          return READ_CSR(pmpaddr6);
+          return READ_CSR(CSR_PMPADDR6);
 
         case 7:
-          return READ_CSR(pmpaddr7);
+          return READ_CSR(CSR_PMPADDR7);
 
         case 8:
-          return READ_CSR(pmpaddr8);
+          return READ_CSR(CSR_PMPADDR8);
 
         case 9:
-          return READ_CSR(pmpaddr9);
+          return READ_CSR(CSR_PMPADDR9);
 
         case 10:
-          return READ_CSR(pmpaddr10);
+          return READ_CSR(CSR_PMPADDR10);
 
         case 11:
-          return READ_CSR(pmpaddr11);
+          return READ_CSR(CSR_PMPADDR11);
 
         case 12:
-          return READ_CSR(pmpaddr12);
+          return READ_CSR(CSR_PMPADDR12);
 
         case 13:
-          return READ_CSR(pmpaddr13);
+          return READ_CSR(CSR_PMPADDR13);
 
         case 14:
-          return READ_CSR(pmpaddr14);
+          return READ_CSR(CSR_PMPADDR14);
 
         case 15:
-          return READ_CSR(pmpaddr15);
+          return READ_CSR(CSR_PMPADDR15);
 
         default:
           break;
@@ -440,67 +447,67 @@ int riscv_config_pmp_region(uintptr_t region, uintptr_t attr,
   switch (region)
     {
       case 0:
-        WRITE_CSR(pmpaddr0, addr);
+        WRITE_CSR(CSR_PMPADDR0, addr);
         break;
 
       case 1:
-        WRITE_CSR(pmpaddr1, addr);
+        WRITE_CSR(CSR_PMPADDR1, addr);
         break;
 
       case 2:
-        WRITE_CSR(pmpaddr2, addr);
+        WRITE_CSR(CSR_PMPADDR2, addr);
         break;
 
       case 3:
-        WRITE_CSR(pmpaddr3, addr);
+        WRITE_CSR(CSR_PMPADDR3, addr);
         break;
 
       case 4:
-        WRITE_CSR(pmpaddr4, addr);
+        WRITE_CSR(CSR_PMPADDR4, addr);
         break;
 
       case 5:
-        WRITE_CSR(pmpaddr5, addr);
+        WRITE_CSR(CSR_PMPADDR5, addr);
         break;
 
       case 6:
-        WRITE_CSR(pmpaddr6, addr);
+        WRITE_CSR(CSR_PMPADDR6, addr);
         break;
 
       case 7:
-        WRITE_CSR(pmpaddr7, addr);
+        WRITE_CSR(CSR_PMPADDR7, addr);
         break;
 
       case 8:
-        WRITE_CSR(pmpaddr8, addr);
+        WRITE_CSR(CSR_PMPADDR8, addr);
         break;
 
       case 9:
-        WRITE_CSR(pmpaddr9, addr);
+        WRITE_CSR(CSR_PMPADDR9, addr);
         break;
 
       case 10:
-        WRITE_CSR(pmpaddr10, addr);
+        WRITE_CSR(CSR_PMPADDR10, addr);
         break;
 
       case 11:
-        WRITE_CSR(pmpaddr11, addr);
+        WRITE_CSR(CSR_PMPADDR11, addr);
         break;
 
       case 12:
-        WRITE_CSR(pmpaddr12, addr);
+        WRITE_CSR(CSR_PMPADDR12, addr);
         break;
 
       case 13:
-        WRITE_CSR(pmpaddr13, addr);
+        WRITE_CSR(CSR_PMPADDR13, addr);
         break;
 
       case 14:
-        WRITE_CSR(pmpaddr14, addr);
+        WRITE_CSR(CSR_PMPADDR14, addr);
         break;
 
       case 15:
-        WRITE_CSR(pmpaddr15, addr);
+        WRITE_CSR(CSR_PMPADDR15, addr);
         break;
 
       default:
@@ -513,27 +520,27 @@ int riscv_config_pmp_region(uintptr_t region, uintptr_t attr,
   switch (region)
     {
       case 0 ... 3:
-        cfg = READ_CSR(pmpcfg0);
+        cfg = READ_CSR(CSR_PMPCFG0);
         PMP_MASK_SET_ONE_REGION(region, attr, cfg);
-        WRITE_CSR(pmpcfg0, cfg);
+        WRITE_CSR(CSR_PMPCFG0, cfg);
         break;
 
       case 4 ... 7:
-        cfg = READ_CSR(pmpcfg1);
+        cfg = READ_CSR(CSR_PMPCFG1);
         PMP_MASK_SET_ONE_REGION(region, attr, cfg);
-        WRITE_CSR(pmpcfg1, cfg);
+        WRITE_CSR(CSR_PMPCFG1, cfg);
         break;
 
       case 8 ... 11:
-        cfg = READ_CSR(pmpcfg2);
+        cfg = READ_CSR(CSR_PMPCFG2);
         PMP_MASK_SET_ONE_REGION(region, attr, cfg);
-        WRITE_CSR(pmpcfg2, cfg);
+        WRITE_CSR(CSR_PMPCFG2, cfg);
         break;
 
       case 12 ... 15:
-        cfg = READ_CSR(pmpcfg3);
+        cfg = READ_CSR(CSR_PMPCFG3);
         PMP_MASK_SET_ONE_REGION(region, attr, cfg);
-        WRITE_CSR(pmpcfg3, cfg);
+        WRITE_CSR(CSR_PMPCFG3, cfg);
         break;
 
       default:
@@ -543,15 +550,15 @@ int riscv_config_pmp_region(uintptr_t region, uintptr_t attr,
   switch (region)
     {
       case 0 ... 7:
-        cfg = READ_CSR(pmpcfg0);
+        cfg = READ_CSR(CSR_PMPCFG0);
         PMP_MASK_SET_ONE_REGION(region, attr, cfg);
-        WRITE_CSR(pmpcfg0, cfg);
+        WRITE_CSR(CSR_PMPCFG0, cfg);
         break;
 
       case 8 ... 15:
-        cfg = READ_CSR(pmpcfg2);
+        cfg = READ_CSR(CSR_PMPCFG2);
         PMP_MASK_SET_ONE_REGION(region, attr, cfg);
-        WRITE_CSR(pmpcfg2, cfg);
+        WRITE_CSR(CSR_PMPCFG2, cfg);
         break;
 
       default:
