@@ -40,6 +40,7 @@
 #  include <syscall.h>
 #endif
 
+#include "sched/sched.h"
 #include "signal/signal.h"
 #include "riscv_internal.h"
 #include "addrenv.h"
@@ -48,16 +49,74 @@
  * Pre-processor Definitions
  ****************************************************************************/
 
-#ifdef CONFIG_LIB_SYSCALL
-#  define TCB_FLAGS_OFFSET offsetof(struct tcb_s, flags)
-#endif
-
 /****************************************************************************
  * Private Functions
  ****************************************************************************/
 
 #ifdef CONFIG_LIB_SYSCALL
 
+/****************************************************************************
+ * Name: do_syscall
+ *
+ * Description:
+ *   Call the stub function corresponding to the system call.  NOTE the non-
+ *   standard parameter passing:
+ *
+ *     A0 = SYS_ call number
+ *     A1 = parm0
+ *     A2 = parm1
+ *     A3 = parm2
+ *     A4 = parm3
+ *     A5 = parm4
+ *     A6 = parm5
+ *
+ * Note:
+ *   Do not allow the compiler to inline this function, as it does a jump to
+ *   another procedure which can clobber any register and the compiler will
+ *   not understand it happens.
+ *
+ ****************************************************************************/
+
+static uintptr_t do_syscall(unsigned int nbr, uintptr_t parm1,
+                            uintptr_t parm2, uintptr_t parm3,
+                            uintptr_t parm4, uintptr_t parm5,
+                            uintptr_t parm6) noinline_function;
+static uintptr_t do_syscall(unsigned int nbr, uintptr_t parm1,
+                            uintptr_t parm2, uintptr_t parm3,
+                            uintptr_t parm4, uintptr_t parm5,
+                            uintptr_t parm6)
+{
+  register long a0 asm("a0") = (long)(nbr);
+  register long a1 asm("a1") = (long)(parm1);
+  register long a2 asm("a2") = (long)(parm2);
+  register long a3 asm("a3") = (long)(parm3);
+  register long a4 asm("a4") = (long)(parm4);
+  register long a5 asm("a5") = (long)(parm5);
+  register long a6 asm("a6") = (long)(parm6);
+
+  asm volatile
+    (
+     "la   t0, g_stublookup\n" /* t0=The base of the stub lookup table */
+#ifdef CONFIG_ARCH_RV32
+     "slli a0, a0, 2\n"        /* a0=Offset for the stub lookup table */
+#else
+     "slli a0, a0, 3\n"        /* a0=Offset for the stub lookup table */
+#endif
+     "add  t0, t0, a0\n"       /* t0=The address in the table */
+     REGLOAD " t0, 0(t0)\n"    /* t0=The address of the stub for this syscall */
+     "jalr ra, t0\n"           /* Call the stub (modifies ra) */
+     : "+r"(a0)
+     : "r"(a1), "r"(a2), "r"(a3), "r"(a4), "r"(a5), "r"(a6)
+     : "t0", "ra", "memory"
+  );
+
+  return a0;
+}
+
+/****************************************************************************
+ * Public Functions
+ ****************************************************************************/
+
 /****************************************************************************
  * Name: dispatch_syscall
  *
@@ -72,13 +131,14 @@
  *     A4 = parm3
  *     A5 = parm4
  *     A6 = parm5
+ *     A7 = context (aka SP)
  *
  ****************************************************************************/
 
 uintptr_t dispatch_syscall(unsigned int nbr, uintptr_t parm1,
                            uintptr_t parm2, uintptr_t parm3,
                            uintptr_t parm4, uintptr_t parm5,
-                           uintptr_t parm6)
+                           uintptr_t parm6, void *context)
 {
   register long a0 asm("a0") = (long)(nbr);
   register long a1 asm("a1") = (long)(parm1);
@@ -87,7 +147,7 @@ uintptr_t dispatch_syscall(unsigned int nbr, uintptr_t parm1,
   register long a4 asm("a4") = (long)(parm4);
   register long a5 asm("a5") = (long)(parm5);
   register long a6 asm("a6") = (long)(parm6);
-
+  register struct tcb_s *rtcb asm("tp");
   uintptr_t ret;
 
   /* Valid system call ? */
@@ -99,37 +159,25 @@ uintptr_t dispatch_syscall(unsigned int nbr, uintptr_t parm1,
       return -ENOSYS;
     }
 
-  /* ra gets clobbered below, but it does not matter */
+  /* Set the user register context to TCB */
 
-  asm volatile
-    (
-     REGLOAD " t0, %1(tp)\n"                /* Load tcb->flags */
-     "ori  t0, t0, %2\n"                    /* tcb->flags |= TCB_FLAG_SYSCALL */
-     REGSTORE " t0, %1(tp)\n"
-     "addi a0, a0, -%3\n"                   /* Offset a0 to account for the reserved syscalls */
-     "la   t0, g_stublookup\n"              /* t0=The base of the stub lookup table */
-#ifdef CONFIG_ARCH_RV32
-     "slli a0, a0, 2\n"                     /* a0=Offset for the stub lookup table */
-#else
-     "slli a0, a0, 3\n"                     /* a0=Offset for the stub lookup table */
-#endif
-     "add  t0, t0, a0\n"                    /* t0=The address in the table */
-     REGLOAD " t0, 0(t0)\n"                 /* t0=The address of the stub for this syscall */
-     "jalr ra, t0\n"                        /* Call the stub (modifies ra) */
-     REGLOAD " t0, %1(tp)\n"                /* Load tcb->flags */
-     "andi  t0, t0, ~%2\n"                  /* tcb->flags &= ~TCB_FLAG_SYSCALL */
-     REGSTORE " t0, %1(tp)\n"
-     : "+r"(a0)
-     : "i"(TCB_FLAGS_OFFSET),
-       "i"(TCB_FLAG_SYSCALL),
-       "i"(CONFIG_SYS_RESERVED),
-       "r"(a1), "r"(a2), "r"(a3), "r"(a4), "r"(a5), "r"(a6)
-     : "t0", "memory"
-  );
+  rtcb->xcp.sregs = context;
 
-  /* a0 gets clobbered below, save it locally here */
+  /* Indicate that we are in a syscall handler */
 
-  ret = a0;
+  rtcb->flags |= TCB_FLAG_SYSCALL;
+
+  /* Offset a0 to account for the reserved syscalls */
+
+  a0 -= CONFIG_SYS_RESERVED;
+
+  /* Run the system call, save return value locally */
+
+  ret = do_syscall(a0, a1, a2, a3, a4, a5, a6);
+
+  /* System call is now done */
+
+  rtcb->flags &= ~TCB_FLAG_SYSCALL;
 
   /* Unmask any pending signals now */
 
@@ -139,10 +187,6 @@ uintptr_t dispatch_syscall(unsigned int nbr, uintptr_t parm1,
 }
 #endif
 
-/****************************************************************************
- * Public Functions
- ****************************************************************************/
-
 /****************************************************************************
  * Name: riscv_swint
  *
@@ -155,8 +199,7 @@ uintptr_t dispatch_syscall(unsigned int nbr, uintptr_t parm1,
 int riscv_swint(int irq, void *context, void *arg)
 {
   uintreg_t *regs = (uintreg_t *)context;
-
-  DEBUGASSERT(regs && regs == CURRENT_REGS);
+  uintreg_t *new_regs = regs;
 
   /* Software interrupt 0 is invoked with REG_A0 (REG_X10) = system call
    * command and REG_A1-6 = variable number of
@@ -181,11 +224,6 @@ int riscv_swint(int irq, void *context, void *arg)
        *
        *   A0 = SYS_restore_context
        *   A1 = next
-       *
-       * In this case, we simply need to set CURRENT_REGS to restore register
-       * area referenced in the saved A1. context == CURRENT_REGS is the
-       * normal exception return.  By setting CURRENT_REGS = context[A1], we
-       * force the return to the saved context referenced in $a1.
        */
 
       case SYS_restore_context:
@@ -193,6 +231,7 @@ int riscv_swint(int irq, void *context, void *arg)
           struct tcb_s *next = (struct tcb_s *)(uintptr_t)regs[REG_A1];
 
           DEBUGASSERT(regs[REG_A1] != 0);
+          new_regs = next->xcp.regs;
           riscv_restorecontext(next);
         }
         break;
@@ -209,9 +248,7 @@ int riscv_swint(int irq, void *context, void *arg)
        *   A2 = next
        *
        * In this case, we save the context registers to the save register
-       * area referenced by the saved contents of R5 and then set
-       * CURRENT_REGS to the save register area referenced by the saved
-       * contents of R6.
+       * area referenced by the saved contents of R5.
        */
 
       case SYS_switch_context:
@@ -221,6 +258,7 @@ int riscv_swint(int irq, void *context, void *arg)
 
           DEBUGASSERT(regs[REG_A1] != 0 && regs[REG_A2] != 0);
           riscv_savecontext(prev);
+          new_regs = next->xcp.regs;
           riscv_restorecontext(next);
         }
         break;
@@ -248,7 +286,7 @@ int riscv_swint(int irq, void *context, void *arg)
 #ifdef CONFIG_ARCH_KERNEL_STACK
           /* Set the user stack pointer as we are about to return to user */
 
-          struct tcb_s *tcb  = nxsched_self();
+          struct tcb_s *tcb  = this_task();
           regs[REG_SP]       = (uintptr_t)tcb->xcp.ustkptr;
           tcb->xcp.ustkptr   = NULL;
 #endif
@@ -294,7 +332,7 @@ int riscv_swint(int irq, void *context, void *arg)
 #ifdef CONFIG_ARCH_KERNEL_STACK
           /* Set the user stack pointer as we are about to return to user */
 
-          struct tcb_s *tcb  = nxsched_self();
+          struct tcb_s *tcb  = this_task();
           regs[REG_SP]       = (uintptr_t)tcb->xcp.ustkptr;
           tcb->xcp.ustkptr   = NULL;
 #endif
@@ -329,7 +367,7 @@ int riscv_swint(int irq, void *context, void *arg)
 #ifndef CONFIG_BUILD_FLAT
       case SYS_signal_handler:
         {
-          struct tcb_s *rtcb   = nxsched_self();
+          struct tcb_s *rtcb   = this_task();
 
           /* Remember the caller's return address */
 
@@ -406,7 +444,7 @@ int riscv_swint(int irq, void *context, void *arg)
 #ifndef CONFIG_BUILD_FLAT
       case SYS_signal_handler_return:
         {
-          struct tcb_s *rtcb   = nxsched_self();
+          struct tcb_s *rtcb   = this_task();
 
           /* Set up to return to the kernel-mode signal dispatching logic. */
 
@@ -434,7 +472,6 @@ int riscv_swint(int irq, void *context, void *arg)
 #endif
 
       default:
-
         DEBUGPANIC();
         break;
     }
@@ -444,10 +481,10 @@ int riscv_swint(int irq, void *context, void *arg)
    */
 
 #ifdef CONFIG_DEBUG_SYSCALL_INFO
-  if (regs != CURRENT_REGS)
+  if (regs != new_regs)
     {
       svcinfo("SWInt Return: Context switch!\n");
-      up_dump_register(CURRENT_REGS);
+      up_dump_register(new_regs);
     }
   else
     {
@@ -455,5 +492,10 @@ int riscv_swint(int irq, void *context, void *arg)
     }
 #endif
 
+  if (regs != new_regs)
+    {
+      restore_critical_section(this_task(), this_cpu());
+    }
+
   return OK;
 }
