@@ -37,17 +37,26 @@
 
 void *riscv_perform_syscall(uintreg_t *regs)
 {
+  struct tcb_s **running_task = &g_running_tasks[this_cpu()];
+  struct tcb_s *tcb;
+
+  if (*running_task != NULL)
+    {
+      (*running_task)->xcp.regs = regs;
+    }
+
   /* Set up the interrupt register set needed by swint() */
 
-  CURRENT_REGS = regs;
+  up_set_current_regs(regs);
 
   /* Run the system call handler (swint) */
 
   riscv_swint(0, regs, NULL);
+  tcb = this_task();
 
-#ifdef CONFIG_ARCH_ADDRENV
-  if (regs != CURRENT_REGS)
+  if ((*running_task) != tcb)
     {
+#ifdef CONFIG_ARCH_ADDRENV
       /* Make sure that the address environment for the previously
        * running task is closed down gracefully (data caches dump,
        * MMU flushed) and set up the address environment for the new
@@ -55,31 +64,16 @@ void *riscv_perform_syscall(uintreg_t *regs)
        */
 
       addrenv_switch(NULL);
-    }
 #endif
 
-  if (regs != CURRENT_REGS)
-    {
       /* Record the new "running" task.  g_running_tasks[] is only used by
        * assertion logic for reporting crashes.
        */
 
-      g_running_tasks[this_cpu()] = this_task();
-
-      /* Restore the cpu lock */
-
-      restore_critical_section();
-
-      /* If a context switch occurred while processing the interrupt then
-       * CURRENT_REGS may have change value.  If we return any value
-       * different from the input regs, then the lower level will know
-       * that a context switch occurred during interrupt processing.
-       */
-
-      regs = (uintreg_t *)CURRENT_REGS;
+      *running_task = tcb;
     }
 
-  CURRENT_REGS = NULL;
+  up_set_current_regs(NULL);
 
-  return regs;
+  return tcb->xcp.regs;
 }
