@@ -27,10 +27,32 @@
 
 /* Register Base Address ****************************************************/
 
-#define QEMU_RV_CLINT_BASE   0x02000000
-#define QEMU_RV_ACLINT_BASE  0x02f00000
-#define QEMU_RV_PLIC_BASE    0x0c000000
+#ifdef CONFIG_ARCH_CHIP_QEMU_RV_PLIC
+#  define QEMU_RV_PLIC_BASE    CONFIG_ARCH_CHIP_QEMU_RV_PLIC
+#else
+#  define QEMU_RV_PLIC_BASE    0xc000000
+#endif
 
-#define QEMU_RV_RESET_BASE   0x100000
+#ifdef CONFIG_ARCH_CHIP_QEMU_RV_CLINT
+#  define QEMU_RV_CLINT_BASE   CONFIG_ARCH_CHIP_QEMU_RV_CLINT
+#else
+#  define QEMU_RV_CLINT_BASE   0x2000000
+#endif
+
+#ifdef CONFIG_ARCH_CHIP_QEMU_RV_ACLINT
+#  define QEMU_RV_ACLINT_BASE  CONFIG_ARCH_CHIP_QEMU_RV_ACLINT
+#else
+#  define QEMU_RV_ACLINT_BASE  0x2f00000
+#endif
+
+#define   QEMU_RV_RESET_BASE   0x100000
+
+#ifdef CONFIG_ARCH_USE_S_MODE
+#  define QEMU_RV_APLIC_BASE   0x0d000000
+#  define QEMU_RV_IMSIC_BASE   0x28000000
+#else
+#  define QEMU_RV_APLIC_BASE   0x0c000000
+#  define QEMU_RV_IMSIC_BASE   0x24000000
+#endif
 
 #endif /* __ARCH_RISCV_SRC_QEMU_RV_HARDWARE_QEMU_RV_MEMORYMAP_H */
