@@ -32,6 +32,7 @@
 #include <sys/types.h>
 
 #include "riscv_internal.h"
+#include "riscv_aia.h"
 #include "hardware/qemu_rv_memorymap.h"
 #include "hardware/qemu_rv_plic.h"
 
@@ -39,49 +40,102 @@
  * Pre-processor Definitions
  ****************************************************************************/
 
-#ifdef CONFIG_ARCH_RV32
-#  define RV_IRQ_MASK 27
-#else
-#  define RV_IRQ_MASK 59
-#endif
-
 /****************************************************************************
  * Public Functions
  ****************************************************************************/
 
-/****************************************************************************
- * riscv_dispatch_irq
- ****************************************************************************/
-
-void *riscv_dispatch_irq(uintreg_t vector, uintreg_t *regs)
+#ifdef CONFIG_ARCH_RV_HAVE_IMSIC
+static void *riscv_dispatch_irq_ext(uintreg_t irq, uintreg_t *regs)
 {
-  int irq = (vector >> RV_IRQ_MASK) | (vector & 0xf);
+  int extirq;
 
-  /* Firstly, check if the irq is machine external interrupt */
-
-  if (RISCV_IRQ_EXT == irq)
+  while ((extirq = SWAP_CSR(CSR_TOPEI, 0)) != 0)
     {
-      uintptr_t val = getreg32(QEMU_RV_PLIC_CLAIM);
+      extirq = (extirq >> TOPI_IID_SHIFT) + irq;
+      regs = riscv_doirq(extirq, regs);
+    }
 
-      /* Add the value to nuttx irq which is offset to the mext */
+  return regs;
+}
+#elif defined(CONFIG_ARCH_RV_HAVE_APLIC)
+static void *riscv_dispatch_irq_ext(uintreg_t irq, uintreg_t *regs)
+{
+  int extirq;
+  int hartid = riscv_mhartid();
+  uintptr_t aplic_base = RISCV_APLIC_IDC(QEMU_RV_APLIC_BASE, hartid) +
+                            RISCV_APLIC_IDC_CLAIMI;
 
-      irq += val;
+  while ((extirq = getreg32(aplic_base)) != 0)
+    {
+      extirq = (extirq >> RISCV_APLIC_IDC_TOPI_ID_SHIFT) + irq;
+      regs = riscv_doirq(extirq, regs);
     }
 
-  /* EXT means no interrupt */
+  return regs;
+}
+#else
+static void *riscv_dispatch_irq_ext(uintreg_t irq, uintreg_t *regs)
+{
+  int extirq;
 
-  if (RISCV_IRQ_EXT != irq)
+  while ((extirq = getreg32(QEMU_RV_PLIC_CLAIM)) != 0)
     {
-      /* Deliver the IRQ */
+      regs = riscv_doirq(irq + extirq, regs);
+      putreg32(extirq, QEMU_RV_PLIC_CLAIM);
+    }
+
+  return regs;
+}
+#endif
+
+#ifdef CONFIG_ARCH_RV_EXT_AIA
+static void *riscv_dispatch_async_irq(uintreg_t irq, uintreg_t *regs)
+{
+  while ((irq = READ_CSR(CSR_TOPI)) != 0)
+    {
+      irq = (irq >> TOPI_IID_SHIFT) + RISCV_IRQ_ASYNC;
+
+      if (RISCV_IRQ_EXT == irq)
+        {
+          regs = riscv_dispatch_irq_ext(irq, regs);
+        }
+      else
+        {
+          regs = riscv_doirq(irq, regs);
+        }
+    }
+
+  return regs;
+}
+#else
+static void *riscv_dispatch_async_irq(uintreg_t irq, uintreg_t *regs)
+{
+  irq += RISCV_IRQ_ASYNC;
 
+  if (irq == RISCV_IRQ_EXT)
+    {
+      regs = riscv_dispatch_irq_ext(irq, regs);
+    }
+  else
+    {
       regs = riscv_doirq(irq, regs);
     }
+
+  return regs;
+}
+#endif
+
+void *riscv_dispatch_irq(uintreg_t vector, uintreg_t *regs)
+{
+  int irq = vector & (~RISCV_IRQ_BIT);
 
-  if (RISCV_IRQ_EXT <= irq)
+  if ((vector & RISCV_IRQ_BIT) != 0)
     {
-      /* Then write PLIC_CLAIM to clear pending in PLIC */
-
-      putreg32(irq - RISCV_IRQ_EXT, QEMU_RV_PLIC_CLAIM);
+      regs = riscv_dispatch_async_irq(irq, regs);
+    }
+  else
+    {
+      regs = riscv_doirq(irq, regs);
     }
 
   return regs;
