@@ -26,7 +26,7 @@
 #include <nuttx/drivers/addrenv.h>
 #include <nuttx/rptun/rptun.h>
 #include <nuttx/list.h>
-#include <nuttx/wqueue.h>
+#include <nuttx/wdog.h>
 
 #include "sim_internal.h"
 
@@ -40,17 +40,25 @@
 #define SIM_RPTUN_SHIFT     16
 #define SIM_RPTUN_WORK_DELAY 1
 
+/* Status byte for master/slave to report progress */
+
+#define SIM_RPTUN_STATUS_BOOT        0x01
+#define SIM_RPTUN_STATUS_OK          0x02
+#define SIM_RPTUN_STATUS_NEED_RESET  0x04
+
 /****************************************************************************
  * Private Types
  ****************************************************************************/
 
 struct sim_rptun_shmem_s
 {
-  volatile uintptr_t        base;
-  volatile unsigned int     seqs;
-  volatile unsigned int     seqm;
-  volatile unsigned int     cmds;
-  volatile unsigned int     cmdm;
+  volatile uint64_t         base;
+  volatile uint32_t         seqs;
+  volatile uint32_t         seqm;
+  volatile uint32_t         cmds;
+  volatile uint32_t         cmdm;
+  volatile uint32_t         boots;
+  volatile uint32_t         bootm;
   struct rptun_rsc_s        rsc;
   char                      buf[0x10000];
 };
@@ -61,16 +69,16 @@ struct sim_rptun_dev_s
   rptun_callback_t          callback;
   void                     *arg;
   int                       master;
-  unsigned int              seq;
+  uint32_t                  seq;
   struct sim_rptun_shmem_s *shmem;
   struct simple_addrenv_s   addrenv[2];
   char                      cpuname[RPMSG_NAME_SIZE + 1];
   char                      shmemname[RPMSG_NAME_SIZE + 1];
   pid_t                     pid;
 
-  /* Work queue for transmit */
+  /* Wdog for transmit */
 
-  struct work_s             worker;
+  struct wdog_s             wdog;
 };
 
 /****************************************************************************
@@ -91,24 +99,19 @@ sim_rptun_get_resource(struct rptun_dev_s *dev)
   struct sim_rptun_dev_s *priv = container_of(dev,
                                  struct sim_rptun_dev_s, rptun);
 
-  if (priv->shmem)
-    {
-      return &priv->shmem->rsc;
-    }
+  priv->shmem = host_allocshmem(priv->shmemname,
+                                sizeof(*priv->shmem));
 
-  while (priv->shmem == NULL)
+  if (!priv->shmem)
     {
-      priv->shmem = host_allocshmem(priv->shmemname,
-                                    sizeof(*priv->shmem),
-                                    priv->master);
-      usleep(1000);
-
-      /* Master isn't ready, sleep and try again */
+      return NULL;
     }
 
   if (priv->master)
     {
       struct rptun_rsc_s *rsc = &priv->shmem->rsc;
+      memset(priv->shmem->buf, 0, sizeof(priv->shmem->buf));
+      memset(rsc, 0, sizeof(struct rptun_rsc_s));
 
       rsc->rsc_tbl_hdr.ver          = 1;
       rsc->rsc_tbl_hdr.num          = 1;
@@ -121,9 +124,11 @@ sim_rptun_get_resource(struct rptun_dev_s *dev)
                                     | 1 << VIRTIO_RPMSG_F_BUFSZ;
       rsc->rpmsg_vdev.config_len    = sizeof(struct fw_rsc_config);
       rsc->rpmsg_vdev.num_of_vrings = 2;
+      rsc->rpmsg_vring0.da          = 0;
       rsc->rpmsg_vring0.align       = 8;
       rsc->rpmsg_vring0.num         = 8;
       rsc->rpmsg_vring0.notifyid    = RSC_NOTIFY_ID_ANY;
+      rsc->rpmsg_vring1.da          = 0;
       rsc->rpmsg_vring1.align       = 8;
       rsc->rpmsg_vring1.num         = 8;
       rsc->rpmsg_vring1.notifyid    = RSC_NOTIFY_ID_ANY;
@@ -131,21 +136,41 @@ sim_rptun_get_resource(struct rptun_dev_s *dev)
       rsc->config.h2r_buf_size      = 0x800;
 
       priv->shmem->base             = (uintptr_t)priv->shmem;
+
+      /* The master notifies its slave when it starts again */
+
+      if (priv->shmem->boots & SIM_RPTUN_STATUS_OK)
+        {
+          priv->shmem->boots = SIM_RPTUN_STATUS_NEED_RESET;
+        }
+
+      priv->shmem->bootm = SIM_RPTUN_STATUS_BOOT;
     }
   else
     {
+      /* The slave notifies its master when it starts again */
+
+      if (priv->shmem->boots & SIM_RPTUN_STATUS_OK)
+        {
+          priv->shmem->bootm = SIM_RPTUN_STATUS_NEED_RESET;
+        }
+
+      priv->shmem->boots = SIM_RPTUN_STATUS_BOOT;
+
       /* Wait untils master is ready */
 
-      while (priv->shmem->base == 0)
+      while (!(priv->shmem->bootm & SIM_RPTUN_STATUS_OK))
         {
           usleep(1000);
         }
 
+      priv->shmem->boots = SIM_RPTUN_STATUS_OK;
+
       priv->addrenv[0].va          = (uintptr_t)priv->shmem;
       priv->addrenv[0].pa          = priv->shmem->base;
       priv->addrenv[0].size        = sizeof(*priv->shmem);
 
-      simple_addrenv_initialize(priv->addrenv);
+      simple_addrenv_initialize(&priv->addrenv[0]);
     }
 
   return &priv->shmem->rsc;
@@ -180,6 +205,14 @@ static int sim_rptun_start(struct rptun_dev_s *dev)
       priv->pid = pid;
     }
 
+  /* Wait until slave has started */
+
+  while (!(priv->shmem->boots & SIM_RPTUN_STATUS_BOOT))
+    {
+      usleep(1000);
+    }
+
+  priv->shmem->bootm = SIM_RPTUN_STATUS_OK;
   return 0;
 }
 
@@ -188,13 +221,21 @@ static int sim_rptun_stop(struct rptun_dev_s *dev)
   struct sim_rptun_dev_s *priv = container_of(dev,
                               struct sim_rptun_dev_s, rptun);
 
-  if ((priv->master & SIM_RPTUN_BOOT) && (priv->pid > 0))
+  /* Don't send SIM_RPTUN_STOP when slave recovery */
+
+  if (priv->shmem->boots & SIM_RPTUN_STATUS_OK)
     {
       priv->shmem->cmdm = SIM_RPTUN_STOP << SIM_RPTUN_SHIFT;
+    }
+
+  if ((priv->master & SIM_RPTUN_BOOT) && priv->pid > 0)
+    {
       host_waitpid(priv->pid);
     }
 
-  if (priv->shmem)
+  /* Master cleans shmem when both sides are about to exit */
+
+  if (priv->shmem && (priv->shmem->boots & SIM_RPTUN_STATUS_OK))
     {
       host_freeshmem(priv->shmem);
       priv->shmem = NULL;
@@ -267,9 +308,25 @@ static void sim_rptun_check_cmd(struct sim_rptun_dev_s *priv)
     }
 }
 
-static void sim_rptun_work(void *arg)
+static void sim_rptun_check_reset(struct sim_rptun_dev_s *priv)
 {
-  struct sim_rptun_dev_s *dev = arg;
+  if (priv->master &&
+      (priv->shmem->bootm & SIM_RPTUN_STATUS_NEED_RESET))
+    {
+      priv->shmem->bootm = 0;
+      rptun_boot(priv->cpuname);
+    }
+  else if (!priv->master &&
+           (priv->shmem->boots & SIM_RPTUN_STATUS_NEED_RESET))
+    {
+      priv->shmem->boots = 0;
+      rptun_boot(priv->cpuname);
+    }
+}
+
+static void sim_rptun_work(wdparm_t arg)
+{
+  struct sim_rptun_dev_s *dev = (struct sim_rptun_dev_s *)arg;
 
   if (dev->shmem != NULL)
     {
@@ -277,6 +334,10 @@ static void sim_rptun_work(void *arg)
 
       sim_rptun_check_cmd(dev);
 
+      /* Check if master/slave need to reset */
+
+      sim_rptun_check_reset(dev);
+
       if (dev->master && dev->seq != dev->shmem->seqs)
         {
           dev->seq = dev->shmem->seqs;
@@ -294,8 +355,7 @@ static void sim_rptun_work(void *arg)
         }
     }
 
-  work_queue(HPWORK, &dev->worker,
-            sim_rptun_work, dev, SIM_RPTUN_WORK_DELAY);
+  wd_start(&dev->wdog, SIM_RPTUN_WORK_DELAY, sim_rptun_work, (wdparm_t)dev);
 }
 
 /****************************************************************************
@@ -342,5 +402,5 @@ int sim_rptun_init(const char *shmemname, const char *cpuname, int master)
       return ret;
     }
 
-  return work_queue(HPWORK, &dev->worker, sim_rptun_work, dev, 0);
+  return wd_start(&dev->wdog, 0, sim_rptun_work, (wdparm_t)dev);
 }
