@@ -29,6 +29,9 @@
 #include <netinet/if_ether.h>
 #include <nuttx/wireless/wireless.h>
 #include <nuttx/net/netdev_lowerhalf.h>
+#include <netpacket/netlink.h>
+#include <nuttx/net/netlink.h>
+#include <sys/time.h>
 
 #include "sim_internal.h"
 
@@ -159,7 +162,7 @@ struct sim_netdev_s
   char bssid[ETH_ALEN];
   uint16_t channel;
   uint32_t freq;
-  uint8_t password[64];
+  char password[64];
   int key_mgmt;
   int proto;
   int auth_alg;
@@ -174,6 +177,24 @@ struct sim_netdev_s
   bool psk_flag;                /* for psk, 0: unset, 1: set */
   char host_ifname[IFNAMSIZ];   /* The wlan interface name on the host */
   uint8_t network_id;           /* for sta, default is 0 */
+  hrtime_t scantime;
+};
+
+/* for wireless event */
+
+struct wireless_event_s
+{
+  struct nlmsghdr  hdr;         /* netlink message header */
+  struct ifinfomsg iface;       /* interface info */
+
+  struct rtattr    attrevent;   /* IFLA_WIRELESS */
+  struct iw_event  event;       /* wireless event */
+};
+
+struct wireless_event_list_s
+{
+  sq_entry_t flink;
+  struct wireless_event_s payload;
 };
 
 /****************************************************************************
@@ -890,6 +911,40 @@ static bool get_wpa_state(struct sim_netdev_s *wifidev)
   return false;
 }
 
+static bool get_wpa_bssid(struct sim_netdev_s *wifidev,
+                          unsigned char *bssid)
+{
+  int ret;
+  char rbuf[BUF_LEN];
+
+  ret = get_cmd(wifidev, rbuf, BUF_LEN, "%s",
+                "status | grep bssid | awk -F'=' '{print $2}'");
+  if (ret > 0)
+    {
+      mac_addr_a2n(bssid, rbuf);
+      return true;
+    }
+
+  return false;
+}
+
+static bool get_wpa_rssi(struct sim_netdev_s *wifidev, int32_t *rssi)
+{
+  int ret;
+  char rbuf[BUF_LEN];
+
+  ret = host_system(rbuf, BUF_LEN, "iwconfig wlan%d | grep level "
+                    "| awk '{print $4}'| awk -F'=' '{print $2}'",
+                    wifidev->devidx);
+  if (ret > 0)
+    {
+      *rssi = atoi(rbuf);
+      return true;
+    }
+
+  return false;
+}
+
 static void get_wpa_ssid(struct sim_netdev_s *wifidev,
                          struct iw_point *essid)
 {
@@ -964,11 +1019,65 @@ static int freq_to_channel(uint16_t freq)
   return OK;
 }
 
+static int wifi_send_event(struct net_driver_s *dev, unsigned int cmd,
+                           union iwreq_data *wrqu)
+{
+  struct wireless_event_list_s *alloc;
+  struct wireless_event_s *wev;
+
+  DEBUGASSERT(dev != NULL);
+
+  int up = IFF_IS_UP(dev->d_flags);
+
+  /* Allocate the response buffer */
+
+  alloc = (struct wireless_event_list_s *)
+          kmm_zalloc(RTA_SPACE(sizeof(struct wireless_event_list_s)));
+  if (alloc == NULL)
+    {
+      nerr("ERROR: Failed to allocate wifi event buffer.\n");
+      return -ENOMEM;
+    }
+
+  /* Initialize the response buffer */
+
+  wev                   = &alloc->payload;
+
+  wev->hdr.nlmsg_len    = sizeof(struct wireless_event_s);
+  wev->hdr.nlmsg_type   = up ? RTM_NEWLINK : RTM_DELLINK;
+  wev->hdr.nlmsg_flags  = 0;
+  wev->hdr.nlmsg_seq    = 0;
+  wev->hdr.nlmsg_pid    = 0;
+
+  wev->iface.ifi_family = AF_UNSPEC;
+  wev->iface.ifi_type   = ARPHRD_IEEE80211;
+#ifdef CONFIG_NETDEV_IFINDEX
+  wev->iface.ifi_index  = dev->d_ifindex;
+#endif
+  wev->iface.ifi_flags  = dev->d_flags;
+  wev->iface.ifi_change = 0;
+
+  /* add wireless event info */
+
+  wev->attrevent.rta_len  = RTA_SPACE(sizeof(struct iw_event));
+  wev->attrevent.rta_type = IFLA_WIRELESS;
+  wev->event.len          = sizeof(union iwreq_data);
+  wev->event.cmd          = cmd;
+
+  memset(&wev->event.u, 0, sizeof(union iwreq_data));
+  memcpy(&wev->event.u, ((char *)wrqu), sizeof(union iwreq_data));
+
+  netlink_add_broadcast(RTNLGRP_LINK,
+                        (struct netlink_response_s *)alloc);
+  return OK;
+}
+
 static int wifidriver_start_scan(struct sim_netdev_s *wifidev,
                                  struct iwreq *pwrq)
 {
   int ret;
   uint8_t  mode = wifidev->mode;
+  hrtime_t curtime;
 
   if (mode == IW_MODE_MASTER)
     {
@@ -976,6 +1085,13 @@ static int wifidriver_start_scan(struct sim_netdev_s *wifidev,
     }
   else if (mode == IW_MODE_INFRA)
     {
+      curtime = gethrtime();
+      if (wifidev->scantime && wifidev->scantime - curtime >= 5000000000)
+        {
+          return OK;
+        }
+
+      wifidev->scantime = curtime;
       ret = set_cmd(wifidev, "scan");
       if (ret == -EINVAL)
         {
@@ -1003,6 +1119,11 @@ static int wifidriver_scan_result(struct sim_netdev_s *wifidev,
     }
   else if (wifidev->mode == IW_MODE_INFRA)
     {
+      if (wifidev->scantime && wifidev->scantime - gethrtime() < 5000000000)
+        {
+          return -EAGAIN;
+        }
+
       scan_req.buf = pwrq->u.data.pointer;
       scan_req.total_len = pwrq->u.data.length;
       scan_req.cur_len = 0;
@@ -1103,16 +1224,16 @@ static int wifidriver_get_auth(struct sim_netdev_s *wifidev,
 static int wifidriver_set_psk(struct sim_netdev_s *wifidev,
                               struct iwreq *pwrq)
 {
-  char psk_buf[64];
   struct iw_encode_ext *ext;
   int ret = 0;
 
   ext = (struct iw_encode_ext *)pwrq->u.encoding.pointer;
 
-  memset(psk_buf, 0, sizeof(psk_buf));
-  memcpy(psk_buf, ext->key, ext->key_len);
+  memset(wifidev->password, 0, sizeof(wifidev->password));
+  memcpy(wifidev->password, ext->key, ext->key_len);
 
-  ninfo("psk=%s, key_len= %d, alg=%u\n", psk_buf, ext->key_len, ext->alg);
+  ninfo("psk=%s, key_len= %d, alg=%u\n", wifidev->password,
+        ext->key_len, ext->alg);
 
   /* set auth_alg */
 
@@ -1127,11 +1248,13 @@ static int wifidriver_set_psk(struct sim_netdev_s *wifidev,
       return -ENOSYS;
     }
 
+  wifidev->auth_alg = ext->alg;
+
   switch (wifidev->mode)
     {
     case IW_MODE_INFRA:
       WPA_SET_NETWORK(wifidev, "auth_alg %s", get_auth_algstr(ext->alg));
-      WPA_SET_NETWORK(wifidev, "psk \\\"%s\\\"", psk_buf);
+      WPA_SET_NETWORK(wifidev, "psk \\\"%s\\\"", wifidev->password);
       WPA_SET_NETWORK(wifidev, "key_mgmt %s", "WPA-PSK WPA-EAP");
 
       /* Set the psk flag for security ap. */
@@ -1142,7 +1265,7 @@ static int wifidriver_set_psk(struct sim_netdev_s *wifidev,
 
        /* set wpa_passphrase psk_buf */
 
-      ret = set_cmd(wifidev, "set wpa_passphrase %s", psk_buf);
+      ret = set_cmd(wifidev, "set wpa_passphrase %s", wifidev->password);
       wifidev->psk_flag = 1;
       break;
     default:
@@ -1152,6 +1275,42 @@ static int wifidriver_set_psk(struct sim_netdev_s *wifidev,
   return ret ;
 }
 
+static int wifidriver_get_psk(struct sim_netdev_s *wifidev,
+                              struct iwreq *pwrq)
+{
+  struct iw_encode_ext *ext;
+  int ret = 0;
+  int len;
+  int size;
+
+  ext = (struct iw_encode_ext *)pwrq->u.encoding.pointer;
+  len = pwrq->u.encoding.length - sizeof(*ext);
+
+  switch (wifidev->mode)
+    {
+    case IW_MODE_INFRA:
+      size = strnlen(wifidev->password, 64);
+      if (len < size)
+        {
+          return -EINVAL;
+        }
+      else
+        {
+          ext->key_len = size;
+          memcpy(ext->key, wifidev->password, ext->key_len);
+          ext->alg = wifidev->auth_alg;
+        }
+      break;
+
+    case IW_MODE_MASTER:
+      break;
+    default:
+      break;
+    }
+
+  return ret ;
+}
+
 static int wifidriver_set_essid(struct sim_netdev_s *wifidev,
                              struct iwreq *pwrq)
 {
@@ -1282,8 +1441,42 @@ static int wifidriver_set_bssid(struct sim_netdev_s *wifidev,
   return ret;
 }
 
+static int wifidriver_get_bssid(struct sim_netdev_s *wifidev,
+                                struct iwreq *pwrq)
+{
+  struct sockaddr *sockaddr = &pwrq->u.ap_addr;
+  unsigned char *bssid = (unsigned char *)sockaddr->sa_data;
+  int ret;
+
+  switch (wifidev->mode)
+    {
+      case IW_MODE_INFRA:
+        if (get_wpa_state(wifidev) && get_wpa_bssid(wifidev, bssid))
+          {
+            ret = OK;
+          }
+        else
+          {
+            ret = -ENOTTY;
+          }
+        break;
+
+      case IW_MODE_MASTER:
+        ret = -ENOSYS;
+        break;
+
+      default:
+        ret = -EINVAL;
+        break;
+    }
+
+  return ret;
+}
+
 static int wifidriver_start_connect(struct sim_netdev_s *wifidev)
 {
+  int timeout = 10;
+
   switch (wifidev->mode)
     {
     case IW_MODE_INFRA:
@@ -1300,7 +1493,28 @@ static int wifidriver_start_connect(struct sim_netdev_s *wifidev)
         {
           wifidev->psk_flag = 0;
         }
-      break;
+
+      /* Wait the connect sucess. */
+
+      while (timeout--)
+        {
+           if (get_wpa_state(wifidev))
+             {
+               unsigned char bssid[ETH_ALEN];
+               union iwreq_data wrqu;
+
+               get_wpa_bssid(wifidev, bssid);
+
+               memset(&wrqu, 0, sizeof(wrqu));
+               memcpy(wrqu.ap_addr.sa_data, bssid, ETH_ALEN);
+               wifi_send_event(&wifidev->dev.netdev, SIOCGIWAP, &wrqu);
+               return OK;
+             }
+
+           sleep(1);
+        }
+
+      return ERROR;
     case IW_MODE_MASTER:
 
       set_cmd(wifidev, "disable");
@@ -1350,12 +1564,15 @@ static int wifidriver_set_mode(struct sim_netdev_s *wifidev,
 {
   int ret;
 
-  /* IW_MODE_INFRA indicates station */
-
-  wifidev->mode = pwrq->u.mode;
-  switch (wifidev->mode)
+  switch (pwrq->u.mode)
     {
     case IW_MODE_INFRA:
+      if (wifidev->mode == IW_MODE_INFRA)
+        {
+          return OK;
+        }
+
+      wifidev->mode = pwrq->u.mode;
 
       /* Start the sta config, including wpa_supplicant and udhcpc. */
 
@@ -1369,22 +1586,30 @@ static int wifidriver_set_mode(struct sim_netdev_s *wifidev,
           */
 
           int num;
-          int network_id = 0;
 
           num = wpa_get_network_num(wifidev);
           if (num < 1)
             {
-              network_id = wpa_add_network(wifidev);
+              ret = wpa_add_network(wifidev);
             }
           else
             {
-              network_id = wpa_get_last_network_id(wifidev, num);
+              ret = wpa_get_last_network_id(wifidev, num);
             }
 
-          wifidev->network_id = network_id;
+          if (ret >= 0)
+            {
+              wifidev->network_id = ret;
+            }
         }
       break;
     case IW_MODE_MASTER:
+      if (wifidev->mode == IW_MODE_MASTER)
+        {
+          return OK;
+        }
+
+      wifidev->mode = pwrq->u.mode;
 
       /* Start the hostapd. */
 
@@ -1459,6 +1684,32 @@ static int wifidriver_get_country(struct sim_netdev_s *wifidev,
   return ret;
 }
 
+static int wifidriver_get_sensitivity(struct sim_netdev_s *wifidev,
+                                      struct iwreq *pwrq)
+{
+  int32_t rssi;
+  int ret;
+
+  if (wifidev->mode != IW_MODE_INFRA)
+    {
+      return OK;
+    }
+
+  if (get_wpa_state(wifidev) && get_wpa_rssi(wifidev, &rssi))
+    {
+      pwrq->u.sens.value = -rssi;
+      ret = OK;
+
+      ninfo("get rssi is %"PRId32 "\n", pwrq->u.sens.value);
+    }
+  else
+    {
+      ret = -ENOTTY;
+    }
+
+  return ret;
+}
+
 int wifidriver_set_freq(struct sim_netdev_s *wifidev, struct iwreq *pwrq)
 {
   int channel;
@@ -1547,11 +1798,15 @@ static int wifidriver_connect(struct netdev_lowerhalf_s *dev)
 static int wifidriver_disconnect(struct netdev_lowerhalf_s *dev)
 {
   int ret;
+  union iwreq_data wrqu;
 
   ret = wifidriver_start_disconnect((struct sim_netdev_s *)dev);
   if (ret >= 0)
     {
       netdev_lower_carrier_off(dev);
+      memset(&wrqu, 0, sizeof(wrqu));
+      wrqu.ap_addr.sa_family = ARPHRD_ETHER;
+      wifi_send_event(&dev->netdev, SIOCGIWAP, &wrqu);
     }
 
   return ret;
@@ -1588,7 +1843,7 @@ static int wifidriver_bssid(struct netdev_lowerhalf_s *dev,
     }
   else
     {
-      return -ENOTTY;
+      ret = wifidriver_get_bssid(wifidev, iwr);
     }
 
   return ret;
@@ -1603,7 +1858,7 @@ static int wifidriver_passwd(struct netdev_lowerhalf_s *dev,
     }
   else
     {
-      return -ENOTTY;
+      return wifidriver_get_psk((struct sim_netdev_s *)dev, iwr);
     }
 }
 
@@ -1682,7 +1937,16 @@ static int wifidriver_country(struct netdev_lowerhalf_s *dev,
 static int wifidriver_sensitivity(struct netdev_lowerhalf_s *dev,
                                   struct iwreq *iwr, bool set)
 {
-  return -ENOTTY;
+  struct sim_netdev_s *wifidev = (struct sim_netdev_s *)dev;
+
+  if (set)
+    {
+      return -ENOTTY;
+    }
+  else
+    {
+      return wifidriver_get_sensitivity(wifidev, iwr);
+    }
 }
 
 static int wifidriver_scan(struct netdev_lowerhalf_s *dev,
