@@ -64,31 +64,31 @@ uint32_t *sparc_doirq(int irq, uint32_t *regs)
 #else
   regs = (uint32_t *)((uint32_t)regs + CPU_MINIMUM_STACK_FRAME_SIZE);
   /* Current regs non-zero indicates that we are processing an interrupt;
-   * CURRENT_REGS is also used to manage interrupt level context switches.
+   * current_regs is also used to manage interrupt level context switches.
    *
    * Nested interrupts are not supported.
    */
 
-  DEBUGASSERT(CURRENT_REGS == NULL);
-  CURRENT_REGS = regs;
+  DEBUGASSERT(up_current_regs() == NULL);
+  up_set_current_regs(regs);
 
   /* Deliver the IRQ */
 
   irq_dispatch(irq, regs);
 
   /* Check for a context switch.  If a context switch occurred, then
-   * CURRENT_REGS will have a different value than it did on entry.
+   * current_regs will have a different value than it did on entry.
    * If an interrupt level context switch has occurred, then restore
    * the floating point state and the establish the correct address
    * environment before returning from the interrupt.
    */
 
-  if (regs != CURRENT_REGS)
+  if (regs != up_current_regs())
     {
 #ifdef CONFIG_ARCH_FPU
       /* Restore floating point registers */
 
-      up_restorefpu((uint32_t *)CURRENT_REGS);
+      up_restorefpu(up_current_regs());
 #endif
 
 #ifdef CONFIG_ARCH_ADDRENV
@@ -110,26 +110,19 @@ uint32_t *sparc_doirq(int irq, uint32_t *regs)
     }
 
   /* If a context switch occurred while processing the interrupt then
-   * CURRENT_REGS may have change value.  If we return any value different
+   * current_regs may have change value.  If we return any value different
    * from the input regs, then the lower level will know that a context
    * switch occurred during interrupt processing.
    */
 
-  regs = (uint32_t *)((uint32_t)CURRENT_REGS -
+  regs = (uint32_t *)((uint32_t)up_current_regs() -
                                 CPU_MINIMUM_STACK_FRAME_SIZE);
 
-  /* Restore the cpu lock */
-
-  if (regs != CURRENT_REGS)
-    {
-      restore_critical_section();
-    }
-
-  /* Set CURRENT_REGS to NULL to indicate that we are no longer in an
+  /* Set current_regs to NULL to indicate that we are no longer in an
    * interrupt handler.
    */
 
-  CURRENT_REGS = NULL;
+  up_set_current_regs(NULL);
 #endif
   board_autoled_off(LED_INIRQ);
   return regs;
