@@ -73,7 +73,7 @@ int sparc_swint1(int irq, void *context, void *arg)
 {
   uint32_t *regs = (uint32_t *)context;
 
-  DEBUGASSERT(regs && regs == CURRENT_REGS);
+  DEBUGASSERT(regs && regs == up_current_regs());
 
   /* Software interrupt 0 is invoked with REG_A0 (REG_R4) = system call
    * command and REG_A1-3 and REG_T0-2 (REG_R5-10) = variable number of
@@ -119,7 +119,7 @@ int sparc_swint1(int irq, void *context, void *arg)
        *   A0 = SYS_restore_context
        *   A1 = restoreregs
        *
-       * In this case, we simply need to set CURRENT_REGS to restore
+       * In this case, we simply need to set current_regs to restore
        * register area referenced in the saved R1. context == g_current
        * regs is the normal exception return.  By setting g_current
        * regs = context[R1], we force the return to the saved context
@@ -129,7 +129,7 @@ int sparc_swint1(int irq, void *context, void *arg)
       case SYS_restore_context:
         {
           DEBUGASSERT(regs[REG_I1] != 0);
-          CURRENT_REGS = (uint32_t *)regs[REG_I1];
+          up_set_current_regs((uint32_t *)regs[REG_I1]);
         }
         break;
 
@@ -146,7 +146,7 @@ int sparc_swint1(int irq, void *context, void *arg)
        *
        * In this case, we save the context registers to the save register
        * area referenced by the saved contents of R5 and then set
-       * CURRENT_REGS to the save register area referenced by the saved
+       * current_regs to the save register area referenced by the saved
        * contents of R6.
        */
 
@@ -157,7 +157,7 @@ int sparc_swint1(int irq, void *context, void *arg)
 
           /* task_flush_trap(regs,(uint32_t *)regs[REG_I2]); */
 
-          CURRENT_REGS = (uint32_t *)regs[REG_I2];
+          up_set_current_regs((uint32_t *)regs[REG_I2]);
         }
         break;
 
@@ -187,7 +187,7 @@ int sparc_swint1(int irq, void *context, void *arg)
            * the original mode.
            */
 
-          CURRENT_REGS[REG_I7] = rtcb->xcp.syscall[index].sysreturn;
+          up_current_regs()[REG_I7] = rtcb->xcp.syscall[index].sysreturn;
 #error "Missing logic -- need to restore the original mode"
           rtcb->xcp.nsyscalls   = index;
         }
@@ -202,7 +202,7 @@ int sparc_swint1(int irq, void *context, void *arg)
 
           /* Verify that the SYS call number is within range */
 
-          DEBUGASSERT(CURRENT_REGS[REG_I1] < SYS_maxsyscall);
+          DEBUGASSERT(up_current_regs()[REG_I1] < SYS_maxsyscall);
 
           /* Make sure that we got here that there is a no saved syscall
            * return address.  We cannot yet handle nested system calls.
@@ -221,7 +221,7 @@ int sparc_swint1(int irq, void *context, void *arg)
 
           /* Offset R0 to account for the reserved values */
 
-          /* CURRENT_REGS[REG_R0] -= CONFIG_SYS_RESERVED; *//*zouboan*/
+          /* up_current_regs()[REG_R0] -= CONFIG_SYS_RESERVED; *//*zouboan*/
 #else
           svcerr("ERROR: Bad SYS call: %d\n", regs[REG_I1]);
 #endif
@@ -234,10 +234,10 @@ int sparc_swint1(int irq, void *context, void *arg)
    */
 
 #ifdef CONFIG_DEBUG_SYSCALL_INFO
-  if (regs != CURRENT_REGS)
+  if (regs != up_current_regs())
     {
       svcinfo("SWInt Return: Context switch!\n");
-      up_dump_register(CURRENT_REGS);
+      up_dump_register(up_current_regs());
     }
   else
     {
