@@ -100,10 +100,10 @@
 
 struct up_dev_s
 {
-  void      *uartbase; /* Base address of UART registers */
-  void      *pins;     /* Pin configuration */
-  uint32_t   baud;     /* Configured baud */
-  uint8_t    irq;      /* IRQ associated with this UART */
+  volatile void *uartbase; /* Base address of UART registers */
+  const void    *pins;     /* Pin configuration */
+  uint32_t       baud;     /* Configured baud */
+  uint8_t        irq;      /* IRQ associated with this UART */
 };
 
 /****************************************************************************
