@@ -54,14 +54,6 @@ void up_exit(int status)
 {
   struct tcb_s *tcb;
 
-  /* Make sure that we are in a critical section with local interrupts.
-   * The IRQ state will be restored when the next task is started.
-   */
-
-  enter_critical_section();
-
-  nxsched_dumponexit();
-
   /* Destroy the task at the head of the ready to run list. */
 
   nxtask_exit();
@@ -92,7 +84,17 @@ void up_exit(int status)
   addrenv_switch(tcb);
 #endif
 
+  /* Restore the cpu lock */
+
+  restore_critical_section(tcb, this_cpu());
+
   /* Then switch contexts */
 
   x86_64_fullcontextrestore(tcb->xcp.regs);
+
+  /* x86_64_fullcontextrestore() should not return but could if the software
+   * interrupts are disabled.
+   */
+
+  PANIC();
 }
