@@ -39,6 +39,6 @@
 #if CONFIG_ARCH_INTERRUPTSTACK > 3
 uintptr_t up_get_intstackbase(int cpu)
 {
-  return (uintptr_t)g_intstackalloc;
+  return (uintptr_t)(g_intstackalloc + (cpu * IRQ_STACK_SIZE));
 }
 #endif
