@@ -64,9 +64,14 @@
 #    undef  USE_SERIALDRIVER
 #    undef  USE_EARLYSERIALINIT
 #    undef  CONFIG_DEV_LOWCONSOLE
-#  elif defined(CONFIG_16550_UART)
+#  elif defined(CONFIG_16550_UART) && \
+        !defined(CONFIG_16550_NO_SERIAL_CONSOLE)
 #    define USE_SERIALDRIVER 1
 #    define USE_EARLYSERIALINIT 1
+#  elif defined(CONFIG_16550_PCI_UART) && \
+        !defined(CONFIG_16550_PCI_NO_SERIAL_CONSOLE)
+#    define USE_SERIALDRIVER 1
+#    undef  USE_EARLYSERIALINIT
 #  endif
 #endif
 
@@ -111,7 +116,15 @@
  * referenced is passed to get the state from the TCB.
  */
 
-#define x86_64_restorestate(regs) (g_current_regs = regs)
+#define x86_64_restorestate(regs) (up_set_current_regs(regs))
+
+/* ISR/IRQ stack size */
+
+#if CONFIG_ARCH_INTERRUPTSTACK == 0
+#  define IRQ_STACK_SIZE 0x2000
+#else
+#  define IRQ_STACK_SIZE CONFIG_ARCH_INTERRUPTSTACK
+#endif
 
 /****************************************************************************
  * Public Types
@@ -132,13 +145,13 @@ typedef void (*up_vector_t)(void);
  * end of the heap is CONFIG_RAM_END
  */
 
-extern const uintptr_t g_idle_topstack;
+extern const uintptr_t g_idle_topstack[];
 
 /* Address of the saved user stack pointer */
 
 #if CONFIG_ARCH_INTERRUPTSTACK > 3
 extern uint8_t g_intstackalloc[];
-extern uint8_t g_intstacktop[];
+extern uint8_t g_intstackalloc[];
 #endif
 
 /* These symbols are setup by the linker script. */
