@@ -57,13 +57,11 @@
 
 void up_switch_context(struct tcb_s *tcb, struct tcb_s *rtcb)
 {
-  /* Update scheduler parameters */
-
-  nxsched_suspend_scheduler(rtcb);
+  int cpu;
 
   /* Are we in an interrupt handler? */
 
-  if (g_current_regs)
+  if (up_interrupt_context())
     {
       /* Yes, then we have to do things differently.
        * Just copy the g_current_regs into the OLD rtcb.
@@ -73,10 +71,6 @@ void up_switch_context(struct tcb_s *tcb, struct tcb_s *rtcb)
 
       x86_64_restore_auxstate(tcb);
 
-      /* Update scheduler parameters */
-
-      nxsched_resume_scheduler(tcb);
-
       /* Then switch contexts.  Any necessary address environment
        * changes will be made when the interrupt returns.
        */
@@ -92,6 +86,8 @@ void up_switch_context(struct tcb_s *tcb, struct tcb_s *rtcb)
 
   else if (!up_saveusercontext(rtcb->xcp.regs))
     {
+      cpu = this_cpu();
+
       x86_64_restore_auxstate(tcb);
 
 #ifdef CONFIG_ARCH_ADDRENV
@@ -103,9 +99,21 @@ void up_switch_context(struct tcb_s *tcb, struct tcb_s *rtcb)
 
       addrenv_switch(tcb);
 #endif
+
+      /* Restore the cpu lock */
+
+      restore_critical_section(tcb, cpu);
+
       /* Update scheduler parameters */
 
-      nxsched_resume_scheduler(tcb);
+      nxsched_suspend_scheduler(g_running_tasks[cpu]);
+      nxsched_resume_scheduler(current_task(cpu));
+
+      /* Record the new "running" task.  g_running_tasks[] is only used by
+       * assertion logic for reporting crashes.
+       */
+
+      g_running_tasks[cpu] = current_task(cpu);
 
       /* Then switch contexts */
 
