@@ -28,9 +28,11 @@
 #include <stdint.h>
 #include <string.h>
 #include <debug.h>
+#include <sched.h>
 
 #include <nuttx/irq.h>
 #include <nuttx/arch.h>
+#include <nuttx/pci/pci.h>
 #include <arch/arch.h>
 #include <arch/irq.h>
 #include <arch/io.h>
@@ -39,15 +41,15 @@
 #include <nuttx/spinlock.h>
 
 #include "x86_64_internal.h"
+#include "intel64_cpu.h"
 #include "intel64.h"
 
 /****************************************************************************
  * Pre-processor Definitions
  ****************************************************************************/
 
-#define UART_BASE 0x3f8
-
-#define IRQ_STACK_SIZE 0x2000
+#define X86_64_MAR_DEST      0xfee00000
+#define X86_64_MDR_TYPE      0x4000
 
 /****************************************************************************
  * Private Types
@@ -55,7 +57,8 @@
 
 struct intel64_irq_priv_s
 {
-  uint8_t busy;
+  cpu_set_t busy;
+  bool      msi;
 };
 
 /****************************************************************************
@@ -71,21 +74,14 @@ static inline void up_idtinit(void);
  * Public Data
  ****************************************************************************/
 
-volatile uint64_t *g_current_regs;
-
-uint8_t g_interrupt_stack[IRQ_STACK_SIZE] aligned_data(16);
-uint8_t *g_interrupt_stack_end = g_interrupt_stack + IRQ_STACK_SIZE - 16;
-
-uint8_t g_isr_stack[IRQ_STACK_SIZE] aligned_data(16);
-uint8_t *g_isr_stack_end = g_isr_stack + IRQ_STACK_SIZE - 16;
-
 /****************************************************************************
  * Private Data
  ****************************************************************************/
 
 static struct idt_entry_s        g_idt_entries[NR_IRQS];
 static struct intel64_irq_priv_s g_irq_priv[NR_IRQS];
-static spinlock_t                g_irq_spin;
+static int                       g_msi_now = IRQ_MSI_START;
+static spinlock_t                g_irq_spinlock;
 
 /****************************************************************************
  * Private Functions
@@ -171,49 +167,6 @@ void up_ioapic_unmask_pin(unsigned int pin)
       cur & ~(IOAPIC_PIN_DISABLE));
 }
 
-/****************************************************************************
- * Name: up_init_ist
- *
- * Description:
- *  Initialize the Interrupt Stack Table
- *
- ****************************************************************************/
-
-static void up_ist_init(void)
-{
-  struct gdt_entry_s tss_l;
-  uint64_t           tss_h;
-
-  memset(&tss_l, 0, sizeof(tss_l));
-  memset(&tss_h, 0, sizeof(tss_h));
-
-  tss_l.limit_low = (((104 - 1) & 0xffff));    /* Segment limit = TSS size - 1 */
-
-  tss_l.base_low  = ((uintptr_t)g_ist64 & 0x00ffffff);          /* Low address 1 */
-  tss_l.base_high = (((uintptr_t)g_ist64 & 0xff000000) >> 24);  /* Low address 2 */
-
-  tss_l.P = 1;
-
-  /* Set type as IST */
-
-  tss_l.AC = 1;
-  tss_l.EX = 1;
-
-  tss_h = (((uintptr_t)g_ist64 >> 32) & 0xffffffff);  /* High address */
-
-  g_gdt64[X86_GDT_ISTL_SEL_NUM] = tss_l;
-
-  /* memcpy used to handle type punning compiler warning */
-
-  memcpy((void *)&g_gdt64[X86_GDT_ISTH_SEL_NUM],
-         (void *)&tss_h, sizeof(g_gdt64[0]));
-
-  g_ist64->IST1 = (uintptr_t)g_interrupt_stack_end;
-  g_ist64->IST2 = (uintptr_t)g_isr_stack_end;
-
-  asm volatile ("mov $0x30, %%ax; ltr %%ax":::"memory", "rax");
-}
-
 /****************************************************************************
  * Name: up_deinit_8259
  *
@@ -486,29 +439,36 @@ static inline void up_idtinit(void)
 
 void up_irqinitialize(void)
 {
-  /* Initialize the IST */
+  int cpu = this_cpu();
 
-  up_ist_init();
+  /* Initialize the TSS */
 
-#ifndef CONFIG_ARCH_INTEL64_DISABLE_INT_INIT
-  /* Disable 8259 PIC */
-
-  up_deinit_8259();
-#endif
+  x86_64_cpu_tss_init(cpu);
 
   /* Initialize the APIC */
 
   up_apic_init();
 
+  if (cpu == 0)
+    {
 #ifndef CONFIG_ARCH_INTEL64_DISABLE_INT_INIT
-  /* Initialize the IOAPIC */
+      /* Disable 8259 PIC */
 
-  up_ioapic_init();
+      up_deinit_8259();
+
+      /* Initialize the IOAPIC */
+
+      up_ioapic_init();
 #endif
 
-  /* Initialize the IDT */
+      /* Initialize the IDT */
 
-  up_idtinit();
+      up_idtinit();
+    }
+
+  /* Program the IDT - one per all cores */
+
+  setidt(&g_idt_entries, sizeof(struct idt_entry_s) * NR_IRQS - 1);
 
   /* And finally, enable interrupts */
 
@@ -528,7 +488,7 @@ void up_irqinitialize(void)
 void up_disable_irq(int irq)
 {
 #ifndef CONFIG_ARCH_INTEL64_DISABLE_INT_INIT
-  irqstate_t flags = spin_lock_irqsave(&g_irq_spin);
+  irqstate_t flags = spin_lock_irqsave(&g_irq_spinlock);
 
   if (irq > IRQ255)
     {
@@ -537,12 +497,22 @@ void up_disable_irq(int irq)
       ASSERT(0);
     }
 
+  /* Do nothing if this is MSI/MSI-X */
+
+  if (g_irq_priv[irq].msi)
+    {
+      spin_unlock_irqrestore(&g_irq_spinlock, flags);
+      return;
+    }
+
   if (g_irq_priv[irq].busy > 0)
     {
       g_irq_priv[irq].busy -= 1;
     }
 
-  if (g_irq_priv[irq].busy == 0)
+  CPU_CLR(this_cpu(), &g_irq_priv[irq].busy);
+
+  if (CPU_COUNT(&g_irq_priv[irq].busy) == 0)
     {
       /* One time disable */
 
@@ -552,7 +522,7 @@ void up_disable_irq(int irq)
         }
     }
 
-  spin_unlock_irqrestore(&g_irq_spin, flags);
+  spin_unlock_irqrestore(&g_irq_spinlock, flags);
 #endif
 }
 
@@ -567,17 +537,25 @@ void up_disable_irq(int irq)
 void up_enable_irq(int irq)
 {
 #ifndef CONFIG_ARCH_INTEL64_DISABLE_INT_INIT
-  irqstate_t flags = spin_lock_irqsave(&g_irq_spin);
+  irqstate_t flags = spin_lock_irqsave(&g_irq_spinlock);
 
 #  ifndef CONFIG_IRQCHAIN
   /* Check if IRQ is free if we don't support IRQ chains */
 
-  if (g_irq_priv[irq].busy)
+  if (CPU_ISSET(this_cpu(), &g_irq_priv[irq].busy))
     {
       ASSERT(0);
     }
 #  endif
 
+  /* Do nothing if this is MSI/MSI-X */
+
+  if (g_irq_priv[irq].msi)
+    {
+      spin_unlock_irqrestore(&g_irq_spinlock, flags);
+      return;
+    }
+
   if (irq > IRQ255)
     {
       /* Not supported yet */
@@ -585,7 +563,7 @@ void up_enable_irq(int irq)
       ASSERT(0);
     }
 
-  if (g_irq_priv[irq].busy == 0)
+  if (CPU_COUNT(&g_irq_priv[irq].busy) == 0)
     {
       /* One time enable */
 
@@ -595,9 +573,9 @@ void up_enable_irq(int irq)
         }
     }
 
-  g_irq_priv[irq].busy += 1;
+  CPU_SET(this_cpu(), &g_irq_priv[irq].busy);
 
-  spin_unlock_irqrestore(&g_irq_spin, flags);
+  spin_unlock_irqrestore(&g_irq_spinlock, flags);
 #endif
 }
 
@@ -619,3 +597,141 @@ int up_prioritize_irq(int irq, int priority)
   return OK;
 }
 #endif
+
+/****************************************************************************
+ * Name: up_trigger_irq
+ *
+ * Description:
+ *   Trigger IRQ interrupt.
+ *
+ ****************************************************************************/
+
+void up_trigger_irq(int irq, cpu_set_t cpuset)
+{
+  uint32_t cpu;
+
+  for (cpu = 0; cpu < CONFIG_SMP_NCPUS; cpu++)
+    {
+      if (CPU_ISSET(cpu, &cpuset))
+        {
+          write_msr(MSR_X2APIC_ICR,
+                    MSR_X2APIC_ICR_FIXED |
+                    MSR_X2APIC_ICR_ASSERT |
+                    MSR_X2APIC_DESTINATION(
+                      (uint64_t)x86_64_cpu_to_loapic(cpu)) |
+                    irq);
+        }
+    }
+}
+
+/****************************************************************************
+ * Name: up_get_legacy_irq
+ *
+ * Description:
+ *   Reserve vector for legacy
+ *
+ ****************************************************************************/
+
+int up_get_legacy_irq(uint32_t devfn, uint8_t line, uint8_t pin)
+{
+  UNUSED(devfn);
+  UNUSED(pin);
+  return IRQ0 + line;
+}
+
+/****************************************************************************
+ * Name: up_alloc_irq_msi
+ *
+ * Description:
+ *   Reserve vector for MSI/MSI-X
+ *
+ ****************************************************************************/
+
+int up_alloc_irq_msi(int *num)
+{
+  irqstate_t flags = spin_lock_irqsave(&g_irq_spin);
+  int        irq   = 0;
+  int        i     = 0;
+
+  /* Limit requested number of vectors */
+
+  if (g_msi_now + *num > IRQ255)
+    {
+      *num = IRQ255 - g_msi_now;
+    }
+
+  if (*num <= 0)
+    {
+      spin_unlock_irqrestore(&g_irq_spin, flags);
+
+      /* No IRQs available */
+
+      return -ENODEV;
+    }
+
+  irq = g_msi_now;
+  g_msi_now += *num;
+
+  /* Mark IRQs as MSI/MSI-X */
+
+  for (i = 0; i < *num; i++)
+    {
+      ASSERT(g_irq_priv[irq + i].busy == 0);
+      g_irq_priv[irq + i].msi = true;
+    }
+
+  spin_unlock_irqrestore(&g_irq_spin, flags);
+
+  return irq;
+}
+
+/****************************************************************************
+ * Name: up_release_irq_msi
+ *
+ * Description:
+ *   Release MSI/MSI-X vector
+ *
+ ****************************************************************************/
+
+void up_release_irq_msi(int *irq, int num)
+{
+  irqstate_t flags = spin_lock_irqsave(&g_irq_spin);
+  int        i     = 0;
+
+  /* Mark IRQ as MSI/MSI-X */
+
+  for (i = 0; i < num; i++)
+    {
+      g_irq_priv[irq[i]].msi = false;
+    }
+
+  spin_unlock_irqrestore(&g_irq_spin, flags);
+}
+
+/****************************************************************************
+ * Name: up_connect_irq
+ *
+ * Description:
+ *   Connect MSI/MSI-X vector to irq
+ *
+ ****************************************************************************/
+
+int up_connect_irq(FAR int *irq, int num,
+                   FAR uintptr_t *mar, FAR uint32_t *mdr)
+{
+  UNUSED(num);
+
+  if (mar != NULL)
+    {
+      *mar = X86_64_MAR_DEST |
+        (up_apic_cpu_id() << PCI_MSI_DATA_CPUID_SHIFT);
+    }
+
+  if (mdr != NULL)
+    {
+      *mdr = X86_64_MDR_TYPE | irq[0];
+    }
+
+  return OK;
+}
+
