@@ -91,7 +91,11 @@ void intel64_lowsetup(void)
 
   setgdt((void *)g_gdt64, (uintptr_t)(&g_gdt64_low_end - &g_gdt64_low) - 1);
 
-  /* Revoke the lower memory */
+#ifndef CONFIG_SMP
+  /* Revoke the lower memory if not SMP, otherwise this is done in
+   * x86_64_ap_boot() after the initialization of the last AP is finished.
+   */
 
   __revoke_low_memory();
+#endif
 }
