@@ -53,8 +53,7 @@ uintptr_t up_getusrsp(void *regs)
 
 void up_dump_register(void *dumpregs)
 {
-  volatile uintptr_t *regs = dumpregs ? dumpregs :
-                            (uintptr_t *)CURRENT_REGS;
+  volatile uintptr_t *regs = dumpregs ? dumpregs : up_current_regs();
 
   _alert("   PC: %08lx    PS: %08lx\n",
          (unsigned long)regs[REG_PC], (unsigned long)regs[REG_PS]);
