@@ -32,8 +32,10 @@
 #include <nuttx/arch.h>
 #include <sys/syscall.h>
 
+#include "sched/sched.h"
 #include "chip.h"
 #include "signal/signal.h"
+#include "sched/sched.h"
 #include "xtensa.h"
 
 /****************************************************************************
@@ -56,11 +58,13 @@
 int xtensa_swint(int irq, void *context, void *arg)
 {
   uint32_t *regs = (uint32_t *)context;
+  struct tcb_s *tcb = this_task();
   uint32_t cmd;
 
-  DEBUGASSERT(regs != NULL && regs == CURRENT_REGS);
+  DEBUGASSERT(regs != NULL);
 
   cmd = regs[REG_A2];
+  tcb->xcp.regs = regs;
 
   /* The syscall software interrupt is called with A2 = system call command
    * and A3..A9 = variable number of arguments depending on the system call.
@@ -105,9 +109,9 @@ int xtensa_swint(int irq, void *context, void *arg)
        *   A2 = SYS_restore_context
        *   A3 = restoreregs
        *
-       * In this case, we simply need to set CURRENT_REGS to restore
-       * register area referenced in the saved A3. context == CURRENT_REGS
-       * is the normal exception return.  By setting CURRENT_REGS =
+       * In this case, we simply need to set current_regs to restore
+       * register area referenced in the saved A3. context == current_regs
+       * is the normal exception return.  By setting current_regs =
        * context[A3], we force the return to the saved context referenced
        * in A3.
        */
@@ -115,7 +119,7 @@ int xtensa_swint(int irq, void *context, void *arg)
       case SYS_restore_context:
         {
           DEBUGASSERT(regs[REG_A3] != 0);
-          CURRENT_REGS = (uint32_t *)regs[REG_A3];
+          tcb->xcp.regs = (uint32_t *)regs[REG_A3];
         }
         break;
 
@@ -132,7 +136,7 @@ int xtensa_swint(int irq, void *context, void *arg)
        *
        * In this case, we do both: We save the context registers to the save
        * register area reference by the saved contents of A3 and then set
-       * CURRENT_REGS to the save register area referenced by the saved
+       * current_regs to the save register area referenced by the saved
        * contents of A4.
        */
 
@@ -140,7 +144,7 @@ int xtensa_swint(int irq, void *context, void *arg)
         {
           DEBUGASSERT(regs[REG_A3] != 0 && regs[REG_A4] != 0);
           *(uint32_t **)regs[REG_A3] = regs;
-          CURRENT_REGS = (uint32_t *)regs[REG_A4];
+          tcb->xcp.regs = (uint32_t *)regs[REG_A4];
         }
         break;
 
@@ -159,7 +163,7 @@ int xtensa_swint(int irq, void *context, void *arg)
 #ifdef CONFIG_LIB_SYSCALL
       case SYS_syscall_return:
         {
-          struct tcb_s *rtcb = nxsched_self();
+          struct tcb_s *rtcb = this_task();
           int index = (int)rtcb->xcp.nsyscalls - 1;
 
           /* Make sure that there is a saved syscall return address. */
@@ -298,7 +302,7 @@ int xtensa_swint(int irq, void *context, void *arg)
 #ifndef CONFIG_BUILD_FLAT
       case SYS_signal_handler:
         {
-          struct tcb_s *rtcb  = nxsched_self();
+          struct tcb_s *rtcb  = this_task();
 
           /* Remember the caller's return address */
 
@@ -337,7 +341,7 @@ int xtensa_swint(int irq, void *context, void *arg)
 #ifndef CONFIG_BUILD_FLAT
       case SYS_signal_handler_return:
         {
-          struct tcb_s *rtcb  = nxsched_self();
+          struct tcb_s *rtcb  = this_task();
 
           /* Set up to return to the kernel-mode signal dispatching logic. */
 
@@ -359,7 +363,7 @@ int xtensa_swint(int irq, void *context, void *arg)
       default:
         {
 #ifdef CONFIG_LIB_SYSCALL
-          struct tcb_s *rtcb = nxsched_self();
+          struct tcb_s *rtcb = this_task();
           int index = rtcb->xcp.nsyscalls;
 
           /* Verify that the syscall number is within range */
@@ -418,9 +422,9 @@ int xtensa_swint(int irq, void *context, void *arg)
         break;
     }
 
-  if ((CURRENT_REGS[REG_PS] & PS_EXCM_MASK) != 0)
+  if ((tcb->xcp.regs[REG_PS] & PS_EXCM_MASK) != 0)
     {
-      CURRENT_REGS[REG_PS] &= ~PS_EXCM_MASK;
+      tcb->xcp.regs[REG_PS] &= ~PS_EXCM_MASK;
     }
 
   /* Report what happened.  That might difficult in the case of a context
@@ -428,10 +432,10 @@ int xtensa_swint(int irq, void *context, void *arg)
    */
 
 #ifdef CONFIG_DEBUG_SYSCALL_INFO
-  if (regs != CURRENT_REGS)
+  if (regs != tcb->xcp.regs)
     {
       svcinfo("SYSCALL Return: Context switch!\n");
-      up_dump_register(CURRENT_REGS);
+      up_dump_register(tcb->xcp.regs);
     }
   else
     {
@@ -439,5 +443,10 @@ int xtensa_swint(int irq, void *context, void *arg)
     }
 #endif
 
+  if (regs != tcb->xcp.regs)
+    {
+      restore_critical_section(this_task(), this_cpu());
+    }
+
   return OK;
 }
