@@ -448,7 +448,7 @@ static void esp32_free_cpuint(int cpuint)
   bitmask = 1ul << cpuint;
 
 #ifdef CONFIG_SMP
-  if (up_cpu_index() != 0)
+  if (this_cpu() != 0)
     {
       freeints = &g_cpu1_freeints;
     }
@@ -616,7 +616,7 @@ void up_disable_irq(int irq)
        */
 
 #ifdef CONFIG_SMP
-      int me = up_cpu_index();
+      int me = this_cpu();
       if (me != cpu)
         {
           /* It was the other CPU that enabled this interrupt. */
@@ -677,7 +677,7 @@ void up_enable_irq(int irq)
        * we are just overwriting the cpu part of the map.
        */
 
-      int cpu = up_cpu_index();
+      int cpu = this_cpu();
 
       /* Enable the CPU interrupt now for internal CPU. */
 
@@ -782,7 +782,7 @@ int esp32_cpuint_initialize(void)
 #ifdef CONFIG_SMP
   /* Which CPU are we initializing */
 
-  cpu = up_cpu_index();
+  cpu = this_cpu();
   DEBUGASSERT(cpu >= 0 && cpu < CONFIG_SMP_NCPUS);
 #endif
 
@@ -1073,7 +1073,7 @@ uint32_t *xtensa_int_decode(uint32_t cpuints, uint32_t *regs)
 
   /* Select PRO or APP CPU interrupt mapping table */
 
-  cpu = up_cpu_index();
+  cpu = this_cpu();
 
 #ifdef CONFIG_SMP
   if (cpu != 0)
@@ -1164,7 +1164,7 @@ void esp32_irq_noniram_disable(void)
   uint32_t non_iram_ints;
 
   irqstate = enter_critical_section();
-  cpu = up_cpu_index();
+  cpu = this_cpu();
   non_iram_ints = g_non_iram_int_mask[cpu];
 
   ASSERT(!g_non_iram_int_disabled_flag[cpu]);
@@ -1200,7 +1200,7 @@ void esp32_irq_noniram_enable(void)
   uint32_t non_iram_ints;
 
   irqstate = enter_critical_section();
-  cpu = up_cpu_index();
+  cpu = this_cpu();
   non_iram_ints = g_non_iram_int_disabled[cpu];
 
   ASSERT(g_non_iram_int_disabled_flag[cpu]);
