@@ -61,7 +61,6 @@
 
 static bool    g_dma_chan_used[ESP32S3_DMA_CHAN_MAX];
 static mutex_t g_dma_lock = NXMUTEX_INITIALIZER;
-static int g_dma_ref;
 
 /****************************************************************************
  * Public Functions
@@ -541,54 +540,10 @@ void esp32s3_dma_set_ext_memblk(int chan, bool tx,
 
 void esp32s3_dma_init(void)
 {
-  nxmutex_lock(&g_dma_lock);
+  modifyreg32(SYSTEM_PERIP_CLK_EN1_REG, 0, SYSTEM_DMA_CLK_EN_M);
+  modifyreg32(SYSTEM_PERIP_RST_EN1_REG, SYSTEM_DMA_RST_M, 0);
 
-  if (!g_dma_ref)
-    {
-      modifyreg32(SYSTEM_PERIP_CLK_EN1_REG, 0, SYSTEM_DMA_CLK_EN_M);
-      modifyreg32(SYSTEM_PERIP_RST_EN1_REG, SYSTEM_DMA_RST_M, 0);
+  /* enable DMA clock gating */
 
-      modifyreg32(DMA_MISC_CONF_REG, 0, DMA_CLK_EN_M);
-    }
-
-  g_dma_ref++;
-
-  nxmutex_unlock(&g_dma_lock);
-}
-
-/****************************************************************************
- * Name: esp32s3_dma_deinit
- *
- * Description:
- *   Deinitialize DMA driver.
- *
- * Input Parameters:
- *   None
- *
- * Returned Value:
- *   None.
- *
- ****************************************************************************/
-
-void esp32s3_dma_deinit(void)
-{
-  nxmutex_lock(&g_dma_lock);
-
-  g_dma_ref--;
-
-  if (!g_dma_ref)
-    {
-      /* Disable DMA clock gating */
-
-      modifyreg32(DMA_MISC_CONF_REG, DMA_CLK_EN_M, 0);
-
-      /* Disable DMA module by gating the clock and asserting the reset
-       * signal.
-       */
-
-      modifyreg32(SYSTEM_PERIP_CLK_EN1_REG, SYSTEM_DMA_CLK_EN_M, 0);
-      modifyreg32(SYSTEM_PERIP_RST_EN1_REG, 0, SYSTEM_DMA_RST_M);
-    }
-
-  nxmutex_unlock(&g_dma_lock);
+  modifyreg32(DMA_MISC_CONF_REG, 0, DMA_CLK_EN_M);
 }
