@@ -115,13 +115,6 @@
 #  define ESP32S3_WIFI_RESERVE_INT  0
 #endif
 
-#ifdef CONFIG_ESP32S3_BLE
-#  define ESP32S3_BLE_RESERVE_INT ((1 << ESP32S3_CPUINT_BT_BB) | \
-                                   (1 << ESP32S3_CPUINT_RWBLE))
-#else
-#  define ESP32S3_BLE_RESERVE_INT 0
-#endif
-
 /****************************************************************************
  * Public Data
  ****************************************************************************/
@@ -186,8 +179,7 @@ static bool g_non_iram_int_disabled_flag[CONFIG_SMP_NCPUS];
  */
 
 static uint32_t g_cpu0_freeints = ESP32S3_CPUINT_PERIPHSET &
-                                  ~(ESP32S3_WIFI_RESERVE_INT |
-                                    ESP32S3_BLE_RESERVE_INT);
+                                  ~ESP32S3_WIFI_RESERVE_INT;
 
 #ifdef CONFIG_SMP
 static uint32_t g_cpu1_freeints = ESP32S3_CPUINT_PERIPHSET;
@@ -420,7 +412,7 @@ static void esp32s3_free_cpuint(int cpuint)
   bitmask  = 1ul << cpuint;
 
 #ifdef CONFIG_SMP
-  if (up_cpu_index() != 0)
+  if (this_cpu() != 0)
     {
       freeints = &g_cpu1_freeints;
     }
@@ -498,11 +490,6 @@ void up_irqinitialize(void)
   g_irqmap[ESP32S3_IRQ_PWR] = IRQ_MKMAP(0, ESP32S3_CPUINT_PWR);
 #endif
 
-#ifdef CONFIG_ESP32S3_BLE
-  g_irqmap[ESP32S3_IRQ_BT_BB] = IRQ_MKMAP(0, ESP32S3_CPUINT_BT_BB);
-  g_irqmap[ESP32S3_IRQ_RWBLE] = IRQ_MKMAP(0, ESP32S3_CPUINT_RWBLE);
-#endif
-
   /* Initialize CPU interrupts */
 
   esp32s3_cpuint_initialize();
@@ -515,13 +502,6 @@ void up_irqinitialize(void)
   xtensa_enable_cpuint(&g_intenable[0], 1 << ESP32S3_CPUINT_MAC);
 #endif
 
-#ifdef CONFIG_ESP32S3_BLE
-  g_cpu0_intmap[ESP32S3_CPUINT_BT_BB] = CPUINT_ASSIGN(ESP32S3_IRQ_BT_BB);
-  g_cpu0_intmap[ESP32S3_CPUINT_RWBLE] = CPUINT_ASSIGN(ESP32S3_IRQ_RWBLE);
-  xtensa_enable_cpuint(&g_intenable[0], 1 << ESP32S3_CPUINT_BT_BB);
-  xtensa_enable_cpuint(&g_intenable[0], 1 << ESP32S3_CPUINT_RWBLE);
-#endif
-
 #ifdef CONFIG_SMP
   /* Attach and enable the inter-CPU interrupt */
 
@@ -585,7 +565,7 @@ void up_disable_irq(int irq)
        */
 
 #ifdef CONFIG_SMP
-      int me = up_cpu_index();
+      int me = this_cpu();
       if (me != cpu)
         {
           /* It was the other CPU that enabled this interrupt. */
@@ -635,7 +615,7 @@ void up_enable_irq(int irq)
        * we are just overwriting the cpu part of the map.
        */
 
-      int cpu = up_cpu_index();
+      int cpu = this_cpu();
 
       /* Enable the CPU interrupt now for internal CPU. */
 
@@ -729,7 +709,7 @@ int esp32s3_cpuint_initialize(void)
 #ifdef CONFIG_SMP
   /* Which CPU are we initializing */
 
-  cpu = up_cpu_index();
+  cpu = this_cpu();
   DEBUGASSERT(cpu >= 0 && cpu < CONFIG_SMP_NCPUS);
 #endif
 
@@ -828,6 +808,12 @@ int esp32s3_setup_irq(int cpu, int periphid, int priority, int flags)
       return -EINVAL;
     }
 
+  if (priority > XCHAL_SYSCALL_LEVEL)
+    {
+      irqerr("Invalid priority %d\n", priority);
+      return -EINVAL;
+    }
+
   irqstate = enter_critical_section();
 
   /* Setting up an IRQ includes the following steps:
@@ -1016,7 +1002,7 @@ uint32_t *xtensa_int_decode(uint32_t cpuints, uint32_t *regs)
 #endif
   /* Select PRO or APP CPU interrupt mapping table */
 
-  cpu = up_cpu_index();
+  cpu = this_cpu();
 
 #ifdef CONFIG_SMP
   if (cpu != 0)
@@ -1107,7 +1093,7 @@ void esp32s3_irq_noniram_disable(void)
   uint32_t non_iram_ints;
 
   irqstate = enter_critical_section();
-  cpu = up_cpu_index();
+  cpu = this_cpu();
   non_iram_ints = g_non_iram_int_mask[cpu];
 
   ASSERT(!g_non_iram_int_disabled_flag[cpu]);
@@ -1143,7 +1129,7 @@ void esp32s3_irq_noniram_enable(void)
   uint32_t non_iram_ints;
 
   irqstate = enter_critical_section();
-  cpu = up_cpu_index();
+  cpu = this_cpu();
   non_iram_ints = g_non_iram_int_disabled[cpu];
 
   ASSERT(g_non_iram_int_disabled_flag[cpu]);
