@@ -267,7 +267,7 @@ static void spislave_prepare_next_tx(struct spislave_priv_s *priv);
 #else
 static void spislave_write_tx_buffer(struct spislave_priv_s *priv);
 #endif
-static void spislave_initialize(struct spi_slave_ctrlr_s *ctrlr);
+static int spislave_initialize(struct spi_slave_ctrlr_s *ctrlr);
 static void spislave_deinitialize(struct spi_slave_ctrlr_s *ctrlr);
 
 /* SPI Slave controller operations */
@@ -1117,7 +1117,7 @@ static int spislave_periph_interrupt(int irq, void *context, void *arg)
  ****************************************************************************/
 
 #ifdef CONFIG_ESP32S3_SPI_DMA
-void spislave_dma_init(struct spislave_priv_s *priv)
+static int spislave_dma_init(struct spislave_priv_s *priv)
 {
   /* Enable GDMA clock for the SPI peripheral */
 
@@ -1127,10 +1127,6 @@ void spislave_dma_init(struct spislave_priv_s *priv)
 
   resetbits(priv->config->dma_rst_bit, SYSTEM_PERIP_RST_EN0_REG);
 
-  /* Initialize GDMA controller */
-
-  esp32s3_dma_init();
-
   /* Request a GDMA channel for SPI peripheral */
 
   priv->dma_channel = esp32s3_dma_request(priv->config->dma_periph, 1, 1,
@@ -1138,8 +1134,7 @@ void spislave_dma_init(struct spislave_priv_s *priv)
   if (priv->dma_channel < 0)
     {
       spierr("Failed to allocate GDMA channel\n");
-
-      DEBUGPANIC();
+      return ERROR;
     }
 
   /* Disable segment transaction mode for SPI Slave */
@@ -1149,6 +1144,8 @@ void spislave_dma_init(struct spislave_priv_s *priv)
   /* Configure DMA In-Link EOF to be generated by trans_done */
 
   resetbits(SPI_RX_EOF_EN_M, SPI_DMA_CONF_REG(priv->config->id));
+
+  return OK;
 }
 
 /****************************************************************************
@@ -1171,10 +1168,6 @@ void spislave_dma_deinit(struct spislave_priv_s *priv)
 
   esp32s3_dma_release(priv->dma_channel);
 
-  /* Deinitialize DMA controller */
-
-  esp32s3_dma_deinit();
-
   /* Disable DMA clock for the SPI peripheral */
 
   modifyreg32(SYSTEM_PERIP_CLK_EN0_REG, priv->config->dma_clk_bit, 0);
@@ -1322,11 +1315,11 @@ static void spislave_gpio_initialize(struct spislave_priv_s *priv)
  *   ctrlr - SPI Slave controller interface instance
  *
  * Returned Value:
- *   None.
+ *   Zero on success; a negated errno on failure
  *
  ****************************************************************************/
 
-static void spislave_initialize(struct spi_slave_ctrlr_s *ctrlr)
+static int spislave_initialize(struct spi_slave_ctrlr_s *ctrlr)
 {
   uint32_t regval;
   struct spislave_priv_s *priv = (struct spislave_priv_s *)ctrlr;
@@ -1373,7 +1366,12 @@ static void spislave_initialize(struct spi_slave_ctrlr_s *ctrlr)
   resetbits(SPI_INT_MASK, SPI_DMA_INT_ENA_REG(priv->config->id));
 
 #ifdef CONFIG_ESP32S3_SPI_DMA
-  spislave_dma_init(priv);
+  if (spislave_dma_init(priv) != OK)
+    {
+      setbits(priv->config->clk_bit, SYSTEM_PERIP_RST_EN0_REG);
+      resetbits(priv->config->clk_bit, SYSTEM_PERIP_CLK_EN0_REG);
+      return ERROR;
+    }
 #endif
 
   esp32s3_gpioirqenable(ESP32S3_PIN2IRQ(config->cs_pin), RISING);
@@ -1392,6 +1390,8 @@ static void spislave_initialize(struct spi_slave_ctrlr_s *ctrlr)
 #endif
   setbits(regval, SPI_DMA_INT_RAW_REG(priv->config->id));
   setbits(regval, SPI_DMA_INT_ENA_REG(priv->config->id));
+
+  return OK;
 }
 
 /****************************************************************************
@@ -1493,7 +1493,12 @@ static void spislave_bind(struct spi_slave_ctrlr_s *ctrlr,
   priv->tx_length = 0;
   priv->is_tx_enabled = false;
 
-  spislave_initialize(ctrlr);
+  if (spislave_initialize(ctrlr) != OK)
+    {
+      spierr("spislave_initialize failed!\n");
+      spin_unlock_irqrestore(&priv->lock, flags);
+      DEBUGPANIC();
+    }
 
   spislave_setmode(ctrlr, mode);
   spislave_setbits(ctrlr, nbits);
@@ -1803,7 +1808,7 @@ struct spi_slave_ctrlr_s *esp32s3_spislave_ctrlr_initialize(int port)
                          spislave_cs_interrupt,
                          priv));
 
-  priv->cpu = up_cpu_index();
+  priv->cpu = this_cpu();
   priv->cpuint = esp32s3_setup_irq(priv->cpu,
                                    priv->config->periph,
                                    ESP32S3_INT_PRIO_DEF,
