@@ -48,6 +48,7 @@
 #include "esp32s3_irq.h"
 #include "esp32s3_spiflash.h"
 
+#include "hal/cache_hal.h"
 #include "soc/extmem_reg.h"
 #include "soc/spi_mem_reg.h"
 #include "rom/opi_flash.h"
@@ -187,8 +188,8 @@
 
 static void spiflash_start(void);
 static void spiflash_end(void);
-static void spi_flash_disable_cache(uint32_t cpuid);
-static void spi_flash_restore_cache(uint32_t cpuid);
+static void spi_flash_disable_cache(void);
+static void spi_flash_restore_cache(void);
 #ifdef CONFIG_SMP
 static int spi_flash_op_block_task(int argc, char *argv[]);
 static int spiflash_init_spi_flash_op_block_task(int cpu);
@@ -220,6 +221,7 @@ static uint32_t s_flash_op_cache_state[CONFIG_SMP_NCPUS];
 static rmutex_t g_flash_op_mutex;
 static volatile bool g_flash_op_can_start = false;
 static volatile bool g_flash_op_complete = false;
+static volatile bool g_spi_flash_cache_suspended = false;
 static volatile bool g_sched_suspended[CONFIG_SMP_NCPUS];
 #ifdef CONFIG_SMP
 static sem_t g_disable_non_iram_isr_on_core[CONFIG_SMP_NCPUS];
@@ -239,15 +241,14 @@ static sem_t g_disable_non_iram_isr_on_core[CONFIG_SMP_NCPUS];
 
 static void spiflash_suspend_cache(void)
 {
-  int cpu = up_cpu_index();
+  int cpu = this_cpu();
 #ifdef CONFIG_SMP
   int other_cpu = cpu ? 0 : 1;
 #endif
 
-  spi_flash_disable_cache(cpu);
-#ifdef CONFIG_SMP
-  spi_flash_disable_cache(other_cpu);
-#endif
+  spi_flash_disable_cache();
+
+  g_spi_flash_cache_suspended = true;
 }
 
 /****************************************************************************
@@ -260,15 +261,14 @@ static void spiflash_suspend_cache(void)
 
 static void spiflash_resume_cache(void)
 {
-  int cpu = up_cpu_index();
+  int cpu = this_cpu();
 #ifdef CONFIG_SMP
   int other_cpu = cpu ? 0 : 1;
 #endif
 
-  spi_flash_restore_cache(cpu);
-#ifdef CONFIG_SMP
-  spi_flash_restore_cache(other_cpu);
-#endif
+  spi_flash_restore_cache();
+
+  g_spi_flash_cache_suspended = false;
 }
 
 /****************************************************************************
@@ -294,7 +294,7 @@ static void spiflash_start(void)
 
   nxsched_set_priority(tcb, SCHED_PRIORITY_MAX);
 
-  cpu = up_cpu_index();
+  cpu = this_cpu();
 #ifdef CONFIG_SMP
   other_cpu = cpu == 1 ? 0 : 1;
 #endif
@@ -308,7 +308,7 @@ static void spiflash_start(void)
     {
       g_flash_op_can_start = false;
 
-      cpu = up_cpu_index();
+      cpu = this_cpu();
       other_cpu = cpu ? 0 : 1;
 
       nxsem_post(&g_disable_non_iram_isr_on_core[other_cpu]);
@@ -343,7 +343,7 @@ static void spiflash_start(void)
 
 static void spiflash_end(void)
 {
-  const int cpu = up_cpu_index();
+  const int cpu = this_cpu();
 #ifdef CONFIG_SMP
   const int other_cpu = cpu ? 0 : 1;
 #endif
@@ -765,17 +765,16 @@ static inline void IRAM_ATTR spiflash_os_yield(void)
  *   s_flash_op_cache_state.
  *
  * Input Parameters:
- *   cpuid - The CPU core whose cache will be disabled.
+ *   None.
  *
  * Returned Value:
  *   None.
  *
  ****************************************************************************/
 
-static void spi_flash_disable_cache(uint32_t cpuid)
+static void spi_flash_disable_cache(void)
 {
-  s_flash_op_cache_state[cpuid] = cache_suspend_icache() << 16;
-  s_flash_op_cache_state[cpuid] |= cache_suspend_dcache();
+  cache_hal_suspend(CACHE_TYPE_ALL);
 }
 
 /****************************************************************************
@@ -786,17 +785,16 @@ static void spi_flash_disable_cache(uint32_t cpuid)
  *   s_flash_op_cache_state.
  *
  * Input Parameters:
- *   cpuid - The CPU core whose cache will be restored.
+ *   None.
  *
  * Returned Value:
  *   None.
  *
  ****************************************************************************/
 
-static void spi_flash_restore_cache(uint32_t cpuid)
+static void spi_flash_restore_cache(void)
 {
-  cache_resume_dcache(s_flash_op_cache_state[cpuid] & 0xffff);
-  cache_resume_icache(s_flash_op_cache_state[cpuid] >> 16);
+  cache_hal_resume(CACHE_TYPE_ALL);
 }
 
 #ifdef CONFIG_SMP
@@ -823,7 +821,7 @@ static void spi_flash_restore_cache(uint32_t cpuid)
 static int spi_flash_op_block_task(int argc, char *argv[])
 {
   struct tcb_s *tcb = this_task();
-  int cpu = up_cpu_index();
+  int cpu = this_cpu();
 
   for (; ; )
     {
@@ -855,7 +853,7 @@ static int spi_flash_op_block_task(int argc, char *argv[])
 
       /* Flash operation is complete, re-enable cache */
 
-      spi_flash_restore_cache(cpu);
+      spi_flash_restore_cache();
 
       /* Restore interrupts that aren't located in IRAM */
 
