@@ -35,17 +35,18 @@
 
 #include "chip.h"
 #include "xtensa.h"
-#include "xtensa_attr.h"
+#include "esp_attr.h"
 #include "esp32s3_irq.h"
 #include "esp32s3_userspace.h"
 #include "hardware/esp32s3_apb_ctrl.h"
 #include "hardware/esp32s3_cache_memory.h"
-#include "hardware/esp32s3_extmem.h"
 #include "hardware/esp32s3_rom_layout.h"
 #include "hardware/esp32s3_sensitive.h"
 #include "hardware/esp32s3_soc.h"
 #include "hardware/esp32s3_wcl_core.h"
 
+#include "soc/extmem_reg.h"
+
 #ifdef CONFIG_BUILD_PROTECTED
 
 /****************************************************************************
@@ -80,9 +81,6 @@
 
 #define WCL_SEQ_LAST_VAL    6
 
-#define I_D_SRAM_OFFSET           (SOC_DIRAM_IRAM_LOW - SOC_DIRAM_DRAM_LOW)
-#define MAP_IRAM_TO_DRAM(addr)    ((addr) - I_D_SRAM_OFFSET)
-
 /* Categories bits for split line configuration */
 
 #define PMS_SRAM_CATEGORY_BELOW   0x0
