@@ -45,7 +45,7 @@
 #  include "esp_private/wifi.h"
 #  include "esp_wpa.h"
 #endif
-#include "esp_coexist_internal.h"
+#include "private/esp_coexist_internal.h"
 #include "periph_ctrl.h"
 #include "esp_phy_init.h"
 #include "phy_init_data.h"
@@ -339,6 +339,85 @@ static void esp_wifi_set_log_level(void)
  * Public Functions
  ****************************************************************************/
 
+/****************************************************************************
+ * Name: esp_wifi_to_errno
+ *
+ * Description:
+ *   Transform from ESP Wi-Fi error code to NuttX error code
+ *
+ * Input Parameters:
+ *   err - ESP Wi-Fi error code
+ *
+ * Returned Value:
+ *   NuttX error code defined in errno.h
+ *
+ ****************************************************************************/
+
+int32_t esp_wifi_to_errno(int err)
+{
+  int ret;
+
+  if (err < ESP_ERR_WIFI_BASE)
+    {
+      /* Unmask component error bits */
+
+      ret = err & 0xfff;
+
+      switch (ret)
+        {
+          case ESP_OK:
+            ret = OK;
+            break;
+          case ESP_ERR_NO_MEM:
+            ret = -ENOMEM;
+            break;
+
+          case ESP_ERR_INVALID_ARG:
+            ret = -EINVAL;
+            break;
+
+          case ESP_ERR_INVALID_STATE:
+            ret = -EIO;
+            break;
+
+          case ESP_ERR_INVALID_SIZE:
+            ret = -EINVAL;
+            break;
+
+          case ESP_ERR_NOT_FOUND:
+            ret = -ENOSYS;
+            break;
+
+          case ESP_ERR_NOT_SUPPORTED:
+            ret = -ENOSYS;
+            break;
+
+          case ESP_ERR_TIMEOUT:
+            ret = -ETIMEDOUT;
+            break;
+
+          case ESP_ERR_INVALID_MAC:
+            ret = -EINVAL;
+            break;
+
+          default:
+            ret = ERROR;
+            break;
+        }
+    }
+  else
+    {
+      ret = ERROR;
+    }
+
+  if (ret != OK)
+    {
+      wlerr("ERROR: %s\n", esp_err_to_name(err));
+    }
+
+  return ret;
+}
+
 /****************************************************************************
  * Functions needed by libphy.a
  ****************************************************************************/
@@ -1281,8 +1360,16 @@ int esp_wireless_deinit(void)
 int32_t esp_wifi_init(const wifi_init_config_t *config)
 {
   int32_t ret;
+  uint32_t min_active_time_us =
+              CONFIG_ESP_WIFI_SLP_DEFAULT_MIN_ACTIVE_TIME * 1000;
+  uint32_t keep_alive_time_us =
+              CONFIG_ESP_WIFI_SLP_DEFAULT_MAX_ACTIVE_TIME * 1000 * 1000;
+  uint32_t wait_broadcast_data_time_us =
+              CONFIG_ESP_WIFI_SLP_DEFAULT_WAIT_BROADCAST_DATA_TIME * 1000;
 
-  esp_wifi_power_domain_on();
+  esp_wifi_set_sleep_min_active_time(min_active_time_us);
+  esp_wifi_set_keep_alive_time(keep_alive_time_us);
+  esp_wifi_set_sleep_wait_broadcast_data_time(wait_broadcast_data_time_us);
 
 #ifdef CONFIG_ESP32S3_WIFI_BT_COEXIST
   ret = coex_init();
@@ -1294,6 +1381,7 @@ int32_t esp_wifi_init(const wifi_init_config_t *config)
 #endif /* CONFIG_ESP32S3_WIFI_BT_COEXIST */
 
   esp_wifi_set_log_level();
+  esp_wifi_power_domain_on();
 
   ret = esp_wifi_init_internal(config);
   if (ret)
