@@ -49,10 +49,6 @@
  * Public Data
  ****************************************************************************/
 
-/****************************************************************************
- * Public Function Prototypes
- ****************************************************************************/
-
 #ifndef __ASSEMBLY__
 #ifdef __cplusplus
 #define EXTERN extern "C"
@@ -66,18 +62,12 @@ extern "C"
 
 chipreg_t up_getsp(void);
 
-/****************************************************************************
- * Public Data
- ****************************************************************************/
-
-#ifndef __ASSEMBLY__
 /* This holds a references to the current interrupt level
  * register storage structure.  It is non-NULL only during
  * interrupt processing.
  */
 
 EXTERN volatile FAR chipreg_t *g_current_regs;
-#endif
 
 /****************************************************************************
  * Public Function Prototypes
@@ -105,6 +95,21 @@ EXTERN volatile FAR chipreg_t *g_current_regs;
  * Inline functions
  ****************************************************************************/
 
+/* This holds a references to the current interrupt level
+ * register storage structure.  If is non-NULL only during
+ * interrupt processing.
+ */
+
+static inline_function chipreg_t *up_current_regs(void)
+{
+  return (FAR chipreg_t *)g_current_regs;
+}
+
+static inline_function void up_set_current_regs(FAR chipreg_t *regs)
+{
+  g_current_regs = regs;
+}
+
 /****************************************************************************
  * Name: up_interrupt_context
  *
@@ -114,7 +119,7 @@ EXTERN volatile FAR chipreg_t *g_current_regs;
  *
  ****************************************************************************/
 
-#define up_interrupt_context() (g_current_regs != NULL)
+#define up_interrupt_context() (up_current_regs() != NULL)
 
 #undef EXTERN
 #ifdef __cplusplus
