@@ -53,7 +53,7 @@ void z16f_sysexec(FAR chipreg_t *regs)
    * diagnostics.
    */
 
-  g_current_regs = regs;
+  up_set_current_regs(regs);
 
   /* The cause of the system exception is indicated in the SYSEXCPH&L
    * registers
