@@ -46,7 +46,7 @@
 /* Initialize the IRQ state */
 
 #define INIT_IRQCONTEXT() \
-  g_current_regs = NULL
+  up_set_current_regs(NULL)
 
 /* IN_INTERRUPT returns true if the system is currently operating
  * in the interrupt context.  IN_INTERRUPT is the inline equivalent
@@ -54,7 +54,7 @@
  */
 
 #define IN_INTERRUPT() \
-  (g_current_regs != NULL)
+  (up_current_regs() != NULL)
 
 /* The following macro declares the variables need by IRQ_ENTER
  * and IRQ_LEAVE.  These variables are used to support nested interrupts.
@@ -83,10 +83,10 @@
 #define IRQ_ENTER(irq, regs) \
   do \
     { \
-      savestate    = (FAR chipreg_t *)g_current_regs; \
-      savecbr      = current_cbr; \
-      g_current_regs = (regs); \
-      current_cbr  = inp(Z180_MMU_CBR); \
+      savestate = up_current_regs(); \
+      savecbr = current_cbr; \
+      up_set_current_regs(regs) \
+      current_cbr = inp(Z180_MMU_CBR); \
     } \
   while (0)
 
@@ -100,8 +100,8 @@
 #define IRQ_LEAVE(irq) \
   do \
     { \
-      g_current_regs = savestate; \
-      if (g_current_regs) \
+      up_set_current_regs(savestate); \
+      if (up_current_regs()) \
         { \
           current_cbr = savecbr; \
         } \
@@ -117,12 +117,12 @@
  */
 
 #define IRQ_STATE() \
-  (g_current_regs)
+  up_current_regs()
 
 /* Save the current IRQ context in the specified TCB */
 
 #define SAVE_IRQCONTEXT(tcb) \
-  z180_copystate((tcb)->xcp.regs, (FAR chipreg_t*)g_current_regs)
+  z180_copystate((tcb)->xcp.regs, up_current_regs())
 
 /* Set the current IRQ context to the state specified in the TCB */
 
@@ -133,7 +133,7 @@
         { \
           current_cbr = (tcb)->xcp.cbr->cbr; \
         } \
-      z180_copystate((FAR chipreg_t*)g_current_regs, (tcb)->xcp.regs); \
+      z180_copystate(up_current_regs(), (tcb)->xcp.regs); \
     } \
   while (0)
 
@@ -211,6 +211,20 @@ void z180_restoreusercontext(FAR chipreg_t *regs);
 void z180_sigsetup(FAR struct tcb_s *tcb, sig_deliver_t sigdeliver,
                    FAR chipreg_t *regs);
 
+/****************************************************************************
+ * Inline Functions
+ ****************************************************************************/
+
+static inline_function chipreg_t *up_current_regs(void)
+{
+  return (FAR chipreg_t *)g_current_regs;
+}
+
+static inline_function void up_set_current_regs(FAR chipreg_t *regs)
+{
+  g_current_regs = regs;
+}
+
 #ifdef __cplusplus
 }
 #endif
