@@ -42,14 +42,14 @@
 
 /* Initialize the IRQ state */
 
-#define INIT_IRQCONTEXT()        g_current_regs = NULL
+#define INIT_IRQCONTEXT()        up_set_current_regs(NULL)
 
 /* IN_INTERRUPT returns true if the system is currently operating in the
  * interrupt context.
  * IN_INTERRUPT is the inline equivalent of up_interrupt_context().
  */
 
-#define IN_INTERRUPT()           (g_current_regs != NULL)
+#define IN_INTERRUPT()           (up_current_regs() != NULL)
 
 /* The following macro is used when the system enters interrupt
  * handling logic
@@ -66,30 +66,32 @@
   FAR chipreg_t *savestate
 
 #define IRQ_ENTER(irq, regs) \
-  do { \
-    savestate    = (FAR chipreg_t *)g_current_regs; \
-    g_current_regs = (regs); \
-  } while (0)
+  do \
+    { \
+      savestate = up_current_regs(); \
+      up_set_current_regs(regs); \
+    } \
+  while (0)
 
 /* The following macro is used when the system exits
  * interrupt handling logic
  */
 
-#define IRQ_LEAVE(irq)           g_current_regs = savestate
+#define IRQ_LEAVE(irq)           up_set_current_regs(savestate)
 
 /* The following macro is used to sample the interrupt state
  * (as a opaque handle)
  */
 
-#define IRQ_STATE()              (g_current_regs)
+#define IRQ_STATE()              up_current_regs()
 
 /* Save the current IRQ context in the specified TCB */
 
-#define SAVE_IRQCONTEXT(tcb)     z80_copystate((tcb)->xcp.regs, (FAR chipreg_t*)g_current_regs)
+#define SAVE_IRQCONTEXT(tcb)     z80_copystate((tcb)->xcp.regs, up_current_regs())
 
 /* Set the current IRQ context to the state specified in the TCB */
 
-#define SET_IRQCONTEXT(tcb)      z80_copystate((FAR chipreg_t*)g_current_regs, (tcb)->xcp.regs)
+#define SET_IRQCONTEXT(tcb)      z80_copystate(up_current_regs(), (tcb)->xcp.regs)
 
 /* Save the user context in the specified TCB.  User context saves
  * can be simpler because only those registers normally saved in a C called
@@ -142,6 +144,20 @@ int up_saveusercontext(FAR chipreg_t *regs);
 
 void z80_restoreusercontext(FAR chipreg_t *regs);
 
+/****************************************************************************
+ * Inline Functions
+ ****************************************************************************/
+
+static inline_function chipreg_t *up_current_regs(void)
+{
+  return (FAR chipreg_t *)g_current_regs;
+}
+
+static inline_function void up_set_current_regs(FAR chipreg_t *regs)
+{
+  g_current_regs = regs;
+}
+
 #ifdef __cplusplus
 }
 #endif
