@@ -1,6 +1,8 @@
 /****************************************************************************
  * binfmt/libelf/libelf_coredump.c
  *
+ * SPDX-License-Identifier: Apache-2.0
+ *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.  The
@@ -246,11 +248,11 @@ static void elf_emit_tcb_note(FAR struct elf_dumpinfo_s *cinfo,
 
   elf_emit(cinfo, &nhdr, sizeof(nhdr));
 
-  strlcpy(name, tcb->name, sizeof(name));
+  strlcpy(name, get_task_name(tcb), sizeof(name));
   elf_emit(cinfo, name, sizeof(name));
 
   info.pr_pid   = tcb->pid;
-  strlcpy(info.pr_fname, tcb->name, sizeof(info.pr_fname));
+  strlcpy(info.pr_fname, get_task_name(tcb), sizeof(info.pr_fname));
   elf_emit(cinfo, &info, sizeof(info));
 
   /* Fill Process status */
@@ -267,7 +269,7 @@ static void elf_emit_tcb_note(FAR struct elf_dumpinfo_s *cinfo,
     {
       if (up_interrupt_context())
         {
-          regs = (FAR uintptr_t *)CURRENT_REGS;
+          regs = (FAR uintptr_t *)up_current_regs();
         }
       else
         {
@@ -277,7 +279,7 @@ static void elf_emit_tcb_note(FAR struct elf_dumpinfo_s *cinfo,
     }
   else
     {
-      regs = (uintptr_t *)tcb->xcp.regs;
+      regs = (FAR uintptr_t *)tcb->xcp.regs;
     }
 
   if (regs != NULL)
@@ -290,8 +292,8 @@ static void elf_emit_tcb_note(FAR struct elf_dumpinfo_s *cinfo,
             }
           else
             {
-              status.pr_regs[i] =
-                *(uintptr_t *)((uint8_t *)regs + g_tcbinfo.reg_off.p[i]);
+              status.pr_regs[i] = *(FAR uintptr_t *)
+                  ((FAR uint8_t *)regs + g_tcbinfo.reg_off.p[i]);
             }
         }
     }
@@ -423,9 +425,34 @@ static void elf_emit_memory(FAR struct elf_dumpinfo_s *cinfo, int memsegs)
 
   for (i = 0; i < memsegs; i++)
     {
-      elf_emit(cinfo, (FAR void *)cinfo->regions[i].start,
-               cinfo->regions[i].end -
-               cinfo->regions[i].start);
+      if (cinfo->regions[i].flags & PF_REGISTER)
+        {
+          FAR uintptr_t *start = (FAR uintptr_t *)cinfo->regions[i].start;
+          FAR uintptr_t *end = (FAR uintptr_t *)cinfo->regions[i].end;
+          uintptr_t buf[64];
+          size_t offset = 0;
+
+          while (start < end)
+            {
+              buf[offset++] = *start++;
+
+              if (offset % (sizeof(buf) / sizeof(uintptr_t)) == 0)
+                {
+                  elf_emit(cinfo, buf, sizeof(buf));
+                  offset = 0;
+                }
+            }
+
+          if (offset != 0)
+            {
+              elf_emit(cinfo, buf, offset * sizeof(uintptr_t));
+            }
+        }
+      else
+        {
+          elf_emit(cinfo, (FAR void *)cinfo->regions[i].start,
+                   cinfo->regions[i].end - cinfo->regions[i].start);
+        }
 
       /* Align to page */
 
@@ -443,7 +470,7 @@ static void elf_emit_memory(FAR struct elf_dumpinfo_s *cinfo, int memsegs)
 
 static void elf_emit_tcb_phdr(FAR struct elf_dumpinfo_s *cinfo,
                               FAR struct tcb_s *tcb,
-                              FAR Elf_Phdr *phdr, off_t *offset)
+                              FAR Elf_Phdr *phdr, FAR off_t *offset)
 {
   uintptr_t sp;
 
