@@ -1,6 +1,8 @@
 /****************************************************************************
  * binfmt/libelf/libelf_ctors.c
  *
+ * SPDX-License-Identifier: Apache-2.0
+ *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.  The
@@ -97,7 +99,7 @@ int elf_loadctors(FAR struct elf_loadinfo_s *loadinfo)
        */
 
       binfo("elf_findsection .ctors section failed: %d\n", ctoridx);
-      return ret == -ENOENT ? OK : ret;
+      return ctoridx == -ENOENT ? OK : ctoridx;
     }
 
   /* Now we can get a pointer to the .ctor section in the section header
@@ -164,7 +166,7 @@ int elf_loadctors(FAR struct elf_loadinfo_s *loadinfo)
 
           for (i = 0; i < loadinfo->nctors; i++)
             {
-              FAR uintptr_t *ptr = (uintptr_t *)
+              FAR uintptr_t *ptr = (FAR uintptr_t *)
                    ((FAR void *)(&loadinfo->ctors)[i]);
 
               binfo("ctor %d: "
