@@ -33,6 +33,7 @@
 
 #include <nuttx/arch.h>
 #include <nuttx/mutex.h>
+#include <nuttx/signal.h>
 
 #include "chip.h"
 #include "arm_internal.h"
@@ -233,7 +234,7 @@ int board_power_control(int target, bool en)
 
       if (!g_rtc_enabled && (PMIC_GET_TYPE(target) == PMIC_TYPE_GPO))
         {
-          usleep(1);
+          nxsig_usleep(1);
         }
     }
 
@@ -271,7 +272,7 @@ int board_power_control_tristate(int target, int value)
 
       if (!g_rtc_enabled)
         {
-          usleep(1);
+          nxsig_usleep(1);
         }
     }
   else if (PMIC_GET_TYPE(target) == CHIP_TYPE_GPIO)
