@@ -53,13 +53,17 @@
 #  include "nrf52_sdc.h"
 #endif
 
+#ifdef CONFIG_IEEE802154_MRF24J40
+#  include "nrf52_mrf24j40.h"
+#endif
+
 #include "nrf52832-dk.h"
 
 /****************************************************************************
  * Pre-processor Definitions
  ****************************************************************************/
 
-#define NRF52_TIMER (0)
+#define NRF52_TIMER (1)
 
 /****************************************************************************
  * Public Functions
@@ -138,7 +142,6 @@ int nrf52_bringup(void)
 
 #ifdef CONFIG_NRF52_SOFTDEVICE_CONTROLLER
   ret = nrf52_sdc_initialize();
-
   if (ret < 0)
     {
       syslog(LOG_ERR, "ERROR: nrf52_sdc_initialize() failed: %d\n", ret);
@@ -153,6 +156,17 @@ int nrf52_bringup(void)
     }
 #endif /* CONFIG_MTD */
 
+#ifdef CONFIG_IEEE802154_MRF24J40
+  /* Configure MRF24J40 wireless */
+
+  ret = nrf52_mrf24j40_initialize();
+  if (ret < 0)
+    {
+      syslog(LOG_ERR, "ERROR: nrf52_mrf24j40_initialize() failed: %d\n",
+             ret);
+    }
+#endif
+
   UNUSED(ret);
   return OK;
 }
