@@ -86,6 +86,7 @@
 
 #define GPIO_ADXL362_INT1 (GPIO_INPUT  | GPIO_PORT0 | GPIO_PIN(19))
 #define GPIO_ADXL362_CS   (GPIO_OUTPUT | GPIO_PORT0 | GPIO_PIN(22))
+#define ADXL362_SPIDEV    (1)
 
 /* BMI270 (I2C address: 0x68)
  *   INT1 - P0.23
@@ -94,6 +95,7 @@
 
 #define GPIO_BMI270_INT1 (GPIO_INPUT  | GPIO_PORT0 | GPIO_PIN(23))
 #define GPIO_BMI270_CS   (GPIO_OUTPUT | GPIO_PORT1 | GPIO_PIN(4))
+#define BMI270_SPIDEV    (1)
 
 /* BMM150 (I2C address: 0x10)
  *   INT  - P0.20
@@ -159,6 +161,16 @@
 
 int nrf53_bringup(void);
 
+/****************************************************************************
+ * Name: nrf53_sensors_init
+ *
+ * Description:
+ *   Initialize on-board sensors
+ *
+ ****************************************************************************/
+
+int nrf53_sensors_init(void);
+
 /****************************************************************************
  * Name: nrf53_rgbled_initialize
  *
@@ -193,5 +205,18 @@ int nrf53_i2c_register(int bus);
 int nrf53_i2ctool(void);
 #endif
 
+/****************************************************************************
+ * Name: nrf53_spidev_initialize
+ *
+ * Description:
+ *   Called to configure SPI chip select GPIO pins for the
+ *   thingy53 board.
+ *
+ ****************************************************************************/
+
+#ifdef CONFIG_NRF53_SPI_MASTER
+void nrf53_spidev_initialize(void);
+#endif
+
 #endif /* __ASSEMBLY__ */
 #endif /* __BOARDS_ARM_NRF53_THINGY53_SRC_THINGY53_H */
