@@ -68,6 +68,16 @@
 #include "rp2040_bmp280.h"
 #endif
 
+#ifdef CONFIG_SENSORS_SHT4X
+#include <nuttx/sensors/sht4x.h>
+#include "rp2040_i2c.h"
+#endif
+
+#ifdef CONFIG_SENSORS_MAX6675
+#include <nuttx/sensors/max6675.h>
+#include "rp2040_max6675.h"
+#endif
+
 #ifdef CONFIG_RP2040_PWM
 #include "rp2040_pwm.h"
 #include "rp2040_pwmdev.h"
@@ -466,6 +476,16 @@ int rp2040_common_bringup(void)
     }
 #endif
 
+#ifdef CONFIG_SENSORS_MAX6675
+  /* Try to register MAX6675 device as /dev/temp0 at SPI0 */
+
+  ret = board_max6675_initialize(0, 0);
+  if (ret < 0)
+    {
+      syslog(LOG_ERR, "Failed to initialize MAX6675 driver: %d\n", ret);
+    }
+#endif
+
 #ifdef CONFIG_SENSORS_INA219
   /* Configure and initialize the INA219 sensor in I2C0 */
 
@@ -476,6 +496,18 @@ int rp2040_common_bringup(void)
     }
 #endif
 
+#ifdef CONFIG_SENSORS_SHT4X
+
+  /* Try to register SHT4X device as /dev/sht4x0 at I2C0. */
+
+  ret = sht4x_register("/dev/sht4x0", rp2040_i2cbus_initialize(0),
+                       CONFIG_SHT4X_I2C_ADDR);
+  if (ret < 0)
+    {
+      syslog(LOG_ERR, "ERROR: couldn't initialize SHT4x: %d\n", ret);
+    }
+#endif
+
 #ifdef CONFIG_VIDEO_FB
   ret = fb_register(0, 0);
   if (ret < 0)
