@@ -384,10 +384,12 @@ static ssize_t smbus_sbd_write(struct file *filep, const char *buffer,
  *
  ****************************************************************************/
 
-static int smbus_sbd_callback(void *arg, size_t rx_len)
+static int smbus_sbd_callback(void *arg, i2c_slave_complete_t state,
+                              size_t rx_len)
 {
   struct smbus_sbd_dev_s *dev;
   int buffer_length;
+  int ret = OK;
   int i;
 
   /* Retrieve the pointer to the SMBus SBD slave device struct */
@@ -726,8 +728,15 @@ static int smbus_sbd_callback(void *arg, size_t rx_len)
    * request has been received.
    */
 
-  return I2CS_WRITE(dev->i2c_slave_dev, (const uint8_t *)dev->write_buffer,
-                    buffer_length);
+  ret = I2CS_WRITE(dev->i2c_slave_dev, (const uint8_t *)dev->write_buffer,
+                   buffer_length);
+  if (ret >= 0)
+    {
+      dev->i2c_slave_dev->callback(dev->i2c_slave_dev->callback_arg,
+                                   I2CS_TX_COMPLETE, buffer_length);
+    }
+
+  return ret;
 }
 
 /****************************************************************************
@@ -761,7 +770,7 @@ int smbus_sbd_initialize(int minor, struct i2c_slave_s *i2c_slave_dev)
 {
   irqstate_t flags;
   struct smbus_sbd_dev_s *smbus_sbd_dev;
-  char dev_name[24];
+  char devname[24];
   int ret;
 
   /* Make sure the initialization is not interrupted */
@@ -780,13 +789,13 @@ int smbus_sbd_initialize(int minor, struct i2c_slave_s *i2c_slave_dev)
     {
       /* Create the device name string */
 
-      snprintf(dev_name, 24, "/dev/smbus-sbd%d", minor);
+      snprintf(devname, sizeof(devname), "/dev/smbus-sbd%d", minor);
 
       /* Register the driver.  The associated private data is a reference to
        * the SMBus Smart Battery Data slave device structure.
        */
 
-      ret = register_driver(dev_name, &g_smbus_sbd_fops, 0, smbus_sbd_dev);
+      ret = register_driver(devname, &g_smbus_sbd_fops, 0, smbus_sbd_dev);
       if (ret < 0)
         {
           ferr("register_driver failed: %d\n", -ret);
