@@ -54,6 +54,10 @@
 #  include <nuttx/video/fb.h>
 #endif
 
+#ifdef CONFIG_USERLED
+#  include <nuttx/leds/userled.h>
+#endif
+
 #include "stm32_romfs.h"
 #include "nucleo-f446re.h"
 
@@ -250,6 +254,16 @@ int stm32_bringup(void)
     }
 #endif
 
+#ifdef CONFIG_USERLED
+  /* Register the LED driver */
+
+  ret = userled_lower_initialize("/dev/userleds");
+  if (ret < 0)
+    {
+      syslog(LOG_ERR, "ERROR: userled_lower_initialize() failed: %d\n", ret);
+    }
+#endif
+
 #ifdef CONFIG_DAC
   /* Initialize DAC and register the DAC driver. */
 
