@@ -31,6 +31,7 @@
 #include <debug.h>
 
 #include <nuttx/board.h>
+#include <nuttx/signal.h>
 #include <arch/board/board.h>
 #ifdef CONFIG_SENSORS_HYT271
 #  include <nuttx/sensors/hyt271.h>
@@ -110,7 +111,7 @@ static int stm32_i2c_power_reset(struct hyt271_bus_s *bus)
     }
 
   stm32_gpiowrite(BOARD_HYT271_POWOUT, false);
-  usleep(250000);
+  nxsig_usleep(250000);
   stm32_gpiowrite(BOARD_HYT271_POWOUT, true);
 
   while (1)
