@@ -289,6 +289,9 @@
 #define GPIO_ENC28J60_INTR  (GPIO_INPUT|GPIO_FLOAT|GPIO_EXTI|\
                              GPIO_OPENDRAIN|GPIO_PORTE|GPIO_PIN4)
 
+#define GPIO_CS_MFRC522      (GPIO_OUTPUT|GPIO_PUSHPULL|GPIO_SPEED_50MHz|\
+                            GPIO_OUTPUT_SET|GPIO_PORTE|GPIO_PIN3)
+
 /* Use same pins as ENC28J60 to W5500 */
 
 #define GPIO_W5500_CS      (GPIO_OUTPUT|GPIO_PUSHPULL|GPIO_SPEED_50MHz|\
