@@ -502,6 +502,11 @@
 #define GPIO_USART3_RX   (GPIO_USART3_RX_1 | GPIO_SPEED_100MHz)  /* PB11 */
 #define GPIO_USART3_TX   (GPIO_USART3_TX_1 | GPIO_SPEED_100MHz)  /* PB10 */
 
+/* UART7 (Discovery Virtual Console) */
+
+#define GPIO_UART7_RX   (GPIO_UART7_RX_1 | GPIO_SPEED_100MHz)  /* PA8 */
+#define GPIO_UART7_TX   (GPIO_UART7_TX_2 | GPIO_SPEED_100MHz)  /* PB4 */
+
 /* I2C4 - Used by Touchscreen and Audio Codec */
 
 #define GPIO_I2C4_SCL    (GPIO_I2C4_SCL_1 | GPIO_SPEED_50MHz)  /* PD12 */
