@@ -32,6 +32,7 @@
 
 #include <nuttx/arch.h>
 #include <nuttx/board.h>
+#include <nuttx/cache.h>
 #include <nuttx/lib/modlib.h>
 #include <nuttx/binfmt/symtab.h>
 #include <nuttx/drivers/ramdisk.h>
@@ -53,10 +54,6 @@
 #  include <nuttx/usb/composite.h>
 #endif
 
-#ifdef CONFIG_BOARDCTL_TESTSET
-#  include <nuttx/spinlock.h>
-#endif
-
 #if defined(CONFIG_BUILD_PROTECTED) && defined(CONFIG_BUILTIN)
 #  include <nuttx/lib/builtin.h>
 #endif
@@ -344,7 +341,7 @@ static inline int boardctl_pmctrl(FAR struct boardioc_pm_ctrl_s *ctrl)
 
 int boardctl(unsigned int cmd, uintptr_t arg)
 {
-  int ret;
+  int ret = OK;
 
   switch (cmd)
     {
@@ -398,6 +395,7 @@ int boardctl(unsigned int cmd, uintptr_t arg)
       case BOARDIOC_POWEROFF:
         {
           reboot_notifier_call_chain(SYS_POWER_OFF, (FAR void *)arg);
+          up_flush_dcache_all();
           ret = board_power_off((int)arg);
         }
         break;
@@ -414,6 +412,7 @@ int boardctl(unsigned int cmd, uintptr_t arg)
       case BOARDIOC_RESET:
         {
           reboot_notifier_call_chain(SYS_RESTART, (FAR void *)arg);
+          up_flush_dcache_all();
           ret = board_reset((int)arg);
         }
         break;
@@ -586,7 +585,6 @@ int boardctl(unsigned int cmd, uintptr_t arg)
 
          DEBUGASSERT(symdesc != NULL);
          exec_setsymtab(symdesc->symtab, symdesc->nsymbols);
-         ret = OK;
         }
         break;
 #endif
@@ -608,7 +606,6 @@ int boardctl(unsigned int cmd, uintptr_t arg)
 
          DEBUGASSERT(symdesc != NULL);
          modlib_setsymtab(symdesc->symtab, symdesc->nsymbols);
-         ret = OK;
         }
         break;
 #endif
@@ -643,7 +640,6 @@ int boardctl(unsigned int cmd, uintptr_t arg)
          DEBUGASSERT(builtin != NULL);
          builtin_setlist(builtin->builtins, builtin->count);
 #endif
-         ret = OK;
         }
         break;
 #endif
@@ -789,27 +785,65 @@ int boardctl(unsigned int cmd, uintptr_t arg)
 
 #endif /* CONFIG_NXTERM */
 
-#ifdef CONFIG_BOARDCTL_TESTSET
-      /* CMD:           BOARDIOC_TESTSET
-       * DESCRIPTION:   Access architecture-specific up_testset() operation
-       * ARG:           A pointer to a write-able spinlock object.  On
-       *                success the  preceding spinlock state is returned:
-       *                0=unlocked, 1=locked.
-       * CONFIGURATION: CONFIG_BOARDCTL_TESTSET
-       * DEPENDENCIES:  Architecture-specific logic provides up_testset()
+#ifdef CONFIG_BOARDCTL_SPINLOCK
+      /* CMD:           BOARDIOC_SPINLOCK
+       * DESCRIPTION:   Access spinlock specific operation
+       * ARG:           A pointer to a write-able boardioc_spinlock_s
+       *                object.
+       * CONFIGURATION: CONFIG_BOARDCTL_SPINLOCK
+       * DEPENDENCIES:  spinlock specific logic
        */
 
-      case BOARDIOC_TESTSET:
+      case BOARDIOC_SPINLOCK:
         {
-          volatile FAR spinlock_t *lock = (volatile FAR spinlock_t *)arg;
+          FAR struct boardioc_spinlock_s *spinlock =
+            (FAR struct boardioc_spinlock_s *)arg;
+          FAR volatile spinlock_t *lock = spinlock->lock;
+          FAR irqstate_t *flags = spinlock->flags;
 
-          if (lock == NULL)
+          if (spinlock->action == BOARDIOC_SPINLOCK_LOCK)
             {
-              ret = -EINVAL;
+              if (flags != NULL)
+                {
+                  *flags = up_irq_save();
+                }
+
+              if (lock != NULL)
+                {
+                  spin_lock(lock);
+                }
+            }
+          else if (spinlock->action == BOARDIOC_SPINLOCK_TRYLOCK)
+            {
+              if (flags != NULL)
+                {
+                  *flags = up_irq_save();
+                }
+
+              if (!spin_trylock(lock))
+                {
+                  ret = -EBUSY;
+                  if (flags != NULL)
+                    {
+                      up_irq_restore(*flags);
+                    }
+                }
+            }
+          else if (spinlock->action == BOARDIOC_SPINLOCK_UNLOCK)
+            {
+              if (flags != NULL)
+                {
+                  up_irq_restore(*flags);
+                }
+
+              if (lock != NULL)
+                {
+                  spin_unlock(lock);
+                }
             }
           else
             {
-              ret = up_testset(lock) == SP_LOCKED ? 1 : 0;
+              ret = -EINVAL;
             }
         }
         break;
@@ -855,6 +889,22 @@ int boardctl(unsigned int cmd, uintptr_t arg)
         break;
 #endif
 
+#ifdef CONFIG_BOARDCTL_START_CPU
+      /* CMD:           BOARDIOC_START_CPU
+       * DESCRIPTION:   Start specified slave core by master core
+       * ARG:           Integer value for cpu core id.
+       * CONFIGURATION: CONFIG_BOARDCTL_START_CPU
+       * DEPENDENCIES:  Board logic must provide the
+       *                board_start_cpu() interface.
+       */
+
+      case BOARDIOC_START_CPU:
+        {
+          ret = board_start_cpu((int)arg);
+        }
+        break;
+#endif
+
        default:
          {
 #ifdef CONFIG_BOARDCTL_IOCTL
