@@ -34,7 +34,20 @@
 #include <sys/mount.h>
 #include <sys/boardctl.h>
 #include <arch/board/board_memorymap.h>
-#include "bl808_courier.h"
+
+#ifdef CONFIG_USERLED
+#include <nuttx/leds/userled.h>
+#endif
+#if defined(CONFIG_BL808_SPI0) || defined(CONFIG_BL808_SPI1)
+#include "bl808_spi.h"
+#endif
+#ifdef CONFIG_BL808_TIMERS
+#include "bl808_timer.h"
+#endif
+#ifdef CONFIG_BL808_WDT
+#include "bl808_wdt.h"
+#endif
+#include "bl808_gpadc.h"
 
 /****************************************************************************
  * Pre-processor Definitions
@@ -158,15 +171,43 @@ void board_late_initialize(void)
 
   mount_ramdisk();
 
-  /* Initialize courier to get IRQs from M0 */
-
-  bl808_courier_init();
-
   /* Perform board-specific initialization */
 
+#ifdef CONFIG_BL808_GPADC
+  bl808_gpadc_init();
+#endif
+
+#ifdef CONFIG_BL808_SPI0
+  struct spi_dev_s *spi0 = bl808_spibus_initialize(0);
+  spi_register(spi0, 0);
+#endif
+
+#ifdef CONFIG_BL808_SPI1
+  struct spi_dev_s *spi1 = bl808_spibus_initialize(1);
+  spi_register(spi1, 1);
+#endif
+
+#ifdef CONFIG_BL808_TIMERS
+  bl808_timer_init();
+#endif
+
+#ifdef CONFIG_BL808_WDT
+  bl808_wdt_init();
+#endif
+
 #ifdef CONFIG_NSH_ARCHINIT
 
   mount(NULL, "/proc", "procfs", 0, NULL);
 
 #endif
+
+#ifdef CONFIG_USERLED
+  /* Register the LED driver */
+
+  int ret = userled_lower_initialize("/dev/userleds");
+  if (ret < 0)
+    {
+      syslog(LOG_ERR, "ERROR: userled_lower_initialize() failed: %d\n", ret);
+    }
+#endif
 }
