@@ -36,13 +36,17 @@
 
 #include <sys/mount.h>
 
-#ifndef CONFIG_BUILD_KERNEL
 #include "hardware/qemu_rv_memorymap.h"
 #include "qemu_rv_memorymap.h"
-#endif
+#include "qemu_rv_rptun.h"
+
 #include "riscv_internal.h"
 #include "romfs.h"
 
+#ifdef CONFIG_USERLED
+#include <nuttx/leds/userled.h>
+#endif
+
 /****************************************************************************
  * Pre-processor Definitions
  ****************************************************************************/
@@ -131,8 +135,14 @@ int board_app_initialize(uintptr_t arg)
 #endif
 
 #ifdef CONFIG_DRIVERS_VIRTIO_MMIO
+#ifndef CONFIG_BOARD_EARLY_INITIALIZE
   qemu_virtio_register_mmio_devices();
 #endif
+#endif
+
+#ifdef CONFIG_RPTUN
+  qemu_rptun_init();
+#endif
 
   return OK;
 #endif
@@ -181,15 +191,32 @@ void board_late_initialize(void)
   mount(NULL, "/proc", "procfs", 0, NULL);
 
 #endif
+
+#ifdef CONFIG_USERLED
+  /* Register the LED driver */
+
+  int ret = userled_lower_initialize("/dev/userleds");
+  if (ret < 0)
+    {
+      syslog(LOG_ERR, "ERROR: userled_lower_initialize() failed: %d\n", ret);
+    }
+#endif
+}
+
+void board_early_initialize(void)
+{
+#ifdef CONFIG_DRIVERS_VIRTIO_MMIO
+  qemu_virtio_register_mmio_devices();
+#endif
 }
 
 #ifdef CONFIG_BOARDCTL_POWEROFF
 int board_power_off(int status)
 {
-#ifdef CONFIG_BUILD_KERNEL
+#if defined(CONFIG_BUILD_KERNEL) && ! defined(CONFIG_NUTTSBI)
   riscv_sbi_system_reset(SBI_SRST_TYPE_SHUTDOWN, SBI_SRST_REASON_NONE);
 #else
-  *(FAR volatile uint32_t *)QEMU_RV_RESET_BASE = QEMU_RV_RESET_DONE;
+  *(volatile uint32_t *)QEMU_RV_RESET_BASE = QEMU_RV_RESET_DONE;
 #endif
 
   UNUSED(status);
