@@ -110,7 +110,8 @@ static ssize_t cryptof_write(FAR struct file *filep,
 static int cryptof_ioctl(FAR struct file *filep,
                          int cmd, unsigned long arg);
 static int cryptof_poll(FAR struct file *filep,
-                        struct pollfd *fds, bool setup);
+                        FAR struct pollfd *fds, bool setup);
+static int cryptof_open(FAR struct file *filep);
 static int cryptof_close(FAR struct file *filep);
 
 static int cryptoopen(FAR struct file *filep);
@@ -127,7 +128,7 @@ static int cryptoioctl(FAR struct file *filep, int cmd, unsigned long arg);
 
 static const struct file_operations g_cryptofops =
 {
-  NULL,                /* open   */
+  cryptof_open,        /* open   */
   cryptof_close,       /* close  */
   cryptof_read,        /* read   */
   cryptof_write,       /* write  */
@@ -223,6 +224,7 @@ static int cryptof_ioctl(FAR struct file *filep,
             case CRYPTO_BLF_CBC:
             case CRYPTO_CAST_CBC:
             case CRYPTO_AES_CBC:
+            case CRYPTO_AES_CMAC:
             case CRYPTO_AES_CTR:
             case CRYPTO_AES_XTS:
             case CRYPTO_AES_OFB:
@@ -246,12 +248,16 @@ static int cryptof_ioctl(FAR struct file *filep,
             case CRYPTO_SHA2_384_HMAC:
             case CRYPTO_SHA2_512_HMAC:
             case CRYPTO_AES_128_GMAC:
+            case CRYPTO_AES_128_CMAC:
             case CRYPTO_MD5:
+            case CRYPTO_POLY1305:
+            case CRYPTO_RIPEMD160:
             case CRYPTO_SHA1:
             case CRYPTO_SHA2_224:
             case CRYPTO_SHA2_256:
             case CRYPTO_SHA2_384:
             case CRYPTO_SHA2_512:
+            case CRYPTO_CRC32:
               thash = true;
               break;
             default:
@@ -283,6 +289,7 @@ static int cryptof_ioctl(FAR struct file *filep,
         if (thash)
           {
             cria.cri_alg = sop->mac;
+            cria.cri_sid = -1;
             cria.cri_klen = sop->mackeylen * 8;
 
             if (cria.cri_klen)
@@ -364,7 +371,7 @@ bail:
         error = crypto_getfeat((FAR int *)arg);
         break;
       default:
-        error = -EINVAL;
+        error = -ENOTTY;
     }
 
   return error;
@@ -379,14 +386,6 @@ int cryptodev_op(FAR struct csession *cse,
   int error = OK;
   uint32_t hid;
 
-  if (cse->txform)
-    {
-      if (cop->len == 0)
-        {
-          return -EINVAL;
-        }
-    }
-
   /* number of requests, not logical and */
 
   crp = crypto_getreq(cse->txform + cse->thash);
@@ -570,27 +569,73 @@ int cryptodev_key(FAR struct crypt_kop *kop)
     {
       case CRK_MOD_EXP:
         if (in == 3 && out == 1)
-          break;
+          {
+            break;
+          }
+
         return -EINVAL;
       case CRK_MOD_EXP_CRT:
         if (in == 6 && out == 1)
-          break;
+          {
+            break;
+          }
+
         return -EINVAL;
       case CRK_DSA_SIGN:
         if (in == 5 && out == 2)
-          break;
+          {
+            break;
+          }
+
         return -EINVAL;
       case CRK_DSA_VERIFY:
         if (in == 7 && out == 0)
-          break;
+          {
+            break;
+          }
+
         return -EINVAL;
       case CRK_DH_COMPUTE_KEY:
         if (in == 3 && out == 1)
-          break;
+          {
+            break;
+          }
+
         return -EINVAL;
-      case CRK_RSA_PCKS15_VERIFY:
+      case CRK_DH_MAKE_PUBLIC:
+        if (in == 2 && out == 2)
+          {
+            break;
+          }
+
+        return -EINVAL;
+      case CRK_RSA_PKCS15_VERIFY:
         if (in == 5 && out == 0)
-          break;
+          {
+            break;
+          }
+
+        return -EINVAL;
+      case CRK_ECDSA_SECP256R1_SIGN:
+        if (in == 2 && out == 2)
+          {
+            break;
+          }
+
+        return -EINVAL;
+      case CRK_ECDSA_SECP256R1_VERIFY:
+        if (in == 6 && out == 0)
+          {
+            break;
+          }
+
+        return -EINVAL;
+      case CRK_ECDSA_SECP256R1_GENKEY:
+        if (in == 0 && out == 4)
+          {
+            break;
+          }
+
         return -EINVAL;
       default:
         return -EINVAL;
@@ -678,7 +723,7 @@ fail:
 /* ARGSUSED */
 
 static int cryptof_poll(FAR struct file *filep,
-                        struct pollfd *fds, bool setup)
+                        FAR struct pollfd *fds, bool setup)
 {
   return 0;
 }
@@ -702,6 +747,122 @@ static int cryptof_close(FAR struct file *filep)
   return 0;
 }
 
+/* Clone csessions into a new fd */
+
+static int cryptof_open(FAR struct file *filep)
+{
+  FAR struct fcrypt *fcr = filep->f_priv;
+  FAR struct fcrypt *fcrd = NULL;
+  FAR struct csession *cse;
+  FAR struct csession *csed;
+  struct cryptoini cria;
+  struct cryptoini crie;
+  uint64_t sid;
+  int ret = 0;
+
+  if (fcr == NULL)
+    {
+      return -EINVAL;
+    }
+
+  /* A 'struct fcrypt' is bound to the fd of the cryptodev,
+   * which stores a list of sessions. Each encryption operation
+   * would create a context and get a session id, which can be
+   * used to find the specific encryption operation. Therefore,
+   * in order to complete the copy operation, it is necessary to
+   * create same session based on the copy fd and obtain the newly
+   * generated session id.
+   */
+
+  fcrd = kmm_zalloc(sizeof(struct fcrypt));
+  if (fcrd == NULL)
+    {
+      return -ENOMEM;
+    }
+
+  TAILQ_INIT(&fcrd->csessions);
+  TAILQ_FOREACH(cse, &fcr->csessions, next)
+    {
+      bzero(&crie, sizeof(crie));
+      bzero(&cria, sizeof(cria));
+      if (cse->txform)
+        {
+          crie.cri_alg = cse->cipher;
+          crie.cri_klen = cse->keylen * 8;
+
+          crie.cri_key = kmm_malloc(cse->keylen);
+          if (crie.cri_key == NULL)
+            {
+              ret = -ENOMEM;
+              goto bail;
+            }
+
+          memcpy(crie.cri_key, cse->key, cse->keylen);
+          if (cse->thash)
+            {
+              crie.cri_next = &cria;
+            }
+        }
+
+      if (cse->thash)
+        {
+          cria.cri_alg = cse->mac;
+          cria.cri_sid = cse->sid;
+          cria.cri_klen = cse->mackeylen * 8;
+
+          if (cria.cri_klen)
+            {
+              cria.cri_key = kmm_malloc(cse->mackeylen);
+              if (cria.cri_key == NULL)
+                {
+                  ret = -ENOMEM;
+                  goto bail;
+                }
+
+              memcpy(cria.cri_key, cse->mackey, cse->mackeylen);
+            }
+        }
+
+      ret = crypto_newsession(&sid, cse->txform ? &crie : &cria,
+                              !cryptodevallowsoft);
+      if (ret < 0)
+        {
+          goto bail;
+        }
+
+      csed = csecreate(fcrd, sid, crie.cri_key, crie.cri_klen,
+                        cria.cri_key, cria.cri_klen,
+                        cse->cipher, cse->mac, cse->txform,
+                        cse->thash);
+      if (csed == NULL)
+        {
+          crypto_freesession(sid);
+          ret = -EINVAL;
+          goto bail;
+        }
+
+      csed->ses = cse->ses;
+    }
+
+  filep->f_priv = fcrd;
+  return 0;
+
+bail:
+  if (crie.cri_key)
+    {
+      explicit_bzero(crie.cri_key, crie.cri_klen / 8);
+      kmm_free(crie.cri_key);
+    }
+
+  if (cria.cri_key)
+    {
+      explicit_bzero(cria.cri_key, cria.cri_klen / 8);
+      kmm_free(cria.cri_key);
+    }
+
+  return ret;
+}
+
 static int cryptoopen(FAR struct file *filep)
 {
   if (usercrypto == 0)
