@@ -70,10 +70,19 @@
 #include <crypto/cryptodev.h>
 #include <crypto/xform.h>
 #include <crypto/gmac.h>
+#include <crypto/cmac.h>
 #include <crypto/chachapoly.h>
+#include <crypto/poly1305.h>
+#include <nuttx/crc32.h>
 
 #include "des_locl.h"
 
+/****************************************************************************
+ * Pre-processor Definitions
+ ****************************************************************************/
+
+#define CRC32_XOR_VALUE 0xFFFFFFFFUL
+
 /****************************************************************************
  * Public Functions
  ****************************************************************************/
@@ -117,6 +126,10 @@ void aes_xts_reinit(caddr_t, FAR uint8_t *);
 void aes_gcm_reinit(caddr_t, FAR uint8_t *);
 void aes_ofb_reinit(caddr_t, FAR uint8_t *);
 
+void null_init(FAR void *);
+void poly1305_setkey(FAR void *, FAR const uint8_t *, uint16_t);
+int poly1305update_int(FAR void *, FAR const uint8_t *, size_t);
+int poly1305_final(FAR uint8_t *, FAR void *);
 int md5update_int(FAR void *, FAR const uint8_t *, size_t);
 int sha1update_int(FAR void *, FAR const uint8_t *, size_t);
 int rmd160update_int(FAR void *, FAR const uint8_t *, size_t);
@@ -124,6 +137,9 @@ int sha224update_int(FAR void *, FAR const uint8_t *, size_t);
 int sha256update_int(FAR void *, FAR const uint8_t *, size_t);
 int sha384update_int(FAR void *, FAR const uint8_t *, size_t);
 int sha512update_int(FAR void *, FAR const uint8_t *, size_t);
+void crc32setkey(FAR void *, FAR const uint8_t *, uint16_t);
+int crc32update(FAR void *, FAR const uint8_t *, size_t);
+void crc32final(FAR uint8_t *, FAR void *);
 
 struct aes_ctr_ctx
 {
@@ -225,6 +241,16 @@ const struct enc_xform enc_xform_aes_gmac =
   NULL
 };
 
+const struct enc_xform enc_xform_aes_cmac =
+{
+  CRYPTO_AES_CMAC, "AES-CMAC",
+  1, 0, 16, 32, 0,
+  null_encrypt,
+  null_decrypt,
+  null_setkey,
+  NULL
+};
+
 const struct enc_xform enc_xform_aes_xts =
 {
   CRYPTO_AES_XTS, "AES-XTS",
@@ -380,6 +406,16 @@ const struct auth_hash auth_hash_chacha20_poly1305 =
   chacha20_poly1305_final
 };
 
+const struct auth_hash auth_hash_cmac_aes_128 =
+{
+  CRYPTO_AES_128_CMAC, "CMAC-AES-128",
+  16, AES_CMAC_KEY_LENGTH, AES_CMAC_DIGEST_LENGTH, sizeof(AES_CMAC_CTX),
+  AESCTR_BLOCKSIZE, (void (*)(FAR void *)) aes_cmac_init,
+  (void (*)(FAR void *, FAR const uint8_t *, uint16_t)) aes_cmac_setkey,
+  NULL, (int (*)(FAR void *, FAR const uint8_t *, size_t)) aes_cmac_update,
+  (void (*) (FAR uint8_t *, FAR void *)) aes_cmac_final
+};
+
 const struct auth_hash auth_hash_md5 =
 {
   CRYPTO_MD5, "MD5",
@@ -389,6 +425,24 @@ const struct auth_hash auth_hash_md5 =
   (void (*) (FAR uint8_t *, FAR void *)) md5final
 };
 
+const struct auth_hash auth_hash_poly1305 =
+{
+  CRYPTO_POLY1305, "POLY1305",
+  0, 16, 16, sizeof(poly1305_state), poly1305_block_size,
+  (void (*) (FAR void *)) null_init, poly1305_setkey, NULL,
+  poly1305update_int,
+  (void (*) (FAR uint8_t *, FAR void *)) poly1305_final
+};
+
+const struct auth_hash auth_hash_ripemd_160 =
+{
+  CRYPTO_RIPEMD160, "RIPEMD160",
+  0, 20, 20, sizeof(RMD160_CTX), HMAC_RIPEMD160_BLOCK_LEN,
+  (void (*) (FAR void *)) rmd160init, NULL, NULL,
+  rmd160update_int,
+  (void (*) (FAR uint8_t *, FAR void *)) rmd160final
+};
+
 const struct auth_hash auth_hash_sha1 =
 {
   CRYPTO_SHA1, "SHA1",
@@ -434,6 +488,13 @@ const struct auth_hash auth_hash_sha2_512 =
   (void (*)(FAR uint8_t *, FAR void *)) sha512final
 };
 
+const struct auth_hash auth_hash_crc32 =
+{
+  CRYPTO_CRC32, "CRC32",
+  0, 32, 0, sizeof(uint32_t), 1,
+  null_init, crc32setkey, NULL, crc32update, crc32final
+};
+
 /* Encryption wrapper routines. */
 
 void des3_encrypt(caddr_t key, FAR uint8_t *blk)
@@ -557,7 +618,9 @@ void aes_ctr_crypt(caddr_t key, FAR uint8_t *data)
   for (i = AESCTR_BLOCKSIZE - 1;
         i >= AESCTR_NONCESIZE + AESCTR_IVSIZE; i--)
     {
-      if (++ctx->ac_block[i])   /* continue on overflow */
+      /* continue on overflow */
+
+      if (++ctx->ac_block[i])
         {
           break;
         }
@@ -789,6 +852,30 @@ void aes_cfb128_decrypt(caddr_t key, FAR uint8_t *data)
 
 /* And now for auth. */
 
+void null_init(FAR void *ctx)
+{
+}
+
+void poly1305_setkey(FAR void *sched, FAR const uint8_t *key, uint16_t len)
+{
+  FAR struct poly1305_state *ctx;
+
+  ctx = (FAR struct poly1305_state *)sched;
+  poly1305_begin(ctx, key);
+}
+
+int poly1305update_int(FAR void *ctx, FAR const uint8_t *buf, size_t len)
+{
+  poly1305_update(ctx, buf, len);
+  return 0;
+}
+
+int poly1305_final(FAR uint8_t *digest, FAR void *ctx)
+{
+  poly1305_finish(ctx, digest);
+  return 0;
+}
+
 int rmd160update_int(FAR void *ctx, FAR const uint8_t *buf, size_t len)
 {
   rmd160update(ctx, buf, len);
@@ -830,3 +917,24 @@ int sha512update_int(FAR void *ctx, FAR const uint8_t *buf, size_t len)
   sha512update(ctx, buf, len);
   return 0;
 }
+
+void crc32setkey(FAR void *ctx, FAR const uint8_t *key, uint16_t len)
+{
+  FAR uint32_t *val = (FAR uint32_t *)key;
+  uint32_t tmp = (*val) ^ CRC32_XOR_VALUE;
+  memcpy(ctx, &tmp, len);
+}
+
+int crc32update(FAR void *ctx, FAR const uint8_t *buf, size_t len)
+{
+  FAR uint32_t *startval = (FAR uint32_t *)ctx;
+  *startval = crc32part(buf, len, *startval);
+  return 0;
+}
+
+void crc32final(FAR uint8_t *digest, FAR void *ctx)
+{
+  FAR uint32_t *val = (FAR uint32_t *)ctx;
+  uint32_t result = (*val) ^ CRC32_XOR_VALUE;
+  memcpy(digest, &result, sizeof(uint32_t));
+}
