@@ -55,7 +55,7 @@ static int     adc_reset(FAR struct adc_dev_s *dev);
 static int     adc_receive(FAR struct adc_dev_s *dev, uint8_t ch,
                            int32_t data);
 static void    adc_notify(FAR struct adc_dev_s *dev);
-static int     adc_poll(FAR struct file *filep, struct pollfd *fds,
+static int     adc_poll(FAR struct file *filep, FAR struct pollfd *fds,
                         bool setup);
 static int     adc_reset_fifo(FAR struct adc_dev_s *dev);
 static int     adc_samples_on_read(FAR struct adc_dev_s *dev);
@@ -523,7 +523,8 @@ static void adc_notify(FAR struct adc_dev_s *dev)
  * Name: adc_poll
  ****************************************************************************/
 
-static int adc_poll(FAR struct file *filep, struct pollfd *fds, bool setup)
+static int adc_poll(FAR struct file *filep, FAR struct pollfd *fds,
+                    bool setup)
 {
   FAR struct inode     *inode = filep->f_inode;
   FAR struct adc_dev_s *dev   = inode->i_private;
@@ -583,7 +584,7 @@ static int adc_poll(FAR struct file *filep, struct pollfd *fds, bool setup)
     {
       /* This is a request to tear down the poll. */
 
-      struct pollfd **slot = (struct pollfd **)fds->priv;
+      FAR struct pollfd **slot = (FAR struct pollfd **)fds->priv;
 
       /* Remove all memory of the poll setup */
 
