@@ -845,11 +845,10 @@ static int es8311_getcaps(FAR struct audio_lowerhalf_s *dev, int type,
 
               /* 8kHz is hardware dependent */
 
-              caps->ac_controls.b[0] =
+              caps->ac_controls.hw[0] =
                 AUDIO_SAMP_RATE_11K | AUDIO_SAMP_RATE_16K |
                 AUDIO_SAMP_RATE_22K | AUDIO_SAMP_RATE_32K |
                 AUDIO_SAMP_RATE_44K | AUDIO_SAMP_RATE_48K;
-              caps->ac_controls.b[1] = 0;
               break;
          }
 
@@ -863,11 +862,10 @@ static int es8311_getcaps(FAR struct audio_lowerhalf_s *dev, int type,
           {
               /* Report supported input sample rates */
 
-              caps->ac_controls.b[0] =
+              caps->ac_controls.hw[0] =
                 AUDIO_SAMP_RATE_11K | AUDIO_SAMP_RATE_16K |
                 AUDIO_SAMP_RATE_22K | AUDIO_SAMP_RATE_32K |
                 AUDIO_SAMP_RATE_44K | AUDIO_SAMP_RATE_48K;
-              caps->ac_controls.b[1] = 0;
               break;
          }
 
@@ -1033,19 +1031,25 @@ static int es8311_configure(FAR struct audio_lowerhalf_s *dev,
             break;
           }
 
+        es8311_audio_output(priv);
+        es8311_reset(priv);
+
         /* Save the current stream configuration */
 
         priv->samprate  = caps->ac_controls.hw[0];
         priv->bpsamp    = caps->ac_controls.b[2];
 
-        es8311_audio_output(priv);
-        es8311_reset(priv);
-        es8311_setsamplerate(priv);
-        es8311_setbitspersample(priv);
+        ret = es8311_setsamplerate(priv) == -ENOTTY ? OK : ret;
+        if (ret < 0)
+          {
+            break;
+          }
+
+        ret = es8311_setbitspersample(priv) == -ENOTTY ? OK : ret;
       }
       break;
 
-        case AUDIO_TYPE_INPUT:
+    case AUDIO_TYPE_INPUT:
       {
         audinfo("  AUDIO_TYPE_INPUT:\n");
         audinfo("    Number of channels: %u\n", caps->ac_channels);
@@ -1074,15 +1078,21 @@ static int es8311_configure(FAR struct audio_lowerhalf_s *dev,
             break;
           }
 
+        es8311_audio_input(priv);
+        es8311_reset(priv);
+
         /* Save the current stream configuration */
 
         priv->samprate  = caps->ac_controls.hw[0];
         priv->bpsamp    = caps->ac_controls.b[2];
 
-        es8311_audio_input(priv);
-        es8311_reset(priv);
-        es8311_setsamplerate(priv);
-        es8311_setbitspersample(priv);
+        ret = es8311_setsamplerate(priv) == -ENOTTY ? OK : ret;
+        if (ret != OK)
+          {
+            break;
+          }
+
+        ret = es8311_setbitspersample(priv) == -ENOTTY ? OK : ret;
       }
       break;
 
