@@ -80,8 +80,8 @@ static uint32_t __clk_round_rate(FAR struct clk_s *clk, uint32_t rate);
 static int __clk_enable(FAR struct clk_s *clk);
 static int __clk_disable(FAR struct clk_s *clk);
 
-static struct clk_s *__clk_lookup(FAR const char *name,
-                                  FAR struct clk_s *clk);
+static FAR struct clk_s *__clk_lookup(FAR const char *name,
+                                      FAR struct clk_s *clk);
 static int __clk_register(FAR struct clk_s *clk);
 
 static void clk_disable_unused_subtree(FAR struct clk_s *clk);
@@ -98,7 +98,7 @@ static ssize_t clk_procfs_read(FAR struct file *filep, FAR char *buffer,
                                size_t buflen);
 static int clk_procfs_dup(FAR const struct file *oldp,
                           FAR struct file *newp);
-static int clk_procfs_stat(const char *relpath, struct stat *buf);
+static int clk_procfs_stat(FAR const char *relpath, FAR struct stat *buf);
 
 #endif /* !defined(CONFIG_FS_PROCFS_EXCLUDE_CLK) && defined(CONFIG_FS_PROCFS) */
 
@@ -164,7 +164,7 @@ static int clk_procfs_close(FAR struct file *filep)
 }
 
 static size_t clk_procfs_printf(FAR char *buffer, size_t buflen,
-                                off_t *pos, FAR const char *fmt,
+                                FAR off_t *pos, FAR const char *fmt,
                                 ...)
 {
   char tmp[CLK_PROCFS_LINELEN];
@@ -180,7 +180,7 @@ static size_t clk_procfs_printf(FAR char *buffer, size_t buflen,
 
 static size_t clk_procfs_show_subtree(FAR struct clk_s *clk, int level,
                                       FAR char *buffer, size_t buflen,
-                                      off_t *pos, FAR irqstate_t *flags)
+                                      FAR off_t *pos, FAR irqstate_t *flags)
 {
   FAR struct clk_s *child;
   size_t oldlen = buflen;
@@ -223,7 +223,7 @@ static size_t clk_procfs_show_subtree(FAR struct clk_s *clk, int level,
 }
 
 static size_t clk_procfs_showtree(FAR char *buffer,
-                                  size_t buflen, off_t *pos)
+                                  size_t buflen, FAR off_t *pos)
 {
   FAR struct clk_s *clk;
   size_t oldlen = buflen;
@@ -305,7 +305,7 @@ static int clk_procfs_dup(FAR const struct file *oldp,
   return OK;
 }
 
-static int clk_procfs_stat(const char *relpath, struct stat *buf)
+static int clk_procfs_stat(FAR const char *relpath, FAR struct stat *buf)
 {
   /* File/directory size, access block size */
 
@@ -426,7 +426,7 @@ static void clk_calc_subtree(FAR struct clk_s *clk, uint32_t new_rate,
 }
 
 static FAR struct clk_s *clk_calc_new_rates(FAR struct clk_s *clk,
-                                      uint32_t rate)
+                                            uint32_t rate)
 {
   FAR struct clk_s *top = clk;
   FAR struct clk_s *old_parent;
@@ -561,8 +561,8 @@ static void clk_change_rate(FAR struct clk_s *clk, uint32_t best_parent_rate)
     }
 }
 
-static struct clk_s *__clk_lookup(FAR const char *name,
-                                  FAR struct clk_s *clk)
+static FAR struct clk_s *__clk_lookup(FAR const char *name,
+                                      FAR struct clk_s *clk)
 {
   FAR struct clk_s *child;
   FAR struct clk_s *ret;
@@ -1198,7 +1198,7 @@ FAR struct clk_s *clk_register(FAR const char *name,
   size_t len;
   int i;
 
-  off = len = sizeof(struct clk_s) + num_parents * sizeof(char *);
+  off = len = sizeof(struct clk_s) + num_parents * sizeof(FAR char *);
   if (!(flags & CLK_PARENT_NAME_IS_STATIC))
     {
       for (i = 0; i < num_parents; i++)
@@ -1228,8 +1228,8 @@ FAR struct clk_s *clk_register(FAR const char *name,
           return NULL;
         }
 
-      clk->name = (char *)clk + len;
-      strlcpy((char *)clk->name, name, size);
+      clk->name = (FAR char *)clk + len;
+      strlcpy((FAR char *)clk->name, name, size);
     }
 
   clk->ops = ops;
@@ -1238,7 +1238,7 @@ FAR struct clk_s *clk_register(FAR const char *name,
 
   if (private_data)
     {
-      clk->private_data = (char *)clk + off;
+      clk->private_data = (FAR char *)clk + off;
       memcpy(clk->private_data, private_data, private_size);
       off += private_size;
     }
@@ -1251,8 +1251,9 @@ FAR struct clk_s *clk_register(FAR const char *name,
         }
       else
         {
-          clk->parent_names[i] = (char *)clk + off;
-          strlcpy((char *)clk->parent_names[i], parent_names[i], len - off);
+          clk->parent_names[i] = (FAR char *)clk + off;
+          strlcpy((FAR char *)clk->parent_names[i], parent_names[i],
+                  len - off);
           off += strlen(parent_names[i]) + 1;
         }
     }
