@@ -30,7 +30,9 @@
 #include <stdint.h>
 #include <strings.h>
 #include <sys/param.h>
+
 #include <nuttx/bits.h>
+#include <nuttx/lib/math32.h>
 
 #ifdef CONFIG_CLK
 
@@ -40,9 +42,6 @@
 
 #define MASK(width)                 (BIT(width) - 1)
 #define MULT_ROUND_UP(r, m)         ((r) * (m) + (m) - 1)
-#define DIV_ROUND_UP(n,d)           (((n) + (d) - 1) / (d))
-#define DIV_ROUND_CLOSEST(n, d)     ((((n) < 0) ^ ((d) < 0)) ? \
-                                    (((n) - (d)/2)/(d)) : (((n) + (d)/2)/(d)))
 
 /****************************************************************************
  * Inline Functions
@@ -50,12 +49,12 @@
 
 static inline void clk_write(uint32_t reg, uint32_t value)
 {
-  *((volatile uint32_t *) (reg)) = value;
+  *((volatile uint32_t *)(uintptr_t)reg) = value;
 }
 
 static inline uint32_t clk_read(uint32_t reg)
 {
-  return *((volatile uint32_t *) (reg));
+  return *((volatile uint32_t *)(uintptr_t)reg);
 }
 
 static inline uint32_t gcd(uint32_t a, uint32_t b)
@@ -84,21 +83,6 @@ static inline uint32_t gcd(uint32_t a, uint32_t b)
   return b;
 }
 
-static inline int is_power_of_2(uint32_t n)
-{
-  return (n != 0 && ((n & (n - 1)) == 0));
-}
-
-static inline uint32_t roundup_pow_of_two(uint32_t n)
-{
-  return 1 << fls(n - 1);
-}
-
-static inline uint32_t rounddown_pow_of_two(uint32_t n)
-{
-  return 1 << (fls(n) - 1);
-}
-
 static inline uint32_t roundup_double(double n)
 {
   uint32_t intn = (uint32_t)n;
