@@ -36,23 +36,61 @@
 #include <nuttx/net/tun.h>
 #include <nuttx/net/telnet.h>
 #include <nuttx/note/note_driver.h>
+#include <nuttx/pci/pci.h>
 #include <nuttx/power/pm.h>
 #include <nuttx/power/regulator.h>
+#include <nuttx/reset/reset-controller.h>
 #include <nuttx/segger/rtt.h>
 #include <nuttx/sensors/sensor.h>
 #include <nuttx/serial/pty.h>
 #include <nuttx/serial/uart_ram.h>
 #include <nuttx/syslog/syslog.h>
 #include <nuttx/syslog/syslog_console.h>
+#include <nuttx/thermal.h>
 #include <nuttx/trace.h>
 #include <nuttx/usrsock/usrsock_rpmsg.h>
 #include <nuttx/virtio/virtio.h>
 #include <nuttx/drivers/optee.h>
 
+/****************************************************************************
+ * Pre-processor Definitions
+ ****************************************************************************/
+
+/* Check if only one console device is selected.
+ * If you get this errro, search your .config file for CONSOLE_XXX_CONSOLE
+ * options and remove what is not needed.
+ */
+
+#if (defined(CONFIG_LWL_CONSOLE) + defined(CONFIG_SERIAL_CONSOLE) + \
+     defined(CONFIG_CDCACM_CONSOLE) + defined(CONFIG_PL2303_CONSOLE) + \
+     defined(CONFIG_SERIAL_RTT_CONSOLE) + defined(CONFIG_RPMSG_UART_CONSOLE)) > 1
+#  error More than one console driver selected. Check your configuration !
+#endif
+
 /****************************************************************************
  * Public Functions
  ****************************************************************************/
 
+/****************************************************************************
+ * Name: drivers_early_initialize
+ *
+ * Description:
+ *   drivers_early_initialize will be called once before OS initialization
+ *   when no system resource is ready to use.
+ *
+ *   drivers_early_initialize serves the purpose of bringing up drivers as
+ *   early as possible, so they can be used even during OS initialization.
+ *   It must not rely on any system resources, such as heap memory.
+ *
+ ****************************************************************************/
+
+void drivers_early_initialize(void)
+{
+#ifdef CONFIG_DRIVERS_NOTE
+  note_early_initialize();
+#endif
+}
+
 /****************************************************************************
  * Name: drivers_initialize
  *
@@ -94,6 +132,10 @@ void drivers_initialize(void)
   devzero_register();   /* Standard /dev/zero */
 #endif
 
+#ifdef CONFIG_DEV_MEM
+  devmem_register();
+#endif
+
 #if defined(CONFIG_DEV_LOOP)
   loop_register();      /* Standard /dev/loop */
 #endif
@@ -114,6 +156,10 @@ void drivers_initialize(void)
   regulator_rpmsg_server_init();
 #endif
 
+#if defined(CONFIG_RESET_RPMSG)
+  reset_rpmsg_server_init();
+#endif
+
   /* Initialize the serial device driver */
 
 #ifdef CONFIG_RPMSG_UART
@@ -214,6 +260,10 @@ void drivers_initialize(void)
   mtd_loop_register();
 #endif
 
+#if defined(CONFIG_PCI) && !defined(CONFIG_PCI_LATE_DRIVERS_REGISTER)
+  pci_register_drivers();
+#endif
+
 #ifdef CONFIG_DRIVERS_VIRTIO
   virtio_register_drivers();
 #endif
@@ -222,5 +272,9 @@ void drivers_initialize(void)
   optee_register();
 #endif
 
+#ifdef CONFIG_THERMAL
+  thermal_init();
+#endif
+
   drivers_trace_end();
 }
