@@ -37,8 +37,6 @@
 #include <nuttx/i2c/i2c_master.h>
 #include <nuttx/mutex.h>
 
-#ifdef CONFIG_I2C_DRIVER
-
 /****************************************************************************
  * Pre-processor Definitions
  ****************************************************************************/
@@ -118,16 +116,16 @@ static const struct file_operations g_i2cdrvr_fops =
 #ifndef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
 static int i2cdrvr_open(FAR struct file *filep)
 {
-  FAR struct inode *inode;
   FAR struct i2c_driver_s *priv;
   int ret;
 
+  /* Sanity check */
+
+  DEBUGASSERT(filep->f_inode->i_private != NULL);
+
   /* Get our private data structure */
 
-  inode = filep->f_inode;
-
-  priv = inode->i_private;
-  DEBUGASSERT(priv);
+  priv = filep->f_inode->i_private;
 
   /* Get exclusive access to the I2C driver state structure */
 
@@ -137,13 +135,25 @@ static int i2cdrvr_open(FAR struct file *filep)
       return ret;
     }
 
+  /* I2c master initialize */
+
+  if (priv->i2c->ops->setup != NULL && priv->crefs == 0)
+    {
+      ret = I2C_SETUP(priv->i2c);
+      if (ret < 0)
+        {
+          goto out;
+        }
+    }
+
   /* Increment the count of open references on the driver */
 
   priv->crefs++;
   DEBUGASSERT(priv->crefs > 0);
 
+out:
   nxmutex_unlock(&priv->lock);
-  return OK;
+  return ret;
 }
 #endif
 
@@ -154,16 +164,16 @@ static int i2cdrvr_open(FAR struct file *filep)
 #ifndef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
 static int i2cdrvr_close(FAR struct file *filep)
 {
-  FAR struct inode *inode;
   FAR struct i2c_driver_s *priv;
   int ret;
 
+  /* Sanity check */
+
+  DEBUGASSERT(filep->f_inode->i_private != NULL);
+
   /* Get our private data structure */
 
-  inode = filep->f_inode;
-
-  priv = inode->i_private;
-  DEBUGASSERT(priv);
+  priv = filep->f_inode->i_private;
 
   /* Get exclusive access to the I2C driver state structure */
 
@@ -173,6 +183,17 @@ static int i2cdrvr_close(FAR struct file *filep)
       return ret;
     }
 
+  /* I2c master uninitialize */
+
+  if (priv->i2c->ops->shutdown != NULL && priv->crefs == 1)
+    {
+      ret = I2C_SHUTDOWN(priv->i2c);
+      if (ret < 0)
+        {
+          goto out;
+        }
+    }
+
   /* Decrement the count of open references on the driver */
 
   DEBUGASSERT(priv->crefs > 0);
@@ -186,11 +207,13 @@ static int i2cdrvr_close(FAR struct file *filep)
     {
       nxmutex_destroy(&priv->lock);
       kmm_free(priv);
+      filep->f_inode->i_private = NULL;
       return OK;
     }
 
+out:
   nxmutex_unlock(&priv->lock);
-  return OK;
+  return ret;
 }
 #endif
 
@@ -220,19 +243,18 @@ static ssize_t i2cdrvr_write(FAR struct file *filep, FAR const char *buffer,
 
 static int i2cdrvr_ioctl(FAR struct file *filep, int cmd, unsigned long arg)
 {
-  FAR struct inode *inode;
   FAR struct i2c_driver_s *priv;
   FAR struct i2c_transfer_s *transfer;
   int ret;
 
+  /* Sanity check */
+
+  DEBUGASSERT(filep->f_inode->i_private != NULL);
   i2cinfo("cmd=%x arg=%08lx\n", cmd, arg);
 
   /* Get our private data structure */
 
-  inode = filep->f_inode;
-
-  priv = inode->i_private;
-  DEBUGASSERT(priv);
+  priv = filep->f_inode->i_private;
 
 #ifndef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
   /* Get exclusive access to the I2C driver state structure */
@@ -303,9 +325,12 @@ static int i2cdrvr_unlink(FAR struct inode *inode)
   FAR struct i2c_driver_s *priv;
   int ret;
 
-  /* Get our private data structure */
+  /* Sanity check */
 
   DEBUGASSERT(inode->i_private != NULL);
+
+  /* Get our private data structure */
+
   priv = inode->i_private;
 
   /* Get exclusive access to the I2C driver state structure */
@@ -322,6 +347,7 @@ static int i2cdrvr_unlink(FAR struct inode *inode)
     {
       nxmutex_destroy(&priv->lock);
       kmm_free(priv);
+      inode->i_private = NULL;
       return OK;
     }
 
@@ -385,7 +411,7 @@ int i2c_register(FAR struct i2c_master_s *i2c, int bus)
 
       /* Create the character device name */
 
-      snprintf(devname, DEVNAME_FMTLEN, DEVNAME_FMT, bus);
+      snprintf(devname, sizeof(devname), DEVNAME_FMT, bus);
       ret = register_driver(devname, &g_i2cdrvr_fops, 0666, priv);
       if (ret < 0)
         {
@@ -408,4 +434,3 @@ int i2c_register(FAR struct i2c_master_s *i2c, int bus)
   return -ENOMEM;
 }
 
-#endif /* CONFIG_I2C_DRIVER */
