@@ -184,19 +184,19 @@ struct mbr3108_dev_s
 {
   /* I2C bus and address for device. */
 
-  struct i2c_master_s *i2c;
+  FAR struct i2c_master_s *i2c;
   uint8_t addr;
 
   /* Configuration for device. */
 
-  struct mbr3108_board_s *board;
-  const struct mbr3108_sensor_conf_s *sensor_conf;
+  FAR struct mbr3108_board_s *board;
+  FAR const struct mbr3108_sensor_conf_s *sensor_conf;
   mutex_t devlock;
   uint8_t cref;
   struct mbr3108_debug_conf_s debug_conf;
   bool int_pending;
 
-  struct pollfd *fds[CONFIG_INPUT_CYPRESS_MBR3108_NPOLLWAITERS];
+  FAR struct pollfd *fds[CONFIG_INPUT_CYPRESS_MBR3108_NPOLLWAITERS];
 };
 
 /****************************************************************************
@@ -234,7 +234,7 @@ static const struct file_operations g_mbr3108_fileops =
  ****************************************************************************/
 
 static int mbr3108_i2c_write(FAR struct mbr3108_dev_s *dev, uint8_t reg,
-                             const uint8_t *buf, size_t buflen)
+                             FAR const uint8_t *buf, size_t buflen)
 {
   struct i2c_msg_s msgv[2] =
   {
@@ -282,7 +282,7 @@ static int mbr3108_i2c_write(FAR struct mbr3108_dev_s *dev, uint8_t reg,
 }
 
 static int mbr3108_i2c_read(FAR struct mbr3108_dev_s *dev, uint8_t reg,
-                            uint8_t *buf, size_t buflen)
+                            FAR uint8_t *buf, size_t buflen)
 {
   struct i2c_msg_s msgv[2] =
   {
@@ -1075,13 +1075,14 @@ static int mbr3108_isr_handler(int irq, FAR void *context, FAR void *arg)
  * Public Functions
  ****************************************************************************/
 
-int cypress_mbr3108_register(FAR const char *devpath,
-                             FAR struct i2c_master_s *i2c_dev,
-                             uint8_t i2c_devaddr,
-                             struct mbr3108_board_s *board_config,
-                             const struct mbr3108_sensor_conf_s *sensor_conf)
+int
+cypress_mbr3108_register(FAR const char *devpath,
+                         FAR struct i2c_master_s *i2c_dev,
+                         uint8_t i2c_devaddr,
+                         FAR struct mbr3108_board_s *board_config,
+                         FAR const struct mbr3108_sensor_conf_s *sensor_conf)
 {
-  struct mbr3108_dev_s *priv;
+  FAR struct mbr3108_dev_s *priv;
   int ret = 0;
 
   /* Allocate device private structure. */
