@@ -103,7 +103,7 @@ static ssize_t  stmpe811_read(FAR struct file *filep, FAR char *buffer,
                               size_t len);
 static int      stmpe811_ioctl(FAR struct file *filep, int cmd,
                                unsigned long arg);
-static int      stmpe811_poll(FAR struct file *filep, struct pollfd *fds,
+static int      stmpe811_poll(FAR struct file *filep, FAR struct pollfd *fds,
                               bool setup);
 
 /* Initialization logic */
@@ -693,7 +693,7 @@ static int stmpe811_poll(FAR struct file *filep, FAR struct pollfd *fds,
     {
       /* This is a request to tear down the poll. */
 
-      struct pollfd **slot = (struct pollfd **)fds->priv;
+      FAR struct pollfd **slot = (FAR struct pollfd **)fds->priv;
       DEBUGASSERT(slot != NULL);
 
       /* Remove all memory of the poll setup */
