@@ -166,7 +166,7 @@ struct tsc2007_dev_s
    * retained in the f_priv field of the 'struct file'.
    */
 
-  struct pollfd *fds[CONFIG_TSC2007_NPOLLWAITERS];
+  FAR struct pollfd *fds[CONFIG_TSC2007_NPOLLWAITERS];
 };
 
 /****************************************************************************
@@ -192,7 +192,7 @@ static int tsc2007_close(FAR struct file *filep);
 static ssize_t tsc2007_read(FAR struct file *filep, FAR char *buffer,
                             size_t len);
 static int tsc2007_ioctl(FAR struct file *filep, int cmd, unsigned long arg);
-static int tsc2007_poll(FAR struct file *filep, struct pollfd *fds,
+static int tsc2007_poll(FAR struct file *filep, FAR struct pollfd *fds,
                         bool setup);
 
 /****************************************************************************
@@ -1136,7 +1136,7 @@ static int tsc2007_poll(FAR struct file *filep, FAR struct pollfd *fds,
     {
       /* This is a request to tear down the poll. */
 
-      struct pollfd **slot = (struct pollfd **)fds->priv;
+      FAR struct pollfd **slot = (FAR struct pollfd **)fds->priv;
       DEBUGASSERT(slot != NULL);
 
       /* Remove all memory of the poll setup */
