@@ -372,11 +372,11 @@ static inline void apa102_refresh(FAR struct apa102_dev_s *priv)
 
   for (i = 0; i < (APA102_XRES * APA102_YRES); i++)
     {
-      uint32_t *led = (uint32_t *) &priv->fb[i];
+      uint32_t *led = (FAR uint32_t *)&priv->fb[i];
 
       /* Then transfer 4 bytes per LED */
 
-      apa102_write32(priv, (uint32_t) (*led | APA102_HEADER_FRAME));
+      apa102_write32(priv, (uint32_t)(*led | APA102_HEADER_FRAME));
     }
 
   /* Send an end of frame */
@@ -438,7 +438,7 @@ static int apa102_putrun(FAR struct lcd_dev_s *dev, fb_coord_t row,
 
   for (i = 0; i < pixlen; i++)
     {
-      uint16_t *ptr = (uint16_t *)buffer;
+      FAR uint16_t *ptr = (FAR uint16_t *)buffer;
 
       if (row % 2 == 0)
         {
@@ -568,7 +568,7 @@ static int apa102_getrun(FAR struct lcd_dev_s *dev, fb_coord_t row,
 
   for (i = 0; i < pixlen; i++)
     {
-      uint16_t *ptr = (uint16_t *) buffer;
+      FAR uint16_t *ptr = (FAR uint16_t *)buffer;
 
       *ptr++ = apa102_rgb565(priv->fb[(row * APA102_XRES) + col + i]);
     }
