@@ -263,7 +263,7 @@ static struct jd9851_dev_s g_lcddev;
  *
  ****************************************************************************/
 
-static void jd9851_select(FAR FAR struct spi_dev_s *spi, int bits)
+static void jd9851_select(FAR struct spi_dev_s *spi, int bits)
 {
   /* Select JD9851 chip (locking the SPI bus in case there are multiple
    * devices competing for the SPI bus
@@ -297,7 +297,7 @@ static void jd9851_select(FAR FAR struct spi_dev_s *spi, int bits)
  *
  ****************************************************************************/
 
-static void jd9851_deselect(FAR FAR struct spi_dev_s *spi)
+static void jd9851_deselect(FAR struct spi_dev_s *spi)
 {
   /* De-select JD9851 chip and relinquish the SPI bus. */
 
@@ -886,7 +886,7 @@ static int jd9851_setcontrast(FAR struct lcd_dev_s *dev,
  *
  ****************************************************************************/
 
-FAR struct lcd_dev_s *jd9851_lcdinitialize(FAR FAR struct spi_dev_s *spi)
+FAR struct lcd_dev_s *jd9851_lcdinitialize(FAR struct spi_dev_s *spi)
 {
   FAR struct jd9851_dev_s *priv = &g_lcddev;
 
