@@ -105,7 +105,7 @@ static int lcdfb_setcursor(FAR struct fb_vtable_s *vtable,
              FAR struct fb_setcursor_s *settings);
 #endif
 
-static int lcdfb_setpower(FAR struct fb_vtable_s *vtable, FAR int power);
+static int lcdfb_setpower(FAR struct fb_vtable_s *vtable, int power);
 
 /****************************************************************************
  * Private Data
@@ -467,7 +467,7 @@ static int lcdfb_setcursor(FAR struct fb_vtable_s *vtable,
  * Name: lcdfb_setpower
  ****************************************************************************/
 
-static int lcdfb_setpower(FAR struct fb_vtable_s *vtable, FAR int power)
+static int lcdfb_setpower(FAR struct fb_vtable_s *vtable, int power)
 {
   int ret = -EINVAL;
   FAR struct lcdfb_dev_s *priv;
