@@ -24,6 +24,7 @@
 
 #include <nuttx/config.h>
 
+#include <sys/param.h>
 #include <sys/types.h>
 #include <stdint.h>
 #include <stdbool.h>
@@ -45,8 +46,6 @@
  * Pre-processor Definitions
  ****************************************************************************/
 
-#define MAX(a,b)    ((a)>(b)?(a):(b))
-
 /* Verify that all configuration requirements have been met */
 
 #ifndef CONFIG_LCD_ST7735_SPIMODE
