@@ -51,7 +51,7 @@
 #define RDFLAG_USER            (RDFLAG_WRENABLED | RDFLAG_FUNLINK)
 
 #define RDFLAG_IS_WRENABLED(f) (((f) & RDFLAG_WRENABLED) != 0)
-#define RDFLAG_IS_FUNLINK(f)   (((f) & RDFLAG_WRENABLED) != 0)
+#define RDFLAG_IS_FUNLINK(f)   (((f) & RDFLAG_FUNLINK) != 0)
 
 /* Flag set when the RAM disk block driver is unlink */
 
@@ -85,14 +85,14 @@ static int     rd_close(FAR struct inode *inode);
 #endif
 
 static ssize_t rd_read(FAR struct inode *inode, FAR unsigned char *buffer,
-                 blkcnt_t start_sector, unsigned int nsectors);
+                       blkcnt_t start_sector, unsigned int nsectors);
 static ssize_t rd_write(FAR struct inode *inode,
-                 FAR const unsigned char *buffer, blkcnt_t start_sector,
-                 unsigned int nsectors);
+                        FAR const unsigned char *buffer,
+                        blkcnt_t start_sector, unsigned int nsectors);
 static int     rd_geometry(FAR struct inode *inode,
-                 FAR struct geometry *geometry);
+                           FAR struct geometry *geometry);
 static int     rd_ioctl(FAR struct inode *inode, int cmd,
-                 unsigned long arg);
+                        unsigned long arg);
 
 #ifndef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
 static int     rd_unlink(FAR struct inode *inode);
@@ -108,15 +108,15 @@ static const struct block_operations g_bops =
   rd_open,     /* open     */
   rd_close,    /* close    */
 #else
-  0,           /* open     */
-  0,           /* close    */
+  NULL,        /* open     */
+  NULL,        /* close    */
 #endif
   rd_read,     /* read     */
   rd_write,    /* write    */
   rd_geometry, /* geometry */
-  rd_ioctl,    /* ioctl    */
+  rd_ioctl     /* ioctl    */
 #ifndef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
-  rd_unlink    /* unlink   */
+  , rd_unlink  /* unlink   */
 #endif
 };
 
@@ -143,7 +143,10 @@ static void rd_destroy(FAR struct rd_struct_s *dev)
     {
       /* Yes.. do it */
 
-      kmm_free(dev->rd_buffer);
+      if (dev->rd_flags & RDFLAG_USER)
+        {
+          kmm_free(dev->rd_buffer);
+        }
     }
 
   /* And free the block driver itself */
@@ -164,8 +167,8 @@ static int rd_open(FAR struct inode *inode)
 {
   FAR struct rd_struct_s *dev;
 
-  DEBUGASSERT(inode && inode->i_private);
-  dev = (FAR struct rd_struct_s *)inode->i_private;
+  DEBUGASSERT(inode->i_private);
+  dev = inode->i_private;
 
   /* Increment the open reference count */
 
@@ -189,8 +192,8 @@ static int rd_close(FAR struct inode *inode)
 {
   FAR struct rd_struct_s *dev;
 
-  DEBUGASSERT(inode && inode->i_private);
-  dev = (FAR struct rd_struct_s *)inode->i_private;
+  DEBUGASSERT(inode->i_private);
+  dev = inode->i_private;
 
   /* Increment the open reference count */
 
@@ -230,8 +233,8 @@ static ssize_t rd_read(FAR struct inode *inode, unsigned char *buffer,
 {
   FAR struct rd_struct_s *dev;
 
-  DEBUGASSERT(inode && inode->i_private);
-  dev = (FAR struct rd_struct_s *)inode->i_private;
+  DEBUGASSERT(inode->i_private);
+  dev = inode->i_private;
 
   finfo("sector: %" PRIuOFF " nsectors: %u sectorsize: %d\n",
         start_sector, nsectors, dev->rd_sectsize);
@@ -244,8 +247,8 @@ static ssize_t rd_read(FAR struct inode *inode, unsigned char *buffer,
              &dev->rd_buffer[start_sector * dev->rd_sectsize]);
 
        memcpy(buffer,
-             &dev->rd_buffer[start_sector * dev->rd_sectsize],
-             nsectors * dev->rd_sectsize);
+              &dev->rd_buffer[start_sector * dev->rd_sectsize],
+              nsectors * dev->rd_sectsize);
       return nsectors;
     }
 
@@ -259,13 +262,14 @@ static ssize_t rd_read(FAR struct inode *inode, unsigned char *buffer,
  *
  ****************************************************************************/
 
-static ssize_t rd_write(FAR struct inode *inode, const unsigned char *buffer,
+static ssize_t rd_write(FAR struct inode *inode,
+                        FAR const unsigned char *buffer,
                         blkcnt_t start_sector, unsigned int nsectors)
 {
-  struct rd_struct_s *dev;
+  FAR struct rd_struct_s *dev;
 
-  DEBUGASSERT(inode && inode->i_private);
-  dev = (struct rd_struct_s *)inode->i_private;
+  DEBUGASSERT(inode->i_private);
+  dev = inode->i_private;
 
   finfo("sector: %" PRIuOFF " nsectors: %u sectorsize: %d\n",
         start_sector, nsectors, dev->rd_sectsize);
@@ -297,16 +301,16 @@ static ssize_t rd_write(FAR struct inode *inode, const unsigned char *buffer,
  *
  ****************************************************************************/
 
-static int rd_geometry(FAR struct inode *inode, struct geometry *geometry)
+static int rd_geometry(FAR struct inode *inode,
+                       FAR struct geometry *geometry)
 {
-  struct rd_struct_s *dev;
+  FAR struct rd_struct_s *dev;
 
   finfo("Entry\n");
 
-  DEBUGASSERT(inode);
   if (geometry)
     {
-      dev = (struct rd_struct_s *)inode->i_private;
+      dev = inode->i_private;
 
       memset(geometry, 0, sizeof(*geometry));
 
@@ -338,16 +342,16 @@ static int rd_geometry(FAR struct inode *inode, struct geometry *geometry)
 static int rd_ioctl(FAR struct inode *inode, int cmd, unsigned long arg)
 {
   FAR struct rd_struct_s *dev;
-  FAR void **ppv = (void**)((uintptr_t)arg);
+  FAR void **ppv = (FAR void **)((uintptr_t)arg);
 
   finfo("Entry\n");
 
   /* Only one ioctl command is supported */
 
-  DEBUGASSERT(inode && inode->i_private);
+  DEBUGASSERT(inode->i_private);
   if (cmd == BIOC_XIPBASE && ppv)
     {
-      dev  = (FAR struct rd_struct_s *)inode->i_private;
+      dev  = inode->i_private;
       *ppv = (FAR void *)dev->rd_buffer;
 
       finfo("ppv: %p\n", *ppv);
@@ -370,8 +374,8 @@ static int rd_unlink(FAR struct inode *inode)
 {
   FAR struct rd_struct_s *dev;
 
-  DEBUGASSERT(inode && inode->i_private);
-  dev = (FAR struct rd_struct_s *)inode->i_private;
+  DEBUGASSERT(inode->i_private);
+  dev = inode->i_private;
 
   /* Mark the pipe unlinked */
 
@@ -415,7 +419,7 @@ static int rd_unlink(FAR struct inode *inode)
 int ramdisk_register(int minor, FAR uint8_t *buffer, uint32_t nsectors,
                      uint16_t sectsize, uint8_t rdflags)
 {
-  struct rd_struct_s *dev;
+  FAR struct rd_struct_s *dev;
   char devname[16];
   int ret = -ENOMEM;
 
@@ -433,7 +437,7 @@ int ramdisk_register(int minor, FAR uint8_t *buffer, uint32_t nsectors,
 
   /* Allocate a ramdisk device structure */
 
-  dev = (struct rd_struct_s *)kmm_zalloc(sizeof(struct rd_struct_s));
+  dev = kmm_zalloc(sizeof(struct rd_struct_s));
   if (dev)
     {
       /* Initialize the ramdisk device structure */
@@ -445,7 +449,7 @@ int ramdisk_register(int minor, FAR uint8_t *buffer, uint32_t nsectors,
 
       /* Create a ramdisk device name */
 
-      snprintf(devname, 16, "/dev/ram%d", minor);
+      snprintf(devname, sizeof(devname), "/dev/ram%d", minor);
 
       /* Inode private data is a reference to the ramdisk device structure */
 
