@@ -725,7 +725,7 @@ static int mtd_loop_ioctl(FAR struct file *filep, int cmd,
  *
  ****************************************************************************/
 
-FAR struct mtd_dev_s *filemtd_initialize(FAR const char *path, size_t offset,
+FAR struct mtd_dev_s *filemtd_initialize(FAR const char *path, off_t offset,
                                          int16_t sectsize, int32_t erasesize)
 {
   FAR struct file_dev_s *priv;
