@@ -225,7 +225,7 @@ static int mx25rxx_command(FAR struct qspi_dev_s *qspi, uint8_t cmd);
 static int mx25rxx_command_address(FAR struct qspi_dev_s *qspi, uint8_t cmd,
                                   off_t addr, uint8_t addrlen);
 
-static int mx25rxx_readid(struct mx25rxx_dev_s *dev);
+static int mx25rxx_readid(FAR struct mx25rxx_dev_s *dev);
 static int mx25rxx_read_byte(FAR struct mx25rxx_dev_s *dev,
                              FAR uint8_t *buffer, off_t address,
                              size_t buflen);
@@ -235,23 +235,26 @@ static void mx25rxx_write_status_config(FAR struct mx25rxx_dev_s *dev,
                                         uint8_t status, uint16_t config);
 static void mx25rxx_write_enable(FAR struct mx25rxx_dev_s *dev, bool enable);
 
-static int mx25rxx_write_page(struct mx25rxx_dev_s *priv,
+static int mx25rxx_write_page(FAR struct mx25rxx_dev_s *priv,
                               FAR const uint8_t *buffer,
                               off_t address,
                               size_t buflen);
-static int mx25rxx_erase_sector(struct mx25rxx_dev_s *priv, off_t sector);
+static int mx25rxx_erase_sector(FAR struct mx25rxx_dev_s *priv,
+                                off_t sector);
 #if 0 /* FIXME:  Not used */
-static int mx25rxx_erase_block(struct mx25rxx_dev_s *priv, off_t block);
+static int mx25rxx_erase_block(FAR struct mx25rxx_dev_s *priv, off_t block);
 #endif
-static int mx25rxx_erase_chip(struct mx25rxx_dev_s *priv);
+static int mx25rxx_erase_chip(FAR struct mx25rxx_dev_s *priv);
 
 #ifdef CONFIG_MX25RXX_SECTOR512
-static int  mx25rxx_flush_cache(struct mx25rxx_dev_s *priv);
-static FAR uint8_t *mx25rxx_read_cache(struct mx25rxx_dev_s *priv,
+static int  mx25rxx_flush_cache(FAR struct mx25rxx_dev_s *priv);
+static FAR uint8_t *mx25rxx_read_cache(FAR struct mx25rxx_dev_s *priv,
                                        off_t sector);
-static void mx25rxx_erase_cache(struct mx25rxx_dev_s *priv, off_t sector);
+static void mx25rxx_erase_cache(FAR struct mx25rxx_dev_s *priv,
+                                off_t sector);
 static int  mx25rxx_write_cache(FAR struct mx25rxx_dev_s *priv,
-              FAR const uint8_t *buffer,  off_t sector, size_t nsectors);
+                                FAR const uint8_t *buffer,  off_t sector,
+                                size_t nsectors);
 #endif
 
 /****************************************************************************
@@ -379,7 +382,8 @@ int mx25rxx_read_byte(FAR struct mx25rxx_dev_s *dev, FAR uint8_t *buffer,
   return QSPI_MEMORY(dev->qspi, &meminfo);
 }
 
-int mx25rxx_write_page(struct mx25rxx_dev_s *priv, FAR const uint8_t *buffer,
+int mx25rxx_write_page(FAR struct mx25rxx_dev_s *priv,
+                       FAR const uint8_t *buffer,
                        off_t address, size_t buflen)
 {
   struct qspi_meminfo_s meminfo;
@@ -409,7 +413,7 @@ int mx25rxx_write_page(struct mx25rxx_dev_s *priv, FAR const uint8_t *buffer,
       /* Set up varying parts of the transfer description */
 
       meminfo.addr   = address;
-      meminfo.buffer = (void *)buffer;
+      meminfo.buffer = (FAR void *)buffer;
 
       /* Write one page */
 
@@ -442,7 +446,7 @@ int mx25rxx_write_page(struct mx25rxx_dev_s *priv, FAR const uint8_t *buffer,
   return OK;
 }
 
-int mx25rxx_erase_sector(struct mx25rxx_dev_s *priv, off_t sector)
+int mx25rxx_erase_sector(FAR struct mx25rxx_dev_s *priv, off_t sector)
 {
   off_t address;
   uint8_t status;
@@ -472,7 +476,7 @@ int mx25rxx_erase_sector(struct mx25rxx_dev_s *priv, off_t sector)
 }
 
 #if 0 /* FIXME:  Not used */
-int mx25rxx_erase_block(struct mx25rxx_dev_s *priv, off_t block)
+int mx25rxx_erase_block(FAR struct mx25rxx_dev_s *priv, off_t block)
 {
   uint8_t status;
 
@@ -497,7 +501,7 @@ int mx25rxx_erase_block(struct mx25rxx_dev_s *priv, off_t block)
 }
 #endif
 
-int mx25rxx_erase_chip(struct mx25rxx_dev_s *priv)
+int mx25rxx_erase_chip(FAR struct mx25rxx_dev_s *priv)
 {
   uint8_t status;
 
@@ -828,7 +832,7 @@ int mx25rxx_ioctl(FAR struct mtd_dev_s *dev, int cmd, unsigned long arg)
   return ret;
 }
 
-int mx25rxx_readid(struct mx25rxx_dev_s *dev)
+int mx25rxx_readid(FAR struct mx25rxx_dev_s *dev)
 {
   /* Lock the QuadSPI bus and configure the bus. */
 
@@ -884,7 +888,7 @@ int mx25rxx_readid(struct mx25rxx_dev_s *dev)
  ****************************************************************************/
 
 #ifdef CONFIG_MX25RXX_SECTOR512
-static int mx25rxx_flush_cache(struct mx25rxx_dev_s *priv)
+static int mx25rxx_flush_cache(FAR struct mx25rxx_dev_s *priv)
 {
   int ret = OK;
 
@@ -927,7 +931,7 @@ static int mx25rxx_flush_cache(struct mx25rxx_dev_s *priv)
  ****************************************************************************/
 
 #ifdef CONFIG_MX25RXX_SECTOR512
-static FAR uint8_t *mx25rxx_read_cache(struct mx25rxx_dev_s *priv,
+static FAR uint8_t *mx25rxx_read_cache(FAR struct mx25rxx_dev_s *priv,
                                        off_t sector)
 {
   off_t esectno;
@@ -996,7 +1000,7 @@ static FAR uint8_t *mx25rxx_read_cache(struct mx25rxx_dev_s *priv,
  ****************************************************************************/
 
 #ifdef CONFIG_MX25RXX_SECTOR512
-static void mx25rxx_erase_cache(struct mx25rxx_dev_s *priv, off_t sector)
+static void mx25rxx_erase_cache(FAR struct mx25rxx_dev_s *priv, off_t sector)
 {
   FAR uint8_t *dest;
 
@@ -1038,8 +1042,8 @@ static void mx25rxx_erase_cache(struct mx25rxx_dev_s *priv, off_t sector)
 
 #ifdef CONFIG_MX25RXX_SECTOR512
 static int mx25rxx_write_cache(FAR struct mx25rxx_dev_s *priv,
-                              FAR const uint8_t *buffer, off_t sector,
-                              size_t nsectors)
+                               FAR const uint8_t *buffer, off_t sector,
+                               size_t nsectors)
 {
   FAR uint8_t *dest;
   int ret;
