@@ -92,14 +92,14 @@
 #define note_irqhandler(drv, irq, handler, enter)                            \
   ((drv)->ops->irqhandler &&                                                 \
   ((drv)->ops->irqhandler(drv, irq, handler, enter), true))
-#define note_string(drv, ip, buf)                                            \
-  ((drv)->ops->string && ((drv)->ops->string(drv, ip, buf), true))
+#define note_heap(drv, event, data, mem, size, used)                         \
+  ((drv)->ops->heap && ((drv)->ops->heap(drv, event, data, mem, size, used), true))
+#define note_wdog(drv, event, handler, arg)                                  \
+  ((drv)->ops->wdog && ((drv)->ops->wdog(drv, event, handler, arg), true))
 #define note_event(drv, ip, event, buf, len)                                 \
   ((drv)->ops->event && ((drv)->ops->event(drv, ip, event, buf, len), true))
 #define note_vprintf(drv, ip, fmt, va)                                       \
   ((drv)->ops->vprintf && ((drv)->ops->vprintf(drv, ip, fmt, va), true))
-#define note_vbprintf(drv, ip, fmt, va)                                      \
-  ((drv)->ops->vbprintf && ((drv)->ops->vbprintf(drv, ip, fmt, va), true))
 
 /****************************************************************************
  * Private Types
@@ -585,10 +585,10 @@ static void note_record_taskname(pid_t pid, FAR const char *name)
 
   ti = (FAR struct note_taskname_info_s *)
         &g_note_taskname.buffer[g_note_taskname.head];
-  ti->size = tilen;
+  ti->size = NOTE_ALIGN(tilen);
   ti->pid = pid;
   strlcpy(ti->name, name, namelen + 1);
-  g_note_taskname.head += tilen;
+  g_note_taskname.head += ti->size;
 }
 #endif
 
@@ -1170,6 +1170,27 @@ void sched_note_spinlock(FAR struct tcb_s *tcb,
       note_add(*driver, &note, sizeof(struct note_spinlock_s));
     }
 }
+
+void sched_note_spinlock_lock(FAR volatile spinlock_t *spinlock)
+{
+  sched_note_spinlock(this_task(), spinlock, NOTE_SPINLOCK_LOCK);
+}
+
+void sched_note_spinlock_locked(FAR volatile spinlock_t *spinlock)
+{
+  sched_note_spinlock(this_task(), spinlock, NOTE_SPINLOCK_LOCKED);
+}
+
+void sched_note_spinlock_abort(FAR volatile spinlock_t *spinlock)
+{
+  sched_note_spinlock(this_task(), spinlock, NOTE_SPINLOCK_ABORT);
+}
+
+void sched_note_spinlock_unlock(FAR volatile spinlock_t *spinlock)
+{
+  sched_note_spinlock(this_task(), spinlock, NOTE_SPINLOCK_UNLOCK);
+}
+
 #endif
 
 #ifdef CONFIG_SCHED_INSTRUMENTATION_SYSCALL
@@ -1331,24 +1352,17 @@ void sched_note_irqhandler(int irq, FAR void *handler, bool enter)
 }
 #endif
 
-#ifdef CONFIG_SCHED_INSTRUMENTATION_DUMP
-void sched_note_string_ip(uint32_t tag, uintptr_t ip, FAR const char *buf)
+#ifdef CONFIG_SCHED_INSTRUMENTATION_WDOG
+void sched_note_wdog(uint8_t event, FAR void *handler, FAR const void *arg)
 {
-  FAR struct note_string_s *note;
-  uint8_t data[255];
-  unsigned int length;
   FAR struct note_driver_s **driver;
+  struct note_wdog_s note;
   bool formatted = false;
   FAR struct tcb_s *tcb = this_task();
 
-  if (!note_isenabled_dump(tag))
-    {
-      return;
-    }
-
   for (driver = g_note_drivers; *driver; driver++)
     {
-      if (note_string(*driver, ip, buf))
+      if (note_wdog(*driver, event, handler, arg))
         {
           continue;
         }
@@ -1358,34 +1372,71 @@ void sched_note_string_ip(uint32_t tag, uintptr_t ip, FAR const char *buf)
           continue;
         }
 
-      /* Format the note */
-
       if (!formatted)
         {
           formatted = true;
-          note = (FAR struct note_string_s *)data;
-          length = SIZEOF_NOTE_STRING(strlen(buf));
-          if (length > sizeof(data))
-            {
-              length = sizeof(data);
-            }
-
-          note_common(tcb, &note->nst_cmn, length, NOTE_DUMP_STRING);
-          memcpy(note->nst_data, buf, length - sizeof(struct note_string_s));
-          data[length - 1] = '\0';
-          note->nst_ip = ip;
+          note_common(tcb, &note.nwd_cmn, sizeof(note), event);
+          note.handler = (uintptr_t)handler;
+          note.arg = (uintptr_t)arg;
         }
 
       /* Add the note to circular buffer */
 
-      note_add(*driver, note, length);
+      note_add(*driver, &note, sizeof(note));
     }
 }
+#endif
 
+#ifdef CONFIG_SCHED_INSTRUMENTATION_HEAP
+void sched_note_heap(uint8_t event, FAR void *heap, FAR void *mem,
+                     size_t size, size_t used)
+{
+  FAR struct note_driver_s **driver;
+  struct note_heap_s note;
+  bool formatted = false;
+  FAR struct tcb_s *tcb = this_task();
+
+#ifdef CONFIG_SCHED_INSTRUMENTATION_FILTER
+  if (!note_isenabled())
+    {
+      return;
+    }
+#endif
+
+  for (driver = g_note_drivers; *driver; driver++)
+    {
+      if (note_heap(*driver, event, heap, mem, size, used))
+        {
+          continue;
+        }
+
+      if ((*driver)->ops->add == NULL)
+        {
+          continue;
+        }
+
+      if (!formatted)
+        {
+          formatted = true;
+          note_common(tcb, &note.nhp_cmn, sizeof(note), event);
+          note.heap = heap;
+          note.mem = mem;
+          note.size = size;
+          note.used = used;
+        }
+
+      /* Add the note to circular buffer */
+
+      note_add(*driver, &note, sizeof(note));
+    }
+}
+#endif
+
+#ifdef CONFIG_SCHED_INSTRUMENTATION_DUMP
 void sched_note_event_ip(uint32_t tag, uintptr_t ip, uint8_t event,
                          FAR const void *buf, size_t len)
 {
-  FAR struct note_binary_s *note;
+  FAR struct note_event_s *note;
   FAR struct note_driver_s **driver;
   bool formatted = false;
   char data[255];
@@ -1414,17 +1465,16 @@ void sched_note_event_ip(uint32_t tag, uintptr_t ip, uint8_t event,
       if (!formatted)
         {
           formatted = true;
-          note = (FAR struct note_binary_s *)data;
-          length = SIZEOF_NOTE_BINARY(len);
+          note = (FAR struct note_event_s *)data;
+          length = SIZEOF_NOTE_EVENT(len);
           if (length > sizeof(data))
             {
               length = sizeof(data);
             }
 
-          note_common(tcb, &note->nbi_cmn, length, event);
-          memcpy(note->nbi_data, buf,
-                 length - sizeof(struct note_binary_s) + 1);
-          note->nbi_ip = ip;
+          note_common(tcb, &note->nev_cmn, length, event);
+          note->nev_ip = ip;
+          memcpy(note->nev_data, buf, length - SIZEOF_NOTE_EVENT(0));
         }
 
       /* Add the note to circular buffer */
@@ -1433,14 +1483,14 @@ void sched_note_event_ip(uint32_t tag, uintptr_t ip, uint8_t event,
     }
 }
 
-void sched_note_vprintf_ip(uint32_t tag, uintptr_t ip,
-                           FAR const char *fmt, va_list va)
+void sched_note_vprintf_ip(uint32_t tag, uintptr_t ip, FAR const char *fmt,
+                           uint32_t type, va_list va)
 {
-  FAR struct note_string_s *note;
-  uint8_t data[255];
-  unsigned int length;
+  FAR struct note_printf_s *note;
   FAR struct note_driver_s **driver;
   bool formatted = false;
+  uint8_t data[255];
+  size_t length = 0;
   FAR struct tcb_s *tcb = this_task();
 
   if (!note_isenabled_dump(tag))
@@ -1464,237 +1514,244 @@ void sched_note_vprintf_ip(uint32_t tag, uintptr_t ip,
 
       if (!formatted)
         {
-          formatted = true;
-          note = (FAR struct note_string_s *)data;
-          length = vsnprintf(note->nst_data,
-                             sizeof(data) - sizeof(struct note_string_s),
-                             fmt,
-                             va);
-          length = SIZEOF_NOTE_STRING(length);
-          if (length > sizeof(data))
+          begin_packed_struct union
             {
-              length = sizeof(data);
+              int i;
+              long l;
+#ifdef CONFIG_HAVE_LONG_LONG
+              long long ll;
+#endif
+              intmax_t im;
+              size_t sz;
+              ptrdiff_t ptr;
+              FAR void *p;
+              FAR const char *s;
+#ifdef CONFIG_HAVE_DOUBLE
+              double d;
+#  ifdef CONFIG_HAVE_LONG_DOUBLE
+              long double ld;
+#  endif
+#endif
             }
 
-          note_common(tcb, &note->nst_cmn, length, NOTE_DUMP_STRING);
-          note->nst_ip = ip;
-        }
-
-      /* Add the note to circular buffer */
-
-      note_add(*driver, note, length);
-    }
-}
-
-void sched_note_vbprintf_ip(uint32_t tag, uintptr_t ip,
-                            FAR const char *fmt, va_list va)
-{
-  FAR struct note_binary_s *note;
-  FAR struct note_driver_s **driver;
-  bool formatted = false;
-  uint8_t data[255];
-  begin_packed_struct union
-    {
-      char c;
-      short s;
-      int i;
-      long l;
-#ifdef CONFIG_HAVE_LONG_LONG
-      long long ll;
-#endif
-      intmax_t im;
-      size_t sz;
-      ptrdiff_t ptr;
-#ifdef CONFIG_HAVE_FLOAT
-      float f;
-#endif
-#ifdef CONFIG_HAVE_DOUBLE
-      double d;
-#endif
-#ifdef CONFIG_HAVE_LONG_DOUBLE
-      long double ld;
-#endif
-    }
-
-  end_packed_struct *var;
-
-  char c;
-  int length;
-  bool infmt = false;
-  int next = 0;
-  FAR struct tcb_s *tcb = this_task();
-
-  if (!note_isenabled_dump(tag))
-    {
-      return;
-    }
-
-  for (driver = g_note_drivers; *driver; driver++)
-    {
-      if (note_vbprintf(*driver, ip, fmt, va))
-        {
-          continue;
-        }
-
-      if ((*driver)->ops->add == NULL)
-        {
-          continue;
-        }
-
-      /* Format the note */
-
-      if (!formatted)
-        {
+          end_packed_struct *var;
+          size_t next = 0;
           formatted = true;
-          note = (FAR struct note_binary_s *)data;
-          length = sizeof(data) - sizeof(struct note_binary_s) + 1;
+          note = (FAR struct note_printf_s *)data;
+          length = sizeof(data) - SIZEOF_NOTE_PRINTF(0);
 
-          while ((c = *fmt++) != '\0')
+          if (type)
             {
-              if (c != '%' && !infmt)
+              size_t count = NOTE_PRINTF_GET_COUNT(type);
+              size_t i;
+
+              for (i = 0; i < count; i++)
                 {
-                  continue;
+                  var = (FAR void *)&note->npt_data[next];
+                  switch (NOTE_PRINTF_GET_TYPE(type, i))
+                    {
+                      case NOTE_PRINTF_UINT32:
+                        {
+                          var->i = va_arg(va, int);
+                          if (next + sizeof(var->i) > length)
+                            {
+                              break;
+                            }
+
+                          next += sizeof(var->i);
+                        }
+                      break;
+                      case NOTE_PRINTF_UINT64:
+                        {
+                          if (next + sizeof(var->ll) > length)
+                            {
+                              break;
+                            }
+
+                          var->ll = va_arg(va, long long);
+                          next += sizeof(var->ll);
+                        }
+                      break;
+                      case NOTE_PRINTF_STRING:
+                        {
+                          size_t len;
+                          var->s = va_arg(va, FAR const char *);
+                          len = strlen(var->s) + 1;
+                          if (next + len > length)
+                            {
+                              len = length - next;
+                            }
+
+                          strlcpy(note->npt_data + next, var->s, len);
+                          next += len;
+                        }
+                      break;
+                      case NOTE_PRINTF_DOUBLE:
+                        {
+                          var->d = va_arg(va, double);
+                          if (next + sizeof(var->d) > length)
+                            {
+                              break;
+                            }
+
+                          next += sizeof(var->d);
+                        }
+                      break;
+                    }
                 }
+            }
+          else
+            {
+              FAR const char *p = fmt;
+              bool infmt = false;
+              char c;
 
-              infmt = true;
-              var = (FAR void *)&note->nbi_data[next];
-
-              if (c == 'd' || c == 'i' || c == 'u' ||
-                  c == 'o' || c == 'x' || c == 'X')
+              while ((c = *p++) != '\0')
                 {
-                  if (*(fmt - 2) == 'h' && *(fmt - 3) == 'h')
+                  if (c != '%' && !infmt)
                     {
-                      if (next + sizeof(var->c) > length)
-                        {
-                          break;
-                        }
-
-                      var->c = va_arg(va, int);
-                      next += sizeof(var->c);
+                      continue;
                     }
-                  else if (*(fmt - 2) == 'h')
+
+                  infmt = true;
+                  var = (FAR void *)&note->npt_data[next];
+
+                  if (c == 'c' || c == 'd' || c == 'i' || c == 'u' ||
+                      c == 'o' || c == 'x' || c == 'X')
                     {
-                      if (next + sizeof(var->s) > length)
+                      if (*(p - 2) == 'j')
                         {
-                          break;
-                        }
+                          if (next + sizeof(var->im) > length)
+                            {
+                              break;
+                            }
 
-                      var->s = va_arg(va, int);
-                      next += sizeof(var->s);
-                    }
-                  else if (*(fmt - 2) == 'j')
-                    {
-                      if (next + sizeof(var->im) > length)
-                        {
-                          break;
+                          var->im = va_arg(va, intmax_t);
+                          next += sizeof(var->im);
                         }
-
-                      var->im = va_arg(va, intmax_t);
-                      next += sizeof(var->im);
-                    }
 #ifdef CONFIG_HAVE_LONG_LONG
-                  else if (*(fmt - 2) == 'l' && *(fmt - 3) == 'l')
-                    {
-                      if (next + sizeof(var->ll) > length)
+                      else if (*(p - 2) == 'l' && *(p - 3) == 'l')
                         {
-                          break;
-                        }
+                          if (next + sizeof(var->ll) > length)
+                            {
+                              break;
+                            }
 
-                      var->ll = va_arg(va, long long);
-                      next += sizeof(var->ll);
-                    }
+                          var->ll = va_arg(va, long long);
+                          next += sizeof(var->ll);
+                        }
 #endif
-                  else if (*(fmt - 2) == 'l')
-                    {
-                      if (next + sizeof(var->l) > length)
+                      else if (*(p - 2) == 'l')
                         {
-                          break;
+                          if (next + sizeof(var->l) > length)
+                            {
+                              break;
+                            }
+
+                          var->l = va_arg(va, long);
+                          next += sizeof(var->l);
+                        }
+                      else if (*(p - 2) == 'z')
+                        {
+                          if (next + sizeof(var->sz) > length)
+                            {
+                              break;
+                            }
+
+                          var->sz = va_arg(va, size_t);
+                          next += sizeof(var->sz);
+                        }
+                      else if (*(p - 2) == 't')
+                        {
+                          if (next + sizeof(var->ptr) > length)
+                            {
+                              break;
+                            }
+
+                          var->ptr = va_arg(va, ptrdiff_t);
+                          next += sizeof(var->ptr);
+                        }
+                      else
+                        {
+                          if (next + sizeof(var->i) > length)
+                            {
+                              break;
+                            }
+
+                          var->i = va_arg(va, int);
+                          next += sizeof(var->i);
                         }
 
-                      var->l = va_arg(va, long);
-                      next += sizeof(var->l);
+                      infmt = false;
                     }
-                  else if (*(fmt - 2) == 'z')
+                  else if (c == 'e' || c == 'f' || c == 'g' || c == 'a' ||
+                           c == 'A' || c == 'E' || c == 'F' || c == 'G')
                     {
-                      if (next + sizeof(var->sz) > length)
+#ifdef CONFIG_HAVE_DOUBLE
+#  ifdef CONFIG_HAVE_LONG_DOUBLE
+                      if (*(p - 2) == 'L')
                         {
-                          break;
-                        }
+                          if (next + sizeof(var->ld) > length)
+                            {
+                              break;
+                            }
 
-                      var->sz = va_arg(va, size_t);
-                      next += sizeof(var->sz);
+                          var->ld = va_arg(va, long double);
+                          next += sizeof(var->ld);
+                        }
+                      else
+#  endif
+                        {
+                          if (next + sizeof(var->d) > length)
+                            {
+                              break;
+                            }
+
+                          var->d = va_arg(va, double);
+                          next += sizeof(var->d);
+                        }
+#endif
+
+                      infmt = false;
                     }
-                  else if (*(fmt - 2) == 't')
+                  else if (c == '*')
                     {
-                      if (next + sizeof(var->ptr) > length)
-                        {
-                          break;
-                        }
-
-                      var->ptr = va_arg(va, ptrdiff_t);
-                      next += sizeof(var->ptr);
-                    }
-                  else
-                    {
-                      if (next + sizeof(var->i) > length)
-                        {
-                          break;
-                        }
-
                       var->i = va_arg(va, int);
                       next += sizeof(var->i);
                     }
-
-                  infmt = false;
-                }
-
-              if (c == 'e' || c == 'f' || c == 'g' ||
-                  c == 'E' || c == 'F' || c == 'G')
-                {
-                  if (*(fmt - 2) == 'L')
+                  else if (c == 's')
                     {
-#ifdef CONFIG_HAVE_LONG_DOUBLE
-                      if (next + sizeof(var->ld) > length)
+                      size_t len;
+                      var->s = va_arg(va, FAR char *);
+                      len = strlen(var->s) + 1;
+                      if (next + len > length)
+                        {
+                          len = length - next;
+                        }
+
+                      strlcpy(note->npt_data + next, var->s, len);
+                      next += len;
+                      infmt = false;
+                    }
+                  else if (c == 'p')
+                    {
+                      if (next + sizeof(var->p) > length)
                         {
                           break;
                         }
 
-                      var->ld = va_arg(va, long double);
-                      next += sizeof(var->ld);
-#endif
+                      var->p = va_arg(va, FAR void *);
+                      next += sizeof(var->p);
+                      infmt = false;
                     }
-                  else if (*(fmt - 2) == 'l')
-                    {
-#ifdef CONFIG_HAVE_DOUBLE
-                      if (next + sizeof(var->d) > length)
-                        {
-                          break;
-                        }
-
-                      var->d = va_arg(va, double);
-                      next += sizeof(var->d);
-#endif
-                    }
-                  else
-#ifdef CONFIG_HAVE_FLOAT
-                    {
-                      if (next + sizeof(var->l) > length)
-                        {
-                          break;
-                        }
-
-                      var->l = va_arg(va, double);
-                      next += sizeof(var->l);
-#endif
-                    }
-
-                  infmt = false;
                 }
             }
 
-          length = SIZEOF_NOTE_BINARY(next);
-          note_common(tcb, &note->nbi_cmn, length, NOTE_DUMP_BINARY);
-          note->nbi_ip = ip;
+          length = SIZEOF_NOTE_PRINTF(next);
+          note_common(tcb, &note->npt_cmn, length, NOTE_DUMP_PRINTF);
+          note->npt_ip = ip;
+          note->npt_fmt = fmt;
+          note->npt_type = type;
         }
 
       /* Add the note to circular buffer */
@@ -1703,23 +1760,15 @@ void sched_note_vbprintf_ip(uint32_t tag, uintptr_t ip,
     }
 }
 
-void sched_note_printf_ip(uint32_t tag, uintptr_t ip,
-                          FAR const char *fmt, ...)
+void sched_note_printf_ip(uint32_t tag, uintptr_t ip, FAR const char *fmt,
+                          uint32_t type, ...)
 {
   va_list va;
-  va_start(va, fmt);
-  sched_note_vprintf_ip(tag, ip, fmt, va);
+  va_start(va, type);
+  sched_note_vprintf_ip(tag, ip, fmt, type, va);
   va_end(va);
 }
 
-void sched_note_bprintf_ip(uint32_t tag, uintptr_t ip,
-                           FAR const char *fmt, ...)
-{
-  va_list va;
-  va_start(va, fmt);
-  sched_note_vbprintf_ip(tag, ip, fmt, va);
-  va_end(va);
-}
 #endif /* CONFIG_SCHED_INSTRUMENTATION_DUMP */
 
 #ifdef CONFIG_SCHED_INSTRUMENTATION_FILTER
@@ -1946,14 +1995,16 @@ static void note_driver_instrument_enter(FAR void *this_fn,
                                          FAR void *call_site,
                                          FAR void *arg)
 {
-  sched_note_string_ip(NOTE_TAG_ALWAYS, (uintptr_t)this_fn, "B");
+  sched_note_event_ip(NOTE_TAG_ALWAYS, (uintptr_t)this_fn,
+                      NOTE_DUMP_BEGIN, NULL, 0);
 }
 
 static void note_driver_instrument_leave(FAR void *this_fn,
                                          FAR void *call_site,
                                          FAR void *arg)
 {
-  sched_note_string_ip(NOTE_TAG_ALWAYS, (uintptr_t)this_fn, "E");
+  sched_note_event_ip(NOTE_TAG_ALWAYS, (uintptr_t)this_fn,
+                      NOTE_DUMP_END, NULL, 0);
 }
 #endif
 
@@ -1986,4 +2037,3 @@ int note_driver_register(FAR struct note_driver_s *driver)
 
   return -ENOMEM;
 }
-
