@@ -31,6 +31,7 @@
 #include <errno.h>
 #include <stdio.h>
 #include <string.h>
+#include <inttypes.h>
 
 #include <nuttx/spinlock.h>
 #include <nuttx/sched.h>
@@ -295,7 +296,7 @@ static void noteram_remove(FAR struct noteram_driver_s *drv)
 
   /* Get the length of the note at the tail index */
 
-  length = drv->ni_buffer[tail];
+  length = NOTE_ALIGN(drv->ni_buffer[tail]);
   DEBUGASSERT(length <= noteram_length(drv));
 
   /* Increment the tail index to remove the entire note from the circular
@@ -365,7 +366,7 @@ static ssize_t noteram_get(FAR struct noteram_driver_s *drv,
     {
       /* Skip the large note so that we do not get constipated. */
 
-      drv->ni_read = noteram_next(drv, read, notelen);
+      drv->ni_read = noteram_next(drv, read, NOTE_ALIGN(notelen));
 
       /* and return an error */
 
@@ -387,7 +388,7 @@ static ssize_t noteram_get(FAR struct noteram_driver_s *drv,
       remaining--;
     }
 
-  drv->ni_read = read;
+  drv->ni_read = noteram_next(drv, drv->ni_read, NOTE_ALIGN(notelen));
 
   return notelen;
 }
@@ -419,6 +420,7 @@ static int noteram_open(FAR struct file *filep)
 int noteram_close(FAR struct file *filep)
 {
   FAR struct noteram_dump_context_s *ctx = filep->f_priv;
+
   kmm_free(ctx);
   return OK;
 }
@@ -498,7 +500,7 @@ static int noteram_ioctl(FAR struct file *filep, int cmd, unsigned long arg)
           }
         else
           {
-            *(unsigned int *)arg = drv->ni_overwrite;
+            *(FAR unsigned int *)arg = drv->ni_overwrite;
             ret = OK;
           }
         break;
@@ -515,7 +517,7 @@ static int noteram_ioctl(FAR struct file *filep, int cmd, unsigned long arg)
           }
         else
           {
-            drv->ni_overwrite = *(unsigned int *)arg;
+            drv->ni_overwrite = *(FAR unsigned int *)arg;
             ret = OK;
           }
         break;
@@ -567,7 +569,7 @@ static void noteram_add(FAR struct note_driver_s *driver,
   DEBUGASSERT(note != NULL && notelen < drv->ni_bufsize);
   remain = drv->ni_bufsize - noteram_length(drv);
 
-  if (remain < notelen)
+  if (remain <= NOTE_ALIGN(notelen))
     {
       if (drv->ni_overwrite == NOTERAM_MODE_OVERWRITE_DISABLE)
         {
@@ -586,7 +588,7 @@ static void noteram_add(FAR struct note_driver_s *driver,
           noteram_remove(drv);
           remain = drv->ni_bufsize - noteram_length(drv);
         }
-      while (remain < notelen);
+      while (remain <= NOTE_ALIGN(notelen));
     }
 
   head = drv->ni_head;
@@ -594,7 +596,7 @@ static void noteram_add(FAR struct note_driver_s *driver,
   space = space < notelen ? space : notelen;
   memcpy(drv->ni_buffer + head, note, space);
   memcpy(drv->ni_buffer, buf + space, notelen - space);
-  drv->ni_head = noteram_next(drv, head, notelen);
+  drv->ni_head = noteram_next(drv, head, NOTE_ALIGN(notelen));
   spin_unlock_irqrestore_wo_note(&drv->lock, flags);
 }
 
@@ -621,11 +623,12 @@ static void noteram_dump_init_context(FAR struct noteram_dump_context_s *ctx)
 }
 
 /****************************************************************************
- * Name: get_task_name
+ * Name: get_taskname
  ****************************************************************************/
 
-static const char *get_task_name(pid_t pid)
+static const char *get_taskname(pid_t pid)
 {
+#if CONFIG_DRIVERS_NOTE_TASKNAME_BUFSIZE > 0
   FAR const char *taskname;
 
   taskname = note_get_taskname(pid);
@@ -633,6 +636,7 @@ static const char *get_task_name(pid_t pid)
     {
       return taskname;
     }
+#endif
 
   return "<noname>";
 }
@@ -658,7 +662,7 @@ static int noteram_dump_header(FAR struct lib_outstream_s *s,
 #endif
 
   ret = lib_sprintf(s, "%8s-%-3u [%d] %3" PRIu32 ".%09" PRIu32 ": ",
-                    get_task_name(pid), get_pid(pid), cpu, sec, nsec);
+                    get_taskname(pid), get_pid(pid), cpu, sec, nsec);
   return ret;
 }
 
@@ -694,9 +698,9 @@ static int noteram_dump_sched_switch(FAR struct lib_outstream_s *s,
   ret = lib_sprintf(s, "sched_switch: prev_comm=%s prev_pid=%u "
                     "prev_prio=%u prev_state=%c ==> "
                     "next_comm=%s next_pid=%u next_prio=%u\n",
-                    get_task_name(current_pid), get_pid(current_pid),
+                    get_taskname(current_pid), get_pid(current_pid),
                     current_priority, get_task_state(cctx->current_state),
-                    get_task_name(next_pid), get_pid(next_pid),
+                    get_taskname(next_pid), get_pid(next_pid),
                     next_priority);
 
   cctx->current_pid = cctx->next_pid;
@@ -706,6 +710,204 @@ static int noteram_dump_sched_switch(FAR struct lib_outstream_s *s,
 }
 #endif
 
+/****************************************************************************
+ * Name: noteram_dump_printf
+ ****************************************************************************/
+
+#ifdef CONFIG_SCHED_INSTRUMENTATION_DUMP
+static int noteram_dump_printf(FAR struct lib_outstream_s *s,
+                               FAR struct note_printf_s *note)
+{
+  begin_packed_struct union
+    {
+      int i;
+      long l;
+#ifdef CONFIG_HAVE_LONG_LONG
+      long long ll;
+#endif
+      intmax_t im;
+      size_t sz;
+      ptrdiff_t pd;
+      FAR void *p;
+      FAR const char *s;
+#ifdef CONFIG_HAVE_DOUBLE
+      double d;
+#  ifdef CONFIG_HAVE_LONG_DOUBLE
+      long double ld;
+#  endif
+#endif
+    }
+
+  end_packed_struct *var;
+  size_t offset = 0;
+  size_t ret = 0;
+  size_t len = 0;
+
+  if (note->npt_type == 0)
+    {
+      FAR const char *p = note->npt_fmt;
+      bool infmt = false;
+      char fmtstr[64];
+      char c;
+
+      while ((c = *p++) != '\0')
+        {
+          if (c != '%' && !infmt)
+            {
+              lib_stream_putc(s, c);
+              ret++;
+              continue;
+            }
+
+          if (!infmt)
+            {
+              len = 0;
+              infmt = true;
+              memset(fmtstr, 0, sizeof(fmtstr));
+            }
+
+          var = (FAR void *)(note->npt_data + offset);
+          fmtstr[len++] = c;
+
+          if (c == 'c' || c == 'd' || c == 'i' || c == 'u' ||
+              c == 'o' || c == 'x' || c == 'X')
+            {
+              if (*(p - 2) == 'j')
+                {
+                  offset += sizeof(var->im);
+                  ret += lib_sprintf(s, fmtstr, var->im);
+                }
+#ifdef CONFIG_HAVE_LONG_LONG
+              else if (*(p - 2) == 'l' && *(p - 3) == 'l')
+                {
+                  offset += sizeof(var->ll);
+                  ret += lib_sprintf(s, fmtstr, var->ll);
+                }
+#endif
+              else if (*(p - 2) == 'l')
+                {
+                  offset += sizeof(var->l);
+                  ret += lib_sprintf(s, fmtstr, var->l);
+                }
+              else if (*(p - 2) == 'z')
+                {
+                  offset += sizeof(var->sz);
+                  ret += lib_sprintf(s, fmtstr, var->sz);
+                }
+              else if (*(p - 2) == 't')
+                {
+                  offset += sizeof(var->pd);
+                  ret += lib_sprintf(s, fmtstr, var->pd);
+                }
+              else
+                {
+                  offset += sizeof(var->i);
+                  ret += lib_sprintf(s, fmtstr, var->i);
+                }
+
+              infmt = false;
+            }
+          else if (c == 'e' || c == 'f' || c == 'g' || c == 'a' ||
+                  c == 'A' || c == 'E' || c == 'F' || c == 'G')
+            {
+#ifdef CONFIG_HAVE_DOUBLE
+#  ifdef CONFIG_HAVE_LONG_DOUBLE
+              if (*(p - 2) == 'L')
+                {
+                  offset += sizeof(var->ld);
+                  ret += lib_sprintf(s, fmtstr, var->ld);
+                }
+              else
+#  endif
+                {
+                  offset += sizeof(var->d);
+                  ret += lib_sprintf(s, fmtstr, var->d);
+                }
+
+              infmt = false;
+            }
+#endif
+          else if (c == '*')
+            {
+              itoa(var->i, fmtstr + len - 1, 10);
+              len = strlen(fmtstr);
+              offset += sizeof(var->i);
+            }
+          else if (c == 's')
+            {
+              const char *str = note->npt_data + offset;
+              offset += strlen(str) + 1;
+              ret += lib_sprintf(s, fmtstr, str);
+              infmt = false;
+            }
+          else if (c == 'p')
+            {
+              offset += sizeof(var->p);
+              ret += lib_sprintf(s, fmtstr, var->p);
+              infmt = false;
+            }
+        }
+
+      if (*(p - 2) != '\n')
+        {
+          lib_stream_putc(s, '\n');
+          ret++;
+        }
+    }
+  else
+    {
+      size_t count = NOTE_PRINTF_GET_COUNT(note->npt_type);
+      size_t i;
+
+      len = strlen(note->npt_fmt);
+      if (note->npt_fmt[len - 1] == '\n')
+        {
+          len--;
+        }
+
+      ret += lib_sprintf(s, "%p", note->npt_fmt);
+      for (i = 0; i < count; i++)
+        {
+          int type = NOTE_PRINTF_GET_TYPE(note->npt_type, i);
+          var = (FAR void *)(note->npt_data + offset);
+
+          switch (type)
+            {
+              case NOTE_PRINTF_UINT32:
+                {
+                  offset += sizeof(var->i);
+                  ret += lib_sprintf(s, " %u", var->i);
+                }
+                break;
+              case NOTE_PRINTF_UINT64:
+                {
+                  offset += sizeof(var->ll);
+                  ret += lib_sprintf(s, " %llu", var->ll);
+                }
+                break;
+              case NOTE_PRINTF_STRING:
+                {
+                  const char *str = note->npt_data + offset;
+                  offset += strlen(str) + 1;
+                  ret += lib_sprintf(s, " %s", str);
+                }
+                break;
+              case NOTE_PRINTF_DOUBLE:
+                {
+                  offset += sizeof(var->d);
+                  ret += lib_sprintf(s, " %f", var->d);
+                }
+            }
+        }
+
+        lib_stream_putc(s, '\n');
+        ret++;
+    }
+
+  return ret;
+}
+#endif
+
 /****************************************************************************
  * Name: noteram_dump_one
  ****************************************************************************/
@@ -740,7 +942,7 @@ static int noteram_dump_one(FAR uint8_t *p, FAR struct lib_outstream_s *s,
         ret += noteram_dump_header(s, note, ctx);
         ret += lib_sprintf(s, "sched_wakeup_new: comm=%s pid=%d "
                            "target_cpu=%d\n",
-                           get_task_name(pid), get_pid(pid), cpu);
+                           get_taskname(pid), get_pid(pid), cpu);
       }
       break;
 
@@ -794,7 +996,7 @@ static int noteram_dump_one(FAR uint8_t *p, FAR struct lib_outstream_s *s,
             ret += noteram_dump_header(s, note, ctx);
             ret += lib_sprintf(s, "sched_waking: comm=%s "
                                "pid=%d target_cpu=%d\n",
-                               get_task_name(cctx->next_pid),
+                               get_taskname(cctx->next_pid),
                                get_pid(cctx->next_pid), cpu);
             cctx->pendingswitch = true;
           }
@@ -897,6 +1099,27 @@ static int noteram_dump_one(FAR uint8_t *p, FAR struct lib_outstream_s *s,
       break;
 #endif
 
+#ifdef CONFIG_SCHED_INSTRUMENTATION_WDOG
+    case NOTE_WDOG_START:
+    case NOTE_WDOG_CANCEL:
+    case NOTE_WDOG_ENTER:
+    case NOTE_WDOG_LEAVE:
+      {
+        FAR struct note_wdog_s *nw;
+        FAR const char *name[] =
+          {
+            "start", "cancel", "enter", "leave",
+          };
+
+        nw = (FAR struct note_wdog_s *)p;
+        ret += noteram_dump_header(s, note, ctx);
+        ret += lib_sprintf(s, "tracing_mark_write: I|%d|wdog: %s-%pS %p\n",
+                           pid, name[note->nc_type - NOTE_WDOG_START],
+                           (FAR void *)nw->handler, (FAR void *)nw->arg);
+      }
+      break;
+#endif
+
 #ifdef CONFIG_SCHED_INSTRUMENTATION_CSECTION
     case NOTE_CSECTION_ENTER:
     case NOTE_CSECTION_LEAVE:
@@ -929,42 +1152,30 @@ static int noteram_dump_one(FAR uint8_t *p, FAR struct lib_outstream_s *s,
 #endif
 
 #ifdef CONFIG_SCHED_INSTRUMENTATION_DUMP
-    case NOTE_DUMP_STRING:
+    case NOTE_DUMP_PRINTF:
       {
-        FAR struct note_string_s *nst;
-        uintptr_t ip;
+        FAR struct note_printf_s *npt;
 
-        nst = (FAR struct note_string_s *)p;
-        ret += noteram_dump_header(s, note, ctx);
-        ip = nst->nst_ip;
-
-        if (nst->nst_data[1] == '\0' &&
-            (nst->nst_data[0] == 'B' || nst->nst_data[0] == 'E'))
-          {
-            ret += lib_sprintf(s, "tracing_mark_write: %c|%d|%pS\n",
-                               nst->nst_data[0], pid, (FAR void *)ip);
-          }
-        else
-          {
-            ret += lib_sprintf(s, "tracing_mark_write: %s\n",
-                               nst->nst_data);
-          }
+        npt = (FAR struct note_printf_s *)p;
+        ret += noteram_dump_header(s, &npt->npt_cmn, ctx);
+        ret += lib_sprintf(s, "tracing_mark_write: ");
+        ret += noteram_dump_printf(s, npt);
       }
       break;
     case NOTE_DUMP_BEGIN:
     case NOTE_DUMP_END:
       {
-        FAR struct note_binary_s *nbi = (FAR struct note_binary_s *)p;
+        FAR struct note_event_s *nbi = (FAR struct note_event_s *)p;
         char c = note->nc_type == NOTE_DUMP_BEGIN ? 'B' : 'E';
-        int len = note->nc_length - sizeof(struct note_binary_s);
+        int len = note->nc_length - SIZEOF_NOTE_EVENT(0);
         uintptr_t ip;
 
-        ip = nbi->nbi_ip;
-        ret += noteram_dump_header(s, &nbi->nbi_cmn, ctx);
+        ip = nbi->nev_ip;
+        ret += noteram_dump_header(s, &nbi->nev_cmn, ctx);
         if (len > 0)
           {
             ret += lib_sprintf(s, "tracing_mark_write: %c|%d|%.*s\n",
-                               c, pid, len, (FAR const char *)nbi->nbi_data);
+                               c, pid, len, (FAR const char *)nbi->nev_data);
           }
         else
           {
@@ -975,47 +1186,45 @@ static int noteram_dump_one(FAR uint8_t *p, FAR struct lib_outstream_s *s,
       break;
     case NOTE_DUMP_MARK:
       {
-        int len = note->nc_length - sizeof(struct note_binary_s);
-        FAR struct note_binary_s *nbi = (FAR struct note_binary_s *)p;
-        ret += noteram_dump_header(s, &nbi->nbi_cmn, ctx);
+        int len = note->nc_length - sizeof(struct note_event_s);
+        FAR struct note_event_s *nbi = (FAR struct note_event_s *)p;
+        ret += noteram_dump_header(s, &nbi->nev_cmn, ctx);
         ret += lib_sprintf(s, "tracing_mark_write: I|%d|%.*s\n",
-                           pid, len, (FAR const char *)nbi->nbi_data);
+                           pid, len, (FAR const char *)nbi->nev_data);
       }
       break;
     case NOTE_DUMP_COUNTER:
       {
-        FAR struct note_binary_s *nbi = (FAR struct note_binary_s *)p;
+        FAR struct note_event_s *nbi = (FAR struct note_event_s *)p;
         FAR struct note_counter_s *counter;
-        counter = (FAR struct note_counter_s *)nbi->nbi_data;
-        ret += noteram_dump_header(s, &nbi->nbi_cmn, ctx);
+        counter = (FAR struct note_counter_s *)nbi->nev_data;
+        ret += noteram_dump_header(s, &nbi->nev_cmn, ctx);
         ret += lib_sprintf(s, "tracing_mark_write: C|%d|%s|%ld\n",
                            pid, counter->name, counter->value);
       }
       break;
-    case NOTE_DUMP_BINARY:
+#endif
+#ifdef CONFIG_SCHED_INSTRUMENTATION_HEAP
+    case NOTE_HEAP_ADD:
+    case NOTE_HEAP_REMOVE:
+    case NOTE_HEAP_ALLOC:
+    case NOTE_HEAP_FREE:
       {
-        FAR struct note_binary_s *nbi;
-        uint8_t count;
-        uintptr_t ip;
-        int i;
-
-        nbi = (FAR struct note_binary_s *)p;
-        ret += noteram_dump_header(s, note, ctx);
-        count = note->nc_length - sizeof(struct note_binary_s) + 1;
-        ip = nbi->nbi_ip;
-
-        ret += lib_sprintf(s, "tracing_mark_write: %pS: count=%u",
-                           (FAR void *)ip, count);
-        for (i = 0; i < count; i++)
+        FAR struct note_heap_s *nmm = (FAR struct note_heap_s *)p;
+        FAR const char *name[] =
           {
-            ret += lib_sprintf(s, " 0x%x", nbi->nbi_data[i]);
-          }
+            "add", "remove", "malloc", "free"
+          };
 
-        ret += lib_sprintf(s, "\n");
+        ret += noteram_dump_header(s, &nmm->nhp_cmn, ctx);
+        ret += lib_sprintf(s, "tracing_mark_write: C|%d|Heap Usage|%d|%s"
+                           ": heap: %p size:%" PRIiPTR ", address: %p\n",
+                           pid, nmm->used,
+                           name[note->nc_type - NOTE_HEAP_ADD],
+                           nmm->heap, nmm->size, nmm->mem);
       }
       break;
 #endif
-
     default:
       break;
     }
