@@ -27,6 +27,7 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/ioctl.h>
+#include <sys/param.h>
 #include <stdint.h>
 #include <stdbool.h>
 #include <stdlib.h>
@@ -94,12 +95,11 @@ FAR struct pipe_dev_s *pipecommon_allocdev(size_t bufsize)
 
   /* Allocate a private structure to manage the pipe */
 
-  dev = kmm_malloc(sizeof(struct pipe_dev_s));
+  dev = kmm_zalloc(sizeof(struct pipe_dev_s));
   if (dev)
     {
       /* Initialize the private structure */
 
-      memset(dev, 0, sizeof(struct pipe_dev_s));
       nxmutex_init(&dev->d_bflock);
       nxsem_init(&dev->d_rdsem, 0, 0);
       nxsem_init(&dev->d_wrsem, 0, 0);
@@ -145,12 +145,9 @@ int pipecommon_open(FAR struct file *filep)
       return ret;
     }
 
-  /* If this the first reference on the device, then allocate the buffer.
-   * In the case of policy 1, the buffer already be present when the pipe
-   * is first opened.
-   */
+  /* If d_buffer is not initialized, init it. */
 
-  if (inode->i_crefs == 1 && !circbuf_is_init(&dev->d_buffer))
+  if (!circbuf_is_init(&dev->d_buffer))
     {
       ret = circbuf_init(&dev->d_buffer, NULL, dev->d_bufsize);
       if (ret < 0)
@@ -160,6 +157,8 @@ int pipecommon_open(FAR struct file *filep)
         }
     }
 
+  dev->d_crefs++;
+
   /* If opened for writing, increment the count of writers on the pipe
    * instance.
    */
@@ -304,7 +303,7 @@ int pipecommon_close(FAR struct file *filep)
   FAR struct pipe_dev_s *dev   = inode->i_private;
   int                    ret;
 
-  DEBUGASSERT(dev && filep->f_inode->i_crefs > 0);
+  DEBUGASSERT(dev && dev->d_crefs > 0);
 
   /* Make sure that we have exclusive access to the device structure.
    * NOTE: close() is supposed to return EINTR if interrupted, however
@@ -325,7 +324,8 @@ int pipecommon_close(FAR struct file *filep)
 
   /* Check if the decremented inode reference count would go to zero */
 
-  if (inode->i_crefs > 1)
+  dev->d_crefs--;
+  if (dev->d_crefs > 0)
     {
       /* More references.. If opened for writing, decrement the count of
        * writers on the pipe instance.
@@ -438,7 +438,7 @@ ssize_t pipecommon_read(FAR struct file *filep, FAR char *buffer, size_t len)
     {
       /* If there are no writers on the pipe, then return end of file */
 
-      if (dev->d_nwriters <= 0)
+      if (dev->d_nwriters <= 0 && PIPE_IS_POLICY_0(dev->d_flags))
         {
           nxmutex_unlock(&dev->d_bflock);
           return 0;
@@ -554,7 +554,7 @@ ssize_t pipecommon_write(FAR struct file *filep, FAR const char *buffer,
        * ignoring this signal, then write(2) fails with the error EPIPE."
        */
 
-      if (dev->d_nreaders <= 0)
+      if (dev->d_nreaders <= 0 && PIPE_IS_POLICY_0(dev->d_flags))
         {
           nxmutex_unlock(&dev->d_bflock);
           return nwritten == 0 ? -EPIPE : nwritten;
@@ -844,7 +844,35 @@ int pipecommon_ioctl(FAR struct file *filep, int cmd, unsigned long arg)
 
           DEBUGASSERT(peek && peek->buf);
 
-          ret = circbuf_peek(&dev->d_buffer, peek->buf, peek->size);
+          ret = circbuf_peekat(&dev->d_buffer,
+                               dev->d_buffer.tail + peek->offset,
+                               peek->buf, peek->size);
+        }
+        break;
+
+      case PIPEIOC_SETSIZE:
+        {
+          size_t size = (size_t)arg;
+          if (size == 0)
+            {
+              ret = -EINVAL;
+              break;
+            }
+
+          size = MIN(size, CONFIG_DEV_PIPE_MAXSIZE);
+          ret = circbuf_resize(&dev->d_buffer, size);
+          if (ret != 0)
+            {
+              break;
+            }
+
+          dev->d_bufsize = size;
+        }
+        break;
+
+      case PIPEIOC_GETSIZE:
+        {
+          ret = dev->d_bufsize;
         }
         break;
 
@@ -886,26 +914,28 @@ int pipecommon_ioctl(FAR struct file *filep, int cmd, unsigned long arg)
 int pipecommon_unlink(FAR struct inode *inode)
 {
   FAR struct pipe_dev_s *dev;
+  int ret;
 
   DEBUGASSERT(inode->i_private);
   dev = inode->i_private;
 
+  ret = nxmutex_lock(&dev->d_bflock);
+  if (ret < 0)
+    {
+      return ret;
+    }
+
+  if (dev->d_crefs <= 0)
+    {
+      circbuf_uninit(&dev->d_buffer);
+      pipecommon_freedev(dev);
+      return OK;
+    }
+
   /* Mark the pipe unlinked */
 
   PIPE_UNLINK(dev->d_flags);
-
-  /* Are the any open references to the driver? */
-
-  if (inode->i_crefs == 1)
-    {
-      /* No.. free the buffer (if there is one) */
-
-      circbuf_uninit(&dev->d_buffer);
-
-      /* And free the device structure. */
-
-      pipecommon_freedev(dev);
-    }
+  nxmutex_unlock(&dev->d_bflock);
 
   return OK;
 }
