@@ -635,7 +635,7 @@ static int bq769x0_updategain(FAR struct bq769x0_dev_s *priv)
       return ret;
     }
 
-  ret = bq769x0_getreg8(priv, BQ769X0_REG_ADCOFFSET, (uint8_t *)&offset);
+  ret = bq769x0_getreg8(priv, BQ769X0_REG_ADCOFFSET, (FAR uint8_t *)&offset);
   if (ret < 0)
     {
       baterr("ERROR: Error reading from BQ769X0! Error = %d\n", ret);
@@ -1588,7 +1588,7 @@ static int bq769x0_getcurrent(FAR struct bq769x0_dev_s *priv,
           /* Get the CC register data (a signed value) */
 
           ret = bq769x0_getreg16(priv, BQ769X0_REG_CC_HI,
-                                 (uint16_t *)&ccval);
+                                 (FAR uint16_t *)&ccval);
           if (ret < 0)
             {
               baterr("ERROR: Error reading from BQ769X0! Error = %d\n", ret);
