@@ -27,7 +27,9 @@
 #include <debug.h>
 #include <assert.h>
 #include <errno.h>
+#include <sched.h>
 #include <nuttx/clock.h>
+#include <nuttx/arch.h>
 #include <nuttx/power/pm_runtime.h>
 #include <sched/sched.h>
 
