@@ -256,7 +256,7 @@ static int lirc_ioctl(FAR struct file *filep, int cmd, unsigned long arg)
   FAR struct lirc_fh_s *fh = filep->f_priv;
   FAR struct lirc_lowerhalf_s *lower = fh->lower;
   FAR struct lirc_upperhalf_s *upper = lower->priv;
-  FAR unsigned int *val = (unsigned int *)(uintptr_t)arg;
+  FAR unsigned int *val = (FAR unsigned int *)(uintptr_t)arg;
   int ret;
 
   ret = nxmutex_lock(&upper->lock);
