@@ -65,7 +65,7 @@
 
 #if defined(CONFIG_SEGGER_RTT_MODE_NO_BLOCK_TRIM)
 #  define SEGGER_RTT_MODE_DEFAULT       SEGGER_RTT_MODE_NO_BLOCK_TRIM
-#elif defined(SEGGER_RTT_MODE_BLOCK_IF_FIFO_FULL)
+#elif defined(CONFIG_SEGGER_RTT_MODE_BLOCK_IF_FIFO_FULL)
 #  define SEGGER_RTT_MODE_DEFAULT       SEGGER_RTT_MODE_BLOCK_IF_FIFO_FULL
 #else
 #  define SEGGER_RTT_MODE_DEFAULT       SEGGER_RTT_MODE_NO_BLOCK_SKIP
