@@ -23,6 +23,7 @@
  ****************************************************************************/
 
 #include <stddef.h>
+#include <stdio.h>
 #include <syslog.h>
 
 #include <nuttx/clock.h>
@@ -73,6 +74,15 @@ static void note_sysview_syscall_enter(FAR struct note_driver_s *drv,
 static void note_sysview_syscall_leave(FAR struct note_driver_s *drv,
                                        int nr, uintptr_t result);
 #endif
+#ifdef CONFIG_SCHED_INSTRUMENTATION_HEAP
+static void note_sysview_heap(FAR struct note_driver_s *drv,
+                              uint8_t event, FAR void *heap, FAR void *mem,
+                              size_t size, size_t curused);
+#endif
+#ifdef CONFIG_SCHED_INSTRUMENTATION_WDOG
+static void note_sysview_wdog(FAR struct note_driver_s *drv, uint8_t event,
+                              FAR void *handler, FAR const void *arg);
+#endif
 
 /****************************************************************************
  * Private Data
@@ -113,6 +123,12 @@ static const struct note_driver_ops_s g_note_sysview_ops =
 #ifdef CONFIG_SCHED_INSTRUMENTATION_IRQHANDLER
   note_sysview_irqhandler,    /* irqhandler */
 #endif
+#ifdef CONFIG_SCHED_INSTRUMENTATION_WDOG
+  note_sysview_wdog,          /* wdog */
+#endif
+#ifdef CONFIG_SCHED_INSTRUMENTATION_HEAP
+  note_sysview_heap,          /* heap */
+#endif
 };
 
 static struct note_sysview_driver_s g_note_sysview_driver =
@@ -135,11 +151,7 @@ static void note_sysview_send_taskinfo(FAR struct tcb_s *tcb)
   SEGGER_SYSVIEW_TASKINFO info;
 
   info.TaskID    = tcb->pid;
-#if CONFIG_TASK_NAME_SIZE > 0
-  info.sName     = tcb->name;
-#else
-  info.sName     = "<noname>";
-#endif
+  info.sName     = get_task_name(tcb);
   info.Prio      = tcb->sched_priority;
   info.StackBase = (uintptr_t)tcb->stack_base_ptr;
   info.StackSize = tcb->adj_stack_size;
@@ -323,6 +335,79 @@ static void note_sysview_syscall_leave(FAR struct note_driver_s *drv,
 }
 #endif
 
+#ifdef CONFIG_SCHED_INSTRUMENTATION_HEAP
+static void note_sysview_heap(FAR struct note_driver_s *drv,
+                              uint8_t event, FAR void *heap, FAR void *mem,
+                              size_t size, size_t curused)
+{
+  switch (event)
+    {
+      case NOTE_HEAP_ALLOC:
+      case NOTE_HEAP_FREE:
+        {
+          U32 value = (U32)curused;
+          const SEGGER_SYSVIEW_DATA_SAMPLE data =
+            {
+              .ID = (U32)(uintptr_t)heap,
+              .pU32_Value = &value,
+            };
+
+          SEGGER_SYSVIEW_SampleData(&data);
+          if (event == NOTE_HEAP_ALLOC)
+            {
+              SEGGER_SYSVIEW_HeapAlloc(heap, mem, size);
+            }
+          else
+            {
+              SEGGER_SYSVIEW_HeapFree(heap, mem);
+            }
+
+          break;
+        }
+
+      case NOTE_HEAP_ADD:
+        {
+          char name[32];
+          SEGGER_SYSVIEW_DATA_REGISTER data =
+            {
+              .ID = (U32)(uintptr_t)heap,
+              .DataType = SEGGER_SYSVIEW_TYPE_U32,
+              .Offset = 0,
+              .RangeMin = 0,
+              .RangeMax = 0,
+              .ScalingFactor = 1.f,
+              .sUnit = "B",
+              .sName = name,
+            };
+
+          snprintf(name, sizeof(name), "Heap%p", heap);
+
+          SEGGER_SYSVIEW_RegisterData(&data);
+          SEGGER_SYSVIEW_HeapDefine(heap, mem, size, 0);
+          break;
+        }
+
+      default:
+        break;
+    }
+}
+#endif
+
+#ifdef CONFIG_SCHED_INSTRUMENTATION_WDOG
+static void note_sysview_wdog(FAR struct note_driver_s *drv, uint8_t event,
+                              FAR void *handler, FAR const void *arg)
+{
+  if (event == NOTE_WDOG_ENTER)
+    {
+      SEGGER_SYSVIEW_RecordEnterTimer((uintptr_t)handler);
+    }
+  else if (event == NOTE_WDOG_LEAVE)
+    {
+      SEGGER_SYSVIEW_RecordExitTimer();
+    }
+}
+#endif
+
 /****************************************************************************
  * Public Functions
  ****************************************************************************/
