@@ -55,7 +55,7 @@ struct adxl372_sensor_s
   int                        devno;
 #ifdef CONFIG_SENSORS_ADXL372_POLL
   bool                       enabled;
-  unsigned long              interval;
+  uint32_t                   interval;
   sem_t                      run;
 #endif
 };
@@ -82,7 +82,7 @@ static int adxl372_activate(FAR struct sensor_lowerhalf_s *lower,
                             bool enable);
 static int adxl372_set_interval(FAR struct sensor_lowerhalf_s *lower,
                                 FAR struct file *filep,
-                                FAR unsigned long *period_us);
+                                FAR uint32_t *period_us);
 #ifndef CONFIG_SENSORS_ADXL372_POLL
 static int adxl372_fetch(FAR struct sensor_lowerhalf_s *lower,
                          FAR struct file *filep,
@@ -105,9 +105,11 @@ static const struct sensor_ops_s g_adxl372_accel_ops =
 #else
   adxl372_fetch,
 #endif
+  NULL,                 /* flush */
   NULL,                 /* selftest */
   NULL,                 /* set_calibvalue */
   NULL,                 /* calibrate */
+  NULL                  /* get_info */
   NULL                  /* control */
 };
 
@@ -410,7 +412,7 @@ static int adxl372_activate(FAR struct sensor_lowerhalf_s *lower,
 
 static int adxl372_set_interval(FAR struct sensor_lowerhalf_s *lower,
                                 FAR struct file *filep,
-                                FAR unsigned long *period_us)
+                                FAR uint32_t *period_us)
 {
 #ifdef CONFIG_SENSORS_ADXL372_POLL
   FAR struct adxl372_sensor_s *priv = (FAR struct adxl372_sensor_s *)lower;
