@@ -68,7 +68,7 @@ struct bmi270_sensor_s
   FAR void                  *dev;
   bool                       enabled;
 #ifdef CONFIG_SENSORS_BMI270_POLL
-  unsigned long              interval;
+  uint32_t                   interval;
 #endif
   struct bmi270_dev_s        base;
 };
@@ -93,7 +93,7 @@ static int bmi270_activate(FAR struct sensor_lowerhalf_s *lower,
                            bool enable);
 static int bmi270_set_interval(FAR struct sensor_lowerhalf_s *lower,
                                FAR struct file *filep,
-                               FAR unsigned long *period_us);
+                               FAR uint32_t *period_us);
 #ifndef CONFIG_SENSORS_BMI270_POLL
 static int bmi270_fetch(FAR struct sensor_lowerhalf_s *lower,
                         FAR struct file *filep,
@@ -126,9 +126,11 @@ static const struct sensor_ops_s g_sensor_ops =
 #else
   bmi270_fetch,
 #endif
+  NULL,                 /* flush */
   NULL,                 /* selftest */
   NULL,                 /* set_calibvalue */
   NULL,                 /* calibrate */
+  NULL,                 /* get_info */
   bmi270_control
 };
 
@@ -207,7 +209,7 @@ static int bmi270_activate(FAR struct sensor_lowerhalf_s *lower,
 
 static int bmi270_set_interval(FAR struct sensor_lowerhalf_s *lower,
                                FAR struct file *filep,
-                               FAR unsigned long *interval)
+                               FAR uint32_t *interval)
 {
 #ifdef CONFIG_SENSORS_BMI270_POLL
   FAR struct bmi270_sensor_s *priv = NULL;
@@ -222,7 +224,7 @@ static int bmi270_set_interval(FAR struct sensor_lowerhalf_s *lower,
 
 #ifndef CONFIG_SENSORS_BMI270_POLL
 /****************************************************************************
- * Name: bmi270_set_interval
+ * Name: bmi270_fetch
  ****************************************************************************/
 
 static int bmi270_fetch(FAR struct sensor_lowerhalf_s *lower,
@@ -526,7 +528,7 @@ static int bmi270_thread(int argc, FAR char **argv)
 
       /* Get data */
 
-      bmi270_getregs(&gyro->base, BMI270_DATA_8, (uint8_t *)data, 12);
+      bmi270_getregs(&gyro->base, BMI270_DATA_8, (FAR uint8_t *)data, 12);
 
       /* Read accel */
 
