@@ -134,7 +134,7 @@ struct bmm150_sensor_dev_s
   uint32_t                        freq;
   mutex_t                         lock;
 #ifdef CONFIG_SENSORS_BMM150_POLL
-  unsigned long                   interval;
+  uint32_t                        interval;
   uint64_t                        last_update;
   sem_t                           run;
 #endif
@@ -153,7 +153,7 @@ static int bmm150_fetch(FAR struct sensor_lowerhalf_s *lower,
 #endif
 static int bmm150_set_interval(FAR struct sensor_lowerhalf_s *lower,
                                FAR struct file *filep,
-                               FAR unsigned long *period_us);
+                               FAR uint32_t *period_us);
 
 /* Helpers */
 
@@ -180,9 +180,11 @@ static const struct sensor_ops_s g_bmm150_sensor_ops =
 #else
   bmm150_fetch,
 #endif
+  NULL,                 /* flush */
   NULL,                 /* selftest */
   NULL,                 /* set_calibvalue */
   NULL,                 /* calibrate */
+  NULL,                 /* get_info */
   NULL,                 /* control */
 };
 
@@ -577,7 +579,7 @@ errout:
 
 static int bmm150_set_interval(FAR struct sensor_lowerhalf_s *lower,
                                   FAR struct file *filep,
-                                  FAR unsigned long *interval)
+                                  FAR uint32_t *interval)
 {
 #ifdef CONFIG_SENSORS_BMM150_POLL
   FAR struct bmm150_sensor_dev_s *dev =
