@@ -126,12 +126,12 @@ static int hts221_poll(FAR struct file *filep, FAR struct pollfd *fds,
 
 struct hts221_dev_s
 {
-  struct i2c_master_s *i2c;
+  FAR struct i2c_master_s *i2c;
   uint8_t addr;
-  hts221_config_t *config;
+  FAR hts221_config_t *config;
   mutex_t devlock;
   volatile bool int_pending;
-  struct pollfd *fds[CONFIG_HTS221_NPOLLWAITERS];
+  FAR struct pollfd *fds[CONFIG_HTS221_NPOLLWAITERS];
   struct
   {
     int16_t t0_out;
@@ -756,7 +756,7 @@ static int hts221_load_calibration_data(FAR struct hts221_dev_s *priv)
    * they are a good candidate to be added to entropy pool.
    */
 
-  up_rngaddentropy(RND_SRC_HW, (uint32_t *)&priv->calib,
+  up_rngaddentropy(RND_SRC_HW, (FAR uint32_t *)&priv->calib,
                    sizeof(priv->calib) / sizeof(uint32_t));
 
   return OK;
@@ -1124,7 +1124,7 @@ static int hts221_poll(FAR struct file *filep, FAR struct pollfd *fds,
     {
       /* This is a request to tear down the poll. */
 
-      struct pollfd **slot = (struct pollfd **)fds->priv;
+      FAR struct pollfd **slot = (FAR struct pollfd **)fds->priv;
       DEBUGASSERT(slot != NULL);
 
       /* Remove all memory of the poll setup */
