@@ -939,8 +939,8 @@ static int scd41_unlink(FAR struct inode *inode)
   FAR struct scd41_dev_s *priv;
   int ret;
 
-  DEBUGASSERT(inode != NULL && inode->i_private != NULL);
-  priv = (FAR struct scd41_dev_s *)inode->i_private;
+  DEBUGASSERT(inode->i_private != NULL);
+  priv = inode->i_private;
 
   /* Get exclusive access */
 
@@ -1000,7 +1000,7 @@ int scd41_register_i2c(FAR const char *devpath, FAR struct i2c_master_s *i2c)
 
   /* Initialize the device structure */
 
-  priv = (FAR struct scd41_dev_s *)kmm_zalloc(sizeof(struct scd41_dev_s));
+  priv = kmm_zalloc(sizeof(struct scd41_dev_s));
   if (priv == NULL)
     {
       scd41_dbg("ERROR: Failed to allocate instance\n");
