@@ -784,7 +784,7 @@ static uint8_t vl53l1x_getreg8(FAR struct vl53l1x_dev_s *priv,
 
   /* Write the register address */
 
-  ret = i2c_write(priv->i2c, &config, (uint8_t *)&regaddr, 2);
+  ret = i2c_write(priv->i2c, &config, (FAR uint8_t *)&regaddr, 2);
   if (ret < 0)
     {
       snerr("ERROR: i2c_write failed: %d\n", ret);
@@ -836,7 +836,7 @@ static uint16_t vl53l1x_getreg16(FAR struct vl53l1x_dev_s *priv,
   /* Register to read */
 
   sninfo("Reg %02x %\n", reg_addr_aux[0], reg_addr_aux[1]);
-  ret = i2c_write(priv->i2c, &config, (uint8_t *)&reg_addr_aux, 2);
+  ret = i2c_write(priv->i2c, &config, (FAR uint8_t *)&reg_addr_aux, 2);
   if (ret < 0)
     {
       snerr("ERROR: i2c_write failed: %d\n", ret);
@@ -845,7 +845,7 @@ static uint16_t vl53l1x_getreg16(FAR struct vl53l1x_dev_s *priv,
 
   /* Read register */
 
-  ret = i2c_read(priv->i2c, &config, (uint8_t *) & regval, 2);
+  ret = i2c_read(priv->i2c, &config, (FAR uint8_t *) & regval, 2);
   if (ret < 0)
     {
       snerr("ERROR: i2c_read failed: %d\n", ret);
@@ -942,7 +942,7 @@ static void vl53l1x_putreg8(FAR struct vl53l1x_dev_s *priv, uint16_t regaddr,
 
   /* Write the register address and value */
 
-  ret = i2c_write(priv->i2c, &config, (uint8_t *) & data, 3);
+  ret = i2c_write(priv->i2c, &config, (FAR uint8_t *) & data, 3);
   if (ret < 0)
     {
       snerr("ERROR: i2c_write failed: %d\n", ret);
@@ -978,7 +978,7 @@ static void vl53l1x_putreg16(FAR struct vl53l1x_dev_s *priv,
 
   /* Write the register address and value */
 
-  ret = i2c_write(priv->i2c, &config, (uint8_t *) & data, 4);
+  ret = i2c_write(priv->i2c, &config, (FAR uint8_t *) & data, 4);
   if (ret < 0)
     {
       snerr("ERROR: i2c_write failed: %d\n", ret);
@@ -1016,7 +1016,7 @@ static void vl53l1x_putreg32(FAR struct vl53l1x_dev_s *priv,
 
   /* Write the register address and value */
 
-  ret = i2c_write(priv->i2c, &config, (uint8_t *) & data, 7);
+  ret = i2c_write(priv->i2c, &config, (FAR uint8_t *) & data, 7);
   if (ret < 0)
     {
       snerr("ERROR: i2c_write failed: %d\n", ret);
@@ -1079,8 +1079,8 @@ static void vl53l1x_ioctl(FAR struct file *filep, int cmd, uint16_t arg)
       {
         sninfo("Calibrating distance\n");
         int16_t offset;
-        vl53l1x_getoffset(priv, (int16_t *)&offset);
-        vl53l1x_calibrateoffset(priv, arg, (int16_t *)&offset);
+        vl53l1x_getoffset(priv, (FAR int16_t *)&offset);
+        vl53l1x_calibrateoffset(priv, arg, (FAR int16_t *)&offset);
       }
       break;
 
