@@ -37,8 +37,6 @@
 #include <nuttx/mutex.h>
 #include <nuttx/spi/spi_transfer.h>
 
-#ifdef CONFIG_SPI_DRIVER
-
 /****************************************************************************
  * Pre-processor Definitions
  ****************************************************************************/
@@ -118,16 +116,16 @@ static const struct file_operations g_spidrvr_fops =
 #ifndef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
 static int spidrvr_open(FAR struct file *filep)
 {
-  FAR struct inode *inode;
   FAR struct spi_driver_s *priv;
   int ret;
 
+  /* Sanity check */
+
+  DEBUGASSERT(filep->f_inode->i_private != NULL);
+
   /* Get our private data structure */
 
-  inode = filep->f_inode;
-
-  priv = inode->i_private;
-  DEBUGASSERT(priv);
+  priv = filep->f_inode->i_private;
 
   /* Get exclusive access to the SPI driver state structure */
 
@@ -154,16 +152,16 @@ static int spidrvr_open(FAR struct file *filep)
 #ifndef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
 static int spidrvr_close(FAR struct file *filep)
 {
-  FAR struct inode *inode;
   FAR struct spi_driver_s *priv;
   int ret;
 
+  /* Sanity check */
+
+  DEBUGASSERT(filep->f_inode->i_private != NULL);
+
   /* Get our private data structure */
 
-  inode = filep->f_inode;
-
-  priv = inode->i_private;
-  DEBUGASSERT(priv);
+  priv = filep->f_inode->i_private;
 
   /* Get exclusive access to the SPI driver state structure */
 
@@ -186,6 +184,7 @@ static int spidrvr_close(FAR struct file *filep)
     {
       nxmutex_destroy(&priv->lock);
       kmm_free(priv);
+      filep->f_inode->i_private = NULL;
       return OK;
     }
 
@@ -220,19 +219,18 @@ static ssize_t spidrvr_write(FAR struct file *filep, FAR const char *buffer,
 
 static int spidrvr_ioctl(FAR struct file *filep, int cmd, unsigned long arg)
 {
-  FAR struct inode *inode;
   FAR struct spi_driver_s *priv;
   FAR struct spi_sequence_s *seq;
   int ret;
 
+  /* Sanity check */
+
+  DEBUGASSERT(filep->f_inode->i_private != NULL);
   spiinfo("cmd=%d arg=%lu\n", cmd, arg);
 
   /* Get our private data structure */
 
-  inode = filep->f_inode;
-
-  priv = inode->i_private;
-  DEBUGASSERT(priv);
+  priv = filep->f_inode->i_private;
 
   /* Get exclusive access to the SPI driver state structure */
 
@@ -307,6 +305,7 @@ static int spidrvr_unlink(FAR struct inode *inode)
     {
       nxmutex_destroy(&priv->lock);
       kmm_free(priv);
+      inode->i_private = NULL;
       return OK;
     }
 
@@ -370,7 +369,7 @@ int spi_register(FAR struct spi_dev_s *spi, int bus)
 
       /* Create the character device name */
 
-      snprintf(devname, DEVNAME_FMTLEN, DEVNAME_FMT, bus);
+      snprintf(devname, sizeof(devname), DEVNAME_FMT, bus);
       ret = register_driver(devname, &g_spidrvr_fops, 0666, priv);
       if (ret < 0)
         {
@@ -393,4 +392,3 @@ int spi_register(FAR struct spi_dev_s *spi, int bus)
   return -ENOMEM;
 }
 
-#endif /* CONFIG_SPI_DRIVER */
